-- *******************************************************
-- KOHA 3.0 MARC 21 STANDARD DEFAULT AUTHORITY FRAMEWORKS
--
--                  PRETEST VERSION 0.0.10
--                       2007-10-12
--
--                         edited
--                   by thd for LibLime
--
--                       BASED UPON
--
--   KOHA MARC 21 STANDARD DEFAULT AUTHORITY FRAMEWORKS
--
--                  PRETEST VERSION 0.0.6
--                       2007-09-29
--
--  original default requiring greater user customisation
--               created by a few Koha Hands
--                 guided by Paul POULAIN
--
--       revised and greatly enlarged to completion,
--            well not quite complete yet today
--        but close enough for someone to have use,
--                   by thd for LibLime
-- *******************************************************




-- ******************************************************
-- KOHA DEFAULT MARC 21 AUTHORITY TYPE.
-- ******************************************************

-- This authority type includes all fields and subfieds used by any
-- authority type.

INSERT INTO `auth_types` (`authtypecode`, `authtypetext`, `auth_tag_to_report`, `summary`) VALUES
		('', 'Default', '', '');


-- ******************************************************
-- KOHA SUPPORTED STANDARD MARC 21 AUTHORITY TYPES.
-- ******************************************************

-- These authority types are supported for for guiding the cataloguer to
-- fill authorised values in Koha MARC bibliographic editor.


INSERT INTO `auth_types` (`authtypecode`, `authtypetext`, `auth_tag_to_report`, `summary`) VALUES
		('PERSO_NAME', 'Personenname', '100', 'Personenname'),
		('CORPO_NAME', 'Körperschaftsname', '110', 'Körperschaftsname'),
		('MEETI_NAME', 'Kongressname', '111', 'Kongressname'),
		('UNIF_TITLE', 'Einheitstitel', '130', 'Einheitstitel'),
		('CHRON_TERM', 'Zeitschlagwort', '148', 'Zeitschlagwort'),
		('TOPIC_TERM', 'Sachschlagwort', '150', 'Sachschlagwort'),
		('GEOGR_NAME', 'Geografischer Name', '151', 'Geografischer Name'),
		('GENRE/FORM', 'Genre/Formschlagwort', '155', 'Genre/Formschlagwort');


-- ******************************************************
-- KOHA UNSUPPORTED STANDARD MARC 21 AUTHORITY TYPES.
-- ******************************************************

-- These authority types are only supported for guiding the cataloguer to
-- fill authorised values in the Koha MARC bibliographic editor to the
-- extent that they have already been included in a primary authority type,
-- therefore, they have not yet been specified.
--
-- Minimal primary authorities including subdivisions may currently be
-- built by a script which uses the values in bibliographic records but
-- include no tracings and references which are necessarily not present
-- in bibliographic records.


-- INSERT INTO `auth_types` (`authtypecode`, `authtypetext`, `auth_tag_to_report`, `summary`) VALUES
-- 		('TOPIC_SUBD', 'General Topical Term Subdivision', '180', 'General Topical Term Subdivision'),
-- 		('GEOGR_SUBD', 'Geografische Unterteilung', '181', 'Geografische Unterteilung'),
-- 		('CHRON_SUBD', 'Chronologische Unterteilung', '182', 'Chronologische Unterteilung'),
-- 		('FORM_SUBDI', 'Unterteilung nach Form', '185', 'Unterteilung nach Form');



-- *****************************************************************
-- MARC 21 AUTHORITY FIELDS/SUBFIELDS AND COMMMONLY USED EXTENSIONS
-- *****************************************************************


-- No support for subfield visibility is yet provided by the Koha code
-- matching the column name 'hidden' in the bibliographic framework.
--
-- Needs checking for errors but probably tolerable for use on a production.
-- A server can be upgraded easily from later versions of this file.
--
-- In the absense of more column support for qualifying the relative
-- importance of subfields to the record editor, some modest modification of
-- the default framework is needed setting the not-useful non-Koha holdings
-- subfields to not managed in Koha.

-- MARC fields including letters as part of the field identifier are from RLIN
-- and should be expected to remain along with RLIN $% subfields.  RLIN has
-- been using letters in fields because there are not enough local use number
-- fields which have not already been specified for very large union catalogue
-- networks such as RLIN itself.

-- Fields ending in a or b are temporary placeholders for information from
-- a numeric value until a non-conflicting way to treat the content under the
-- proper original numeric field is adopted.  090 for LC call numbers is much
-- too common and important so 999 is also provided as a temporary place
-- holder until all Koha code for finding control fields has been changed from
-- a numeric test of < 10 to a regular expression match of m/^00/ to prevent
-- mistaken matching of fields with letters such as 09o if they were control
-- fields.

-- Fields and subfields which belong exclusively in a classification
-- framework have been marked '[CLASSIFICATION FRAMEWORK]'.  They are retained
-- or included here becuase some had been included previously and Koha does
-- not yet have a classification framework.


INSERT INTO `auth_tag_structure` (`authtypecode`, `tagfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `authorised_value`) VALUES
		('', '000', 'Leader', 'Leader', 0, 1, NULL),
		('', '001', 'Kontrollnummer', 'Kontrollnummer', 0, 1, NULL),
		('', '003', 'Kontrollnummer Identifier', 'Kontrollnummer Identifier', 0, 1, NULL),
		('', '005', 'Datum und Zeit der letzten Transaktion', 'Datum und Zeit der letzten Transaktion', 0, 1, NULL),
		('', '008', 'Datenelemente mit fester Länge', 'Datenelemente mit fester Länge', 0, 1, NULL),
		('', '010', 'Kontrollnummer der Library of Congress', 'Kontrollnummer der Library of Congress', 0, 0, NULL),
		('', '014', 'Verknüpfung zum bibliografischen Datensatz für Gesamttitel oder mehrteilige Exemplare', 'Verknüpfung zum bibliografischen Datensatz für Gesamttitel oder mehrteilige Exemplare', 1, 0, NULL),
		('', '016', 'Kontrollnummer der nationalen bibliografischen Stelle', 'Kontrollnummer der nationalen bibliografischen Stelle', 1, 0, NULL),
		('', '020', 'Internationale Standardbuchnummer', 'Internationale Standardbuchnummer', 1, 0, NULL),
		('', '022', 'Internationale Standardseriennummer', 'Internationale Standardseriennummer', 1, 0, NULL),
		('', '024', 'Anderer Standard-Identifier', 'Anderer Standard-Identifier', 1, 0, NULL),
		('', '031', 'Informationen zum Musik-Incipit', 'Informationen zum Musik-Incipit', 1, 0, NULL),
		('', '034', 'Kodierte kartografische mathematische Angaben', 'Kodierte kartografische mathematische Angaben', 1, 0, NULL),
		('', '035', 'System-Kontrollnummer', 'System-Kontrollnummer', 1, 0, NULL),
		('', '040', 'Katalogisierungsquelle', 'Katalogisierungsquelle', 0, 1, NULL),
		('', '042', 'Authentifizierungscode', 'Authentifizierungscode', 0, 0, NULL),
		('', '043', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 0, 0, NULL),
		('', '045', 'Zeitabschnitt der Ansetzung', 'Zeitabschnitt der Ansetzung', 0, 0, NULL),
		('', '050', 'Signatur der Library of Congress', 'Signatur der Library of Congress', 1, 0, NULL),
		('', '052', 'Geografische Klassifikation', 'Geografische Klassifikation', 1, 0, NULL),
		('', '053', 'Notation der LC', 'Notation der LC', 1, 0, NULL),
		('', '055', 'Signatur der Library and Archives Canada', 'Signatur der Library and Archives Canada', 1, 0, NULL),
		('', '058', 'LC CLASSIFICATION NUMBER ASSIGNED IN CANADA [OBSOLETE, CAN/MARC]', 'LC CLASSIFICATION NUMBER ASSIGNED IN CANADA [OBSOLETE, CAN/MARC]', 1, 0, NULL),
		('', '060', 'Signatur der National Library of Medicine', 'Signatur der National Library of Medicine', 1, 0, NULL),
		('', '063', 'NLM CLASSIFICATION NUMBER ASSIGNED BY NLM [OBSOLETE, CAN/MARC]', 'NLM CLASSIFICATION NUMBER ASSIGNED BY NLM [OBSOLETE, CAN/MARC]', 1, 0, NULL),
		('', '065', 'Andere Notation', 'Andere Notation', 1, 0, NULL),
		('', '066', 'Angewendete Zeichensätze', 'Angewendete Zeichensätze', 0, 0, NULL),
		('', '068', 'NLM CLASSIFICATION NUMBER ASSIGNED IN CANADA [OBSOLETE, CAN/MARC]', 'NLM CLASSIFICATION NUMBER ASSIGNED IN CANADA [OBSOLETE, CAN/MARC]', 1, 0, NULL),
		('', '070', 'Signatur der National Agricultural Library', 'Signatur der National Agricultural Library', 1, 0, NULL),
		('', '072', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 1, 0, NULL),
		('', '073', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 0, 0, NULL),
		('', '082', 'Dewey-Dezimal-Signatur', 'Dewey-Dezimal-Signatur', 1, 0, NULL),
		('', '083', 'DDC-Notation', 'DDC-Notation', 1, 0, NULL),
		('', '084', 'CLASSIFICATION SCHEME AND EDITION [CLASSIFICATION FORMAT]', 'CLASSIFICATION SCHEME AND EDITION [CLASSIFICATION FORMAT]', 0, 0, NULL),
		('', '086', 'Signatur für Amtsdruckschriften', 'Signatur für Amtsdruckschriften', 1, 0, NULL),
		('', '087', 'Notation für Amtsdruckschriften', 'Notation für Amtsdruckschriften', 1, 0, NULL),
		('', '088', 'DOCUMENT SHELVING NUMBER (CODOC) [OBSOLETE, CAN/MARC]', 'DOCUMENT SHELVING NUMBER (CODOC) [OBSOLETE, CAN/MARC]', 1, 0, NULL),
		('', '090', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (RLIN)', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (OCLC)', 1, 0, NULL),
		('', '091', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 0, 0, NULL),
		('', '092', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 1, 0, NULL),
		('', '093', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('', '096', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 1, 0, NULL),
		('', '097', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('', '098', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 1, 0, NULL),
		('', '099', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 1, 0, NULL),
		('', '100', 'Ansetzung - Personenname', 'Ansetzung - Personenname', 0, 0, NULL),
		('', '110', 'Ansetzung - Körperschaftsname', 'Ansetzung - Körperschaftsname', 0, 0, NULL),
		('', '111', 'Ansetzung - Kongressname', 'Ansetzung - Kongressname', 0, 0, NULL),
		('', '130', 'Ansetzung - Einheitstitel', 'Ansetzung - Einheitstitel', 0, 0, NULL),
		('', '140', 'UNIFORM TITLE [OBSOLETE, CAN/MARC]', 'UNIFORM TITLE [OBSOLETE, CAN/MARC]', 1, 0, NULL),
		('', '143', 'COLLECTIVE TITLE [OBSOLETE, CAN/MARC]', 'COLLECTIVE TITLE [OBSOLETE, CAN/MARC]', 1, 0, NULL),
		('', '148', 'Ansetzung - Zeitschlagwort', 'Ansetzung - Zeitschlagwort', 0, 0, NULL),
		('', '150', 'Ansetzung - Zeitschlagwort', 'Ansetzung - Zeitschlagwort', 0, 0, NULL),
		('', '151', 'Ansetzung - Geografischer Name', 'Ansetzung - Geografischer Name', 0, 0, NULL),
		('', '153', 'CLASSIFICATION NUMBER [CLASSIFICATION FORMAT]', 'CLASSIFICATION NUMBER [CLASSIFICATION FORMAT]', 0, 0, NULL),
		('', '154', 'GENERAL EXPLANATORY INDEX TERM [CLASSIFICATION FORMAT]', 'GENERAL EXPLANATORY INDEX TERM [CLASSIFICATION FORMAT]', 0, 0, NULL),
		('', '155', 'Ansetzung - Genre/Form Schlagwort', 'Ansetzung - Genre/Form Schlagwort', 0, 0, NULL),
		('', '180', 'Ansetzung - Allgemeine Unterteilung', 'Ansetzung - Allgemeine Unterteilung', 0, 0, NULL),
		('', '181', 'Ansetzung - Geografische Unterteilung', 'Ansetzung - Geografische Unterteilung', 0, 0, NULL),
		('', '182', 'Ansetzung - Chronologische Unterteilung', 'Ansetzung - Chronologische Unterteilung', 0, 0, NULL),
		('', '185', 'Ansetzung - Unterteilung nach Form', 'Ansetzung - Unterteilung nach Form', 0, 0, NULL),
		('', '253', 'COMPLEX SEE REFERENCE [CLASSIFICATION FORMAT]', 'COMPLEX SEE REFERENCE [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '260', 'Komplexer Siehe-Hinweis - Schlagwort', 'Komplexer Siehe-Hinweis - Schlagwort', 1, 0, NULL),
		('', '353', 'COMPLEX SEE ALSO REFERENCE [CLASSIFICATION FORMAT]', 'COMPLEX SEE ALSO REFERENCE [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '360', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 1, 0, NULL),
		('', '400', 'Siehe-Verweisung - Personenname', 'Siehe-Verweisung - Personenname', 1, 0, NULL),
		('', '410', 'Siehe-Verweisung - Körperschaftsname', 'Siehe-Verweisung - Körperschaftsname', 1, 0, NULL),
		('', '411', 'Siehe-Verweisung - Kongressname', 'Siehe-Verweisung - Kongressname', 1, 0, NULL),
		('', '430', 'Siehe-Verweisung - Einheitstitel', 'Siehe-Verweisung - Einheitstitel', 1, 0, NULL),
		('', '448', 'Siehe-Verweisung - Zeitschlagwort', 'Siehe-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('', '450', 'Siehe-Verweisung - Sachschlagwort', 'Siehe-Verweisung - Sachschlagwort', 1, 0, NULL),
		('', '451', 'Siehe-Verweisung - Geografischer Name', 'Siehe-Verweisung - Geografischer Name', 1, 0, NULL),
		('', '453', 'INVALID NUMBER TRACING [CLASSIFICATION FORMAT]', 'INVALID NUMBER TRACING [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '455', 'Siehe-Verweisung - Genre/Formschlagwort', 'Siehe-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('', '480', 'Siehe-Verweisung - Allgemeine Unterteilung', 'Siehe-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('', '481', 'Siehe-Verweisung - Geografische Unterteilung', 'Siehe-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('', '482', 'Siehe-Verweisung - Chronologische Unterteilung', 'Siehe-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('', '485', 'Siehe-Verweisung - Unterteilung nach Form', 'Siehe-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('', '500', 'Siehe-auch-Verweisung - Personenname', 'Siehe-auch-Verweisung - Personenname', 1, 0, NULL),
		('', '510', 'Siehe-auch-Verweisung - Körperschaftsname', 'Siehe-auch-Verweisung - Körperschaftsname', 1, 0, NULL),
		('', '511', 'Siehe-auch-Verweisung - Kongressname', 'Siehe-auch-Verweisung - Kongressname', 1, 0, NULL),
		('', '530', 'Siehe-auch-Verweisung - Einheitstitel', 'Siehe-auch-Verweisung - Einheitstitel', 1, 0, NULL),
		('', '548', 'Siehe-auch-Verweisung - Zeitschlagwort', 'Siehe-auch-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('', '550', 'Siehe-auch-Verweisung - Sachschlagwort', 'Siehe-auch-Verweisung - Sachschlagwort', 1, 0, NULL),
		('', '551', 'Siehe-auch-Verweisung - Geografischer Name', 'Siehe-auch-Verweisung - Geografischer Name', 1, 0, NULL),
		('', '553', 'VALID NUMBER TRACING [CLASSIFICATION FORMAT]', 'VALID NUMBER TRACING [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '555', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('', '580', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('', '581', 'Siehe-auch-Verweisung - Geografische Unterteilung', 'Siehe-auch-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('', '582', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('', '585', 'Siehe-auch-Verweisung - Unterteilung nach Form', 'Siehe-auch-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('', '640', 'Erscheinungsjahr und/oder Erscheinungsverlauf von Gesamttiteln', 'Erscheinungsjahr und/oder Erscheinungsverlauf von Gesamttiteln', 1, 0, NULL),
		('', '641', 'Besonderheiten der Zählung von Gesamttiteln', 'Besonderheiten der Zählung von Gesamttiteln', 1, 0, NULL),
		('', '642', 'Beispiel für die Zählung von Gesamttiteln', 'Beispiel für die Zählung von Gesamttiteln', 1, 0, NULL),
		('', '643', 'Erscheinungsort und herausgebende Körperschaft von Gesamttiteln', 'Erscheinungsort und herausgebende Körperschaft von Gesamttiteln', 1, 0, NULL),
		('', '644', 'Analysepraxis von Gesamttiteln', 'Analysepraxis von Gesamttiteln', 1, 0, NULL),
		('', '645', 'Verweisungspraxis von Gesamttiteln', 'Verweisungspraxis von Gesamttiteln', 1, 0, NULL),
		('', '646', 'Klassifizierungspraxis von Gesamttiteln', 'Klassifizierungspraxis von Gesamttiteln', 1, 0, NULL),
		('', '663', 'Komplexe Siehe-auch-Verweisung - Name', 'Komplexe Siehe-auch-Verweisung - Name', 0, 0, NULL),
		('', '664', 'Komplexe Siehe-Verweisung - Name', 'Komplexe Siehe-Verweisung - Name', 0, 0, NULL),
		('', '665', 'Geschichte der Verweisung', 'Geschichte der Verweisung', 0, 0, NULL),
		('', '666', 'Allgemein erläuternde Verweisung - Name', 'Allgemein erläuternde Verweisung - Name', 0, 0, NULL),
		('', '667', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 1, 0, NULL),
		('', '668', 'CHARACTERS IN NONROMAN ALPHABETS [OBSOLETE]', 'CHARACTERS IN NONROMAN ALPHABETS [OBSOLETE]', 1, 0, NULL),
		('', '670', 'Datenquelle', 'Datenquelle', 1, 0, NULL),
		('', '671', 'NOTE--WORK CATALOGUED [OBSOLETE, CAN/MARC ONLY]', 'NOTE--WORK CATALOGUED [OBSOLETE, CAN/MARC ONLY]', 1, 0, NULL),
		('', '675', 'Datenquelle ohne Information', 'Datenquelle ohne Information', 0, 0, NULL),
		('', '676', 'NOTE--CATALOGUING RULES (NAMES/TITLES) [OBSOLETE, CAN/MARC ONLY]', 'NOTE--CATALOGUING RULES (NAMES/TITLES) [OBSOLETE, CAN/MARC ONLY]', 0, 0, NULL),
		('', '678', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, NULL),
		('', '680', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, NULL),
		('', '681', 'Beispiel für die Schlagwortverweisung', 'Beispiel für die Schlagwortverweisung', 1, 0, NULL),
		('', '682', 'Beispiel für die Schlagwortverweisung', 'Beispiel für die Schlagwortverweisung', 0, 0, NULL),
		('', '683', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('', '684', 'AUXILIARY INSTRUCTION NOTE [CLASSIFICATION FORMAT]', 'AUXILIARY INSTRUCTION NOTE [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '685', 'NOTE--SOURCE DATA FOUND (SUBJECTS) [OBSOLETE, CAN/MARC ONLY]', 'NOTE--SOURCE DATA FOUND (SUBJECTS) [OBSOLETE, CAN/MARC ONLY]', 1, 0, NULL),
		('', '686', 'NOTE--SOURCE DATA NOT FOUND (SUBJECTS) [OBSOLETE, CAN/MARC ONLY]', 'NOTE--SOURCE DATA NOT FOUND (SUBJECTS) [OBSOLETE, CAN/MARC ONLY]', 1, 0, NULL),
		('', '687', 'NOTE--USAGE (SUBJECTS) [OBSOLETE, CAN/MARC ONLY]', 'NOTE--USAGE (SUBJECTS) [OBSOLETE, CAN/MARC ONLY]', 1, 0, NULL),
		('', '688', 'Anwendungsgeschichte', 'Anwendungsgeschichte', 1, 0, NULL),
		('', '700', 'Verknüpfungseintragung für normierte Ansetzungen - Personenname', 'Verknüpfungseintragung für normierte Ansetzungen - Personenname', 1, 0, NULL),
		('', '710', 'Verknüpfungseintragung für normierte Ansetzungen - Körperschaftsname', 'Verknüpfungseintragung für normierte Ansetzungen - Körperschaftsname', 1, 0, NULL),
		('', '711', 'Verknüpfungseintragung für normierte Ansetzungen - Kongressname', 'Verknüpfungseintragung für normierte Ansetzungen - Kongressname', 1, 0, NULL),
		('', '730', 'Verknüpfungseintragung für normierte Ansetzungen - Einheitstitel', 'Verknüpfungseintragung für normierte Ansetzungen - Einheitstitel', 1, 0, NULL),
		('', '748', 'Verknüpfungseintragung für normierte Ansetzungen - Zeitschlagwort', 'Verknüpfungseintragung für normierte Ansetzungen - Zeitschlagwort', 1, 0, NULL),
		('', '750', 'Verknüpfungseintragung für normierte Ansetzungen - Sachschlagwort', 'Verknüpfungseintragung für normierte Ansetzungen - Sachschlagwort', 1, 0, NULL),
		('', '751', 'Verknüpfungseintragung für normierte Ansetzungen - Geografischer Name', 'Verknüpfungseintragung für normierte Ansetzungen - Geografischer Name', 1, 0, NULL),
		('', '753', 'INDEX TERM--UNCONTROLLED [CLASSIFICATION FORMAT]', 'INDEX TERM--UNCONTROLLED [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '754', 'INDEX TERM--FACETED TOPICAL TERMS [CLASSIFICATION FORMAT]', 'INDEX TERM--FACETED TOPICAL TERMS [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '755', 'Verknüpfungseintragung für normierte Ansetzungen - Genre/Formschlagwort', 'Verknüpfungseintragung für normierte Ansetzungen - Genre/Formschlagwort', 1, 0, NULL),
		('', '761', 'ADD OR DIVIDE LIKE INSTRUCTIONS [CLASSIFICATION FORMAT]', 'ADD OR DIVIDE LIKE INSTRUCTIONS [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '762', 'TABLE IDENTIFICATION [CLASSIFICATION FORMAT]', 'TABLE IDENTIFICATION [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '763', 'INTERNAL SUBARRANGEMENT OR ADD TABLE ENTRY [CLASSIFICATION FORMAT]', 'INTERNAL SUBARRANGEMENT OR ADD TABLE ENTRY [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '764', 'RULE IDENTIFICATION [CLASSIFICATION FORMAT]', 'RULE IDENTIFICATION [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '765', 'SYNTHESIZED NUMBER COMPONENTS [CLASSIFICATION FORMAT]', 'SYNTHESIZED NUMBER COMPONENTS [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '766', 'SECONDARY TABLE INFORMATION [CLASSIFICATION FORMAT]', 'SECONDARY TABLE INFORMATION [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '768', 'CITATION AND PREFERENCE ORDER INSTRUCTIONS [CLASSIFICATION FORMAT]', 'CITATION AND PREFERENCE ORDER INSTRUCTIONS [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '780', 'Verknüpfungseintragung der Unterteilung - Allgemeine Unterteilung', 'Verknüpfungseintragung der Unterteilung - Allgemeine Unterteilung', 1, 0, NULL),
		('', '781', 'Verknüpfungseintragung der Unterteilung - Geografische Unterteilung', 'Verknüpfungseintragung der Unterteilung - Geografische Unterteilung', 1, 0, NULL),
		('', '782', 'Verknüpfungseintragung der Unterteilung - Chronologische Unterteilung', 'Verknüpfungseintragung der Unterteilung - Chronologische Unterteilung', 1, 0, NULL),
		('', '785', 'Verknüpfungseintragung der Unterteilung - Unterteilung nach Form', 'Verknüpfungseintragung der Unterteilung - Unterteilung nach Form', 1, 0, NULL),
		('', '788', 'Komplexe Verknüpfungseintragungsdaten', 'Komplexe Verknüpfungseintragungsdaten', 0, 0, NULL),
		('', '856', 'Elektronische Adresse und Zugriff', 'Elektronische Adresse und Zugriff', 1, 0, NULL),
		('', '880', 'Andersschriftliche Darstellung', 'Andersschriftliche Darstellung', 1, 0, NULL),
        ('', '942', 'Koha-interne Verwendung', 'Koha-interne Verwendung', 0, 1, NULL);



INSERT INTO `auth_subfield_structure` (`authtypecode`, `tagfield`, `tagsubfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `tab`, `authorised_value`, `value_builder`, `seealso`, `isurl`, `hidden`, `linkid`, `kohafield`, `frameworkcode`) VALUES
		('', '000', '@', 'Kontrollfeld fester Länge', 'Kontrollfeld fester Länge', 0, 1, 0, NULL, 'marc21_leader_authorities.pl', NULL, 0, 0, '', '', ''),
		('', '001', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', 'auth_header.authid', ''),
		('', '003', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
		('', '005', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_005.pl', NULL, 0, 0, '', '', ''),
		('', '008', '@', 'Kontrollfeld fester Länge', 'Kontrollfeld fester Länge', 0, 1, 0, NULL, 'marc21_field_008_authorities.pl', NULL, 0, 0, '', '', ''),
		('', '010', 'a', 'LoC-Kontrollnummer', 'LoC-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '010', 'z', 'Gelöschte/ungültige LoC-Kontrollnummer', 'Gelöschte/ungültige LoC-Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '010', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '014', 'a', 'Kontrollnummer des verwandten bibliografischen Datensatzes', 'Kontrollnummer des verwandten bibliografischen Datensatzes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '014', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '014', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '016', 'a', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '016', 'z', 'Gelöschte oder ungültige Datensatzkontrollnummer', 'Gelöschte oder ungültige Datensatzkontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '016', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '016', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '020', 'a', 'Internationale Standardbuchnummer', 'Internationale Standardbuchnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '020', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '020', 'z', 'Gelöschte/ungültige ISBN', 'Gelöschte/ungültige ISBN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '020', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '020', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '022', 'a', 'Internationale Standardseriennummer', 'Internationale Standardseriennummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '022', 'y', 'Falsche ISSN', 'Falsche ISSN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '022', 'z', 'Gelöschte ISSN', 'Gelöschte ISSN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '022', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '022', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', 'a', 'Standardnummer oder Code', 'Standardnummer oder Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', 'd', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', 'z', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', '2', 'Quelle der Nummer oder des Codes', 'Quelle der Nummer oder des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'a', 'Number of work', 'Number of work', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'b', 'Satznummer', 'Satznummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'c', 'Nummer des Ausschnitts', 'Nummer des Ausschnitts', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'd', 'Titel oder Ansetzung', 'Titel oder Ansetzung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'e', 'Partie', 'Partie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'g', 'Notenschlüssel', 'Notenschlüssel', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'm', 'Stimme/Instrument', 'Stimme/Instrument', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'n', 'Tonartvorzeichen', 'Tonartvorzeichen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'o', 'Taktvorzeichen', 'Taktvorzeichen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'p', 'Musikalische Notierung', 'Musikalische Notierung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'q', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'r', 'Tonart oder Modus', 'Tonart oder Modus', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 's', 'Kodierte Fußnote zur Echtheit', 'Kodierte Fußnote zur Echtheit', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 't', 'Text-Incipit', 'Text-Incipit', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', '2', 'Systemcode', 'Systemcode', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'd', 'Koordinaten - westlichster Längengrad', 'Koordinaten - westlichster Längengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'e', 'Koordinaten - östlichster Längengrad', 'Koordinaten - östlichster Längengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'f', 'Koordinaten - nördlichster Breitengrad', 'Koordinaten - nördlichster Breitengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'g', 'Koordinaten - südlichster Breitengrad', 'Koordinaten - südlichster Breitengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'j', 'Deklination - nördliche Grenze', 'Deklination - nördliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'k', 'Deklination - südliche Grenze', 'Deklination - südliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'm', 'Rektaszension - östliche Grenze', 'Rektaszension - östliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'n', 'Rektaszension - westliche Grenze', 'Rektaszension - westliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'p', 'Äquinoktium', 'Äquinoktium', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'r', 'Entfernung von der Erde', 'Entfernung von der Erde',  1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 's', 'G-Ring Breitengrad', 'G-Ring Breitengrad', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 't', 'G-Ring Längengrad', 'G-Ring Längengrad', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'x', 'Anfangsdatum', 'Anfangsdatum', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'y', 'Enddatum', 'Enddatum', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'z', 'Name des außerirdischen Himmelskörpers', 'Name des außerirdischen Himmelskörpers', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '035', 'a', 'System-Kontrollnummer', 'System-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '035', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '035', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '035', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', 'a', 'Original-Katalogisierungsstelle', 'Original-Katalogisierungsstelle', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
		('', '040', 'b', 'Katalogisierungssprache', 'Katalogisierungssprache', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', 'c', 'Übertragungsstelle', 'Übertragungsstelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', 'd', 'Bearbeitungsstelle', 'Bearbeitungsstelle', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', 'e', 'Beschreibungsfestlegungen', 'Beschreibungsfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', 'f', 'Schlagwort- oder Thesaurusfestlegungen', 'Schlagwort- oder Thesaurusfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '042', 'a', 'Authentifizierungscode', 'Authentifizierungscode', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '043', 'a', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '043', 'b', 'Lokaler GAC-Code', 'Lokaler GAC-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '043', 'c', 'ISO-Code', 'ISO-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '043', '2', 'Quelle des lokalen Codes', 'Quelle des lokalen Codes', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '043', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '043', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '045', 'a', 'Zeitabschnitts-Code', 'Zeitabschnitts-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '045', 'b', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '045', 'c', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '045', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '045', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '050', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '050', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '050', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '050', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '050', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '050', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '052', 'a', 'Klassifikation des geografischen Gebiets', 'Klassifikation des geografischen Gebiets', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '052', 'b', 'Klassifikation des geografischen Teilgebiets', 'Klassifikation des geografischen Teilgebiets', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '052', 'd', 'Eingetragener Ortsname', 'Eingetragener Ortsname', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '052', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '052', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '052', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '053', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '053', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '053', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '053', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '053', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '053', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '055', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '055', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '055', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '055', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '055', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '055', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '058', 'a', 'LC-Notation - Einzelnummer oder Beginnnummer des Bereiches', 'LC-Notation - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '058', 'b', 'LC-Notation - Endnummer des Bereiches', 'LC-Notation - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '058', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '058', '5', 'Bibliothek, auf die sich das Feld bezieht', 'Bibliothek, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '058', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '060', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '060', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '060', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '060', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '060', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '060', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '063', 'a', 'NLM-Notation - Einzelnummer oder Beginnnummer des Bereiches', 'NLM-Notation - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '063', 'b', 'NLM-Notation - Endnummer des Bereiches', 'NLM-Notation - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '063', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '065', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '065', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '065', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '065', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '065', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '065', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '065', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '066', 'a', 'Primärer G0-Zeichensatz', 'Primärer G0-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '066', 'b', 'Primärer G1-Zeichensatz', 'Primärer G1-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '066', 'c', 'Wechselnder G0- oder G1-Zeichensatz', 'Wechselnder G0- oder G1-Zeichensatz', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '068', 'a', 'NLM-Notation - Einzelnummer oder Beginnnummer des Bereiches', 'NLM-Notation - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '068', 'b', 'NLM-Notation - Endnummer des Bereiches', 'NLM-Notation - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '068', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '068', '5', 'Bibliothek, auf die sich das Feld bezieht', 'Bibliothek, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '070', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '070', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '070', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '070', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '070', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '072', 'a', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '072', 'x', 'Code der Unterteilung der Sacherschließungskategorien', 'Code der Unterteilung der Sacherschließungskategorien', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '072', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '072', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '072', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '073', 'a', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '073', 'z', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '073', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '073', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'a', 'Classification scheme code', 'Classification scheme code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'b', 'Edition title', 'Edition title', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'c', 'Edition identifier', 'Edition identifier', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'd', 'Source edition identifier', 'Source edition identifier', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'e', 'Language code', 'Language code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'f', 'Authorization', 'Authorization', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'n', 'Variations', 'Variations', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', 'a', 'Signatur', 'Signatur', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '087', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '087', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '087', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '087', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '087', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '087', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '088', 'a', 'Document shelving number (CODOC)', 'Document shelving number (CODOC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'a', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'b', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'e', 'Feature heading (OCLC)', 'Feature heading (OCLC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'f', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'h', 'Output transaction history, HST (RLIN)', 'Output transaction history, HST (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'i', 'Output transaction instruction, INS (RLIN)', 'Output transaction instruction, INS (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'l', 'Extra card control statement, EXT (RLIN)', 'Extra card control statement, EXT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'n', 'Additional local notes, ANT (RLIN)', 'Additional local notes, ANT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'p', 'Pathfinder code, PTH (RLIN)', 'Pathfinder code, PTH (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 't', 'Field suppresion, FSP (RLIN)', 'Field suppresion, FSP (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'v', 'Volumes, VOL (RLIN)', 'Volumes, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'y', 'Date, VOL (RLIN)', 'Date, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', 'a', 'Call number based on other classification scheme', 'Call number based on other classification scheme', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'a', 'Personenname', 'Personenname', 0, 0, 1, NULL, NULL, '''100b'',''100c'',''100q'',''100d'',''100t'',''100o'',''100m'',''100r'',''100s'',''100k'',''100n'',''100p'',''100g'',''100l'',''100f'',''100h'',''100x'',''100z'',''100y'',''100v''', 0, 0, '', '', ''),
		('', '100', 'b', 'Zählung', 'Zählung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'h', 'Medium', 'Medium', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'r', 'Tonart', 'Tonart', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 's', 'Version', 'Version', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 1, NULL, NULL, '''110b'',''110c'',''110d'',''110t'',''110o'',''110m'',''110r'',''110s'',''110k'',''110n'',''110p'',''110g'',''110l'',''110f'',''110h'',''110x'',''110z'',''110y'',''110v''', 0, 0, '', '', ''),
		('', '110', 'b', 'Untergeordnete Körperschaft', 'Untergeordnete Körperschaft', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'h', 'Medium', 'Medium', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'k', 'Unterteilung nach der Form', 'Unterteilung nach der Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'r', 'Tonart', 'Tonart', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 's', 'Version', 'Version', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 1, NULL, NULL, '''111e'',''111c'',''111d'',''111t'',''111s'',''111k'',''111n'',''111p'',''111g'',''111l'',''111f'',''111h'',''111x'',''111z'',''111y'',''111v''', 0, 0, '', '', ''),
		('', '111', 'b', 'Nummer [OBSOLETE]', 'Nummer [OBSOLETE]', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'h', 'Medium', 'Medium', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'k', 'Unterteilung nach der Form', 'Unterteilung nach der Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'j', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 's', 'Version', 'Version', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 1, NULL, NULL, '''130o'',''130m'',''130r'',''130s'',''130d'',''130k'',''130n'',''130p'',''130g'',''130l'',''130f'',''130h'',''130t'',''130x'',''130z'',''130y'',''130v''', 0, 0, '', '', ''),
		('', '130', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'h', 'Medium', 'Medium', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'r', 'Tonart', 'Tonart', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 's', 'Version', 'Version', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'd', 'Date of treaty', 'Date of treaty', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'h', 'General material designation', 'General material designation', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'l', 'Language', 'Language', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'n', 'Number of part or section/serial, thematic, or opus number', 'Number of part or section/serial, thematic, or opus number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'o', 'Arranged or arr. for music', 'Arranged or arr. for music', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'p', 'Part or section', 'Part or section', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'r', 'Tonart', 'Tonart', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'x', 'General subject subdivision', 'General subject subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'y', 'Period subject subdivision', 'Period subject subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'z', 'Place subject subdivision', 'Place subject subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'a', 'Collective title', 'Collective title', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'd', 'Date of treaty', 'Date of treaty', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'h', 'General material designation', 'General material designation', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'l', 'Language', 'Language', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'n', 'Number of part or section/serial, thematic, or opus number', 'Number of part or section/serial, thematic, or opus number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'o', 'Arranged or arr. for music', 'Arranged or arr. for music', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'p', 'Part or section', 'Part or section', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'r', 'Tonart', 'Tonart', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 's', 'Version', 'Version', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '148', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 1, NULL, NULL, '''148y'',''148x'',''148z'',''148v''', 0, 0, '', '', ''),
		('', '148', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '148', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '148', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '148', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '148', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '148', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '150', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 1, NULL, NULL, '''150x'',''150z'',''150y'',''150v''', 0, 0, '', '', ''),
		('', '150', 'b', 'Einem geografischen Namen folgendes Sachschlagwort als Eintragungselement', 'Einem geografischen Namen folgendes Sachschlagwort als Eintragungselement', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '150', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '150', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '150', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '150', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '150', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '150', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 1, NULL, NULL, '''151z'',''151x'',''151y'',''151v''', 0, 0, '', '', ''),
		('', '151', 'b', 'Name following place as an entry element {OBSOLETE]', 'Name following place as an entry element {OBSOLETE]', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', 'h', 'Caption hierarchy', 'Caption hierarchy', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', 'j', 'Caption', 'Caption', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', 'k', 'Summary number span caption hierarchy', 'Summary number span caption hierarchy', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', 'z', 'Table identification', 'Table identification', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '154', 'a', 'General explanatory index term', 'General explanatory index term', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '154', 'b', 'General explanatory index term--Succeeding level', 'General explanatory index term--Succeeding level', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '154', 'f', 'Schedule identification', 'Schedule identification', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '154', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '154', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '155', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 1, NULL, NULL, '''155v'',''155x'',''155z'',''155y''', 0, 0, '', '', ''),
		('', '155', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '155', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '155', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '155', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '155', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '155', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '180', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '180', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '180', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '180', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '180', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '180', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '181', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '181', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '181', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '181', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '181', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '181', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '182', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '182', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '182', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '182', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '182', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '182', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '185', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '185', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '185', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '185', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '185', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '185', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', 'a', 'Classification number referred to--Single number or beginning number of span', 'Classification number referred to--Single number or beginning number of span', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', 'c', 'Classification number referred to--Ending number of span', 'Classification number referred to--Ending number of span', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', 'z', 'Table identification', 'Table identification', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '260', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '260', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '260', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '260', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', 'a', 'Classification number referred to--Single number or beginning number of span', 'Classification number referred to--Single number or beginning number of span', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', 'c', 'Classification number referred to--Ending number of span', 'Classification number referred to--Ending number of span', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', 'z', 'Table identification', 'Table identification', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '360', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '360', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '360', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '360', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'a', 'Personenname', 'Personenname', 0, 0, 4, NULL, NULL, '''400b'',''400c'',''400q'',''400d'',''400t'',''400o'',''400m'',''400r'',''400s'',''400k'',''400n'',''400p'',''400g'',''400l'',''400f'',''400h'',''400x'',''400z'',''400y'',''400v''', 0, 0, '', '', ''),
		('', '400', 'b', 'Zählung', 'Zählung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''410b'',''410c'',''410d'',''410t'',''410o'',''410m'',''410r'',''410s'',''410k'',''410n'',''410p'',''410g'',''410l'',''410f'',''410h'',''410x'',''410z'',''410y'',''410v''', 0, 0, '', '', ''),
		('', '410', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''411e'',''411c'',''411d'',''411t'',''411s'',''411k'',''411n'',''411p'',''411g'',''411l'',''411f'',''411h'',''411x'',''411z'',''411y'',''411v''', 0, 0, '', '', ''),
		('', '411', 'b', 'Nummer {OBSOLETE]', 'Nummer {OBSOLETE]', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 4, NULL, NULL, '''430o'',''430m'',''430r'',''430s'',''430d'',''430k'',''430n'',''430p'',''430g'',''430l'',''430f'',''430h'',''430t'',''430x'',''430z'',''430y'',''430v''', 0, 0, '', '', ''),
		('', '430', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 4, NULL, NULL, '''448y'',''448x'',''448z'',''448v''', 0, 0, '', '', ''),
		('', '448', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 4, NULL, NULL, '''450x'',''450z'',''450y'',''450v''', 0, 0, '', '', ''),
		('', '450', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 4, NULL, NULL, '''451z'',''451x'',''451y'',''451v''', 0, 0, '', '', ''),
		('', '451', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'c', 'Classification element--Ending number of span', 'Classification element--Ending number of span', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'h', 'Caption hierarchy', 'Caption hierarchy', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'j', 'Caption', 'Caption', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'k', 'Summary number span caption hierarchy', 'Summary number span caption hierarchy', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 't', 'Topic', 'Topic', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'z', 'Table identification', 'Table identification', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 4, NULL, NULL, '''455v'',''455x'',''455z'',''455y''', 0, 0, '', '', ''),
		('', '455', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'a', 'Personenname', 'Personenname', 0, 0, 5, NULL, NULL, '''500b'',''500c'',''500q'',''500d'',''500t'',''500o'',''500m'',''500r'',''500s'',''500k'',''500n'',''500p'',''500g'',''500l'',''500f'',''500h'',''500x'',''500z'',''500y'',''500v''', 0, 0, '', '', ''),
		('', '500', 'b', 'Zählung', 'Zählung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''510b'',''510c'',''510d'',''510t'',''510o'',''510m'',''510r'',''510s'',''510k'',''510n'',''510p'',''510g'',''510l'',''510f'',''510h'',''510x'',''510z'',''510y'',''510v''', 0, 0, '', '', ''),
		('', '510', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''511e'',''511c'',''511d'',''511t'',''511s'',''511k'',''511n'',''511p'',''511g'',''511l'',''511f'',''511h'',''511x'',''511z'',''511y'',''511v''', 0, 0, '', '', ''),
		('', '511', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 5, NULL, NULL, '''530o'',''530m'',''530r'',''530s'',''530d'',''530k'',''530n'',''530p'',''530g'',''530l'',''530f'',''530h'',''530t'',''530x'',''530z'',''530y'',''530v''', 0, 0, '', '', ''),
		('', '530', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 5, NULL, NULL, '''548y'',''548x'',''548z'',''548v''', 0, 0, '', '', ''),
		('', '548', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 5, NULL, NULL, '''550x'',''550z'',''550y'',''550v''', 0, 0, '', '', ''),
		('', '550', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 5, NULL, NULL, '''551z'',''551x'',''551y'',''551v''', 0, 0, '', '', ''),
		('', '551', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'h', 'Caption hierarchy', 'Caption hierarchy', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'j', 'Caption', 'Caption', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'k', 'Summary number span caption hierarchy', 'Summary number span caption hierarchy', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 't', 'Topic', 'Topic', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'z', 'Table identification', 'Table identification', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 5, NULL, NULL, '''555v'',''555x'',''555z'',''555y''', 0, 0, '', '', ''),
		('', '555', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '640', 'a', 'Erscheinungsjahr und/oder Erscheinungsverlauf', 'Erscheinungsjahr und/oder Erscheinungsverlauf', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '640', 'z', 'Quelle der Information', 'Quelle der Information', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '640', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '640', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '641', 'a', 'Fußnote zu Besonderheiten der Zählung', 'Fußnote zu Besonderheiten der Zählung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '641', 'z', 'Quelle der Information', 'Quelle der Information', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '641', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '641', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '642', 'a', 'Beispiel für die Zählung von Gesamttiteln', 'Beispiel für die Zählung von Gesamttiteln', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '642', 'd', 'Band-/Datumsangaben, auf die sich das Beispiel für die Zählung von Gesamttiteln bezieht', 'Band-/Datumsangaben, auf die sich das Beispiel für die Zählung von Gesamttiteln bezieht', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '642', '5', 'Institution/Kopie, auf die sich das Feld bezieht', 'Institution/Kopie, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '642', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '642', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '643', 'a', 'Ort', 'Ort', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '643', 'b', 'Herausgebende Körperschaft', 'Herausgebende Körperschaft', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '643', 'd', 'Band-/Datumsangaben, auf die sich Ort und herausgebende Körperschaft bezieht', 'Band-/Datumsangaben, auf die sich Ort und herausgebende Körperschaft bezieht', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '643', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '643', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '644', 'a', 'Analyse-Praxis von Gesamttiteln', 'Analyse-Praxis von Gesamttiteln', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '644', 'b', 'Ausnahmen von der Analyse-Praxis', 'Ausnahmen von der Analyse-Praxis', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '644', 'd', 'Band-/Datumsangaben auf die sich die Analyse-Praxis beziehen', 'Band-/Datumsangaben auf die sich die Analyse-Praxis beziehen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '644', '5', 'Institution/Kopie, auf die sich das Feld bezieht', 'Institution/Kopie, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '644', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '644', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '645', 'a', 'Verweisungspraxis von Gesamttiteln', 'Verweisungspraxis von Gesamttiteln', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '645', 'd', 'Band-/Datumsangaben, auf die sich die Verweisungs-Praxis beziehen', 'Band-/Datumsangaben, auf die sich die Verweisungs-Praxis beziehen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '645', '5', 'Institution/Kopie, auf die sich das Feld bezieht', 'Institution/Kopie, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '645', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '645', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '646', 'a', 'Klassifizierungspraxis von Gesamttiteln', 'Klassifizierungspraxis von Gesamttiteln', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '646', 'd', 'Band-/Datumsangaben, auf die sich die Klassifizierungspraxis beziehen', 'Band-/Datumsangaben, auf die sich die Klassifizierungspraxis beziehen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '646', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '646', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '646', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '663', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '663', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '663', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '663', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '663', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '664', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '664', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '664', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '664', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '664', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '665', 'a', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '665', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '665', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '666', 'a', 'Allgemeine Hinweiserläuterung', 'Allgemeine Hinweiserläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '666', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '666', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '667', 'a', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '667', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '667', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '667', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '668', 'a', 'Characters in nonroman alphabet', 'Characters in nonroman alphabet', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '670', 'a', 'Quellenangabe', 'Quellenangabe', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '670', 'b', 'Vorhandene Informationen', 'Vorhandene Informationen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '670', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '670', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '670', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '671', 'a', 'Citation', 'Citation', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '671', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '675', 'a', 'Quellenangabe', 'Quellenangabe', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '675', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '675', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '676', 'a', 'Rule number(s) and additional information', 'Rule number(s) and additional information', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '676', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '678', 'a', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '678', 'b', 'Erweiterung', 'Erweiterung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '678', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '678', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '678', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', 'a', 'Ansetzung oder Unterteilung', 'Ansetzung oder Unterteilung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', 'c', 'Classification number--Ending number of span [CLASSIFICATION FORMAT]', 'Classification number--Ending number of span [CLASSIFICATION FORMAT]', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '681', 'a', 'Schlagwort- oder Unterteilungsansetzung', 'Schlagwort- oder Unterteilungsansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '681', 'c', 'Classification number--Ending number of span [CLASSIFICATION FORMAT]', 'Classification number--Ending number of span [CLASSIFICATION FORMAT]', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '681', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '681', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '681', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '681', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '682', 'a', 'Zu ersetzende Ansetzung', 'Zu ersetzende Ansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '682', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '682', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '682', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', 'p', 'Corresponding classification field', 'Corresponding classification field', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', 'j', 'Caption', 'Caption', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '685', 'a', 'Source consulted and information found', 'Source consulted and information found', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '685', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '686', 'a', 'Source consulted and information found', 'Source consulted and information found', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '686', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '687', 'a', 'Source consulted and information found', 'Source consulted and information found', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '687', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '688', 'a', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '688', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '688', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '688', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'a', 'Personenname', 'Personenname', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'b', 'Zählung', 'Zählung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'h', 'Medium', 'Medium', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'r', 'Tonart', 'Tonart', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 's', 'Version', 'Version', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '3', 'Spezifische Materialangaben [CLASSIFICATION FORMAT]', 'Spezifische Materialangaben [CLASSIFICATION FORMAT]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '4', 'Relator code', 'Relator code', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'h', 'Medium', 'Medium', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'r', 'Tonart', 'Tonart', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 's', 'Version', 'Version', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '3', 'Spezifische Materialangaben [CLASSIFICATION FORMAT]', 'Spezifische Materialangaben [CLASSIFICATION FORMAT]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '4', 'Relator code', 'Relator code', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'h', 'Medium', 'Medium', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 's', 'Version', 'Version', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '3', 'Spezifische Materialangaben', 'Spezifische Materialangaben', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '4', 'Relator code', 'Relator code', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'h', 'Medium', 'Medium', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'r', 'Tonart', 'Tonart', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 's', 'Version', 'Version', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', '3', 'Spezifische Materialangaben [CLASSIFICATION FORMAT]', 'Spezifische Materialangaben [CLASSIFICATION FORMAT]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', '3', 'Spezifische Materialangaben [CLASSIFICATION FORMAT]', 'Spezifische Materialangaben [CLASSIFICATION FORMAT]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'b', 'Einem geografischen Namen folgendes Sachschlagwort als Eintragungselement', 'Einem geografischen Namen folgendes Sachschlagwort als Eintragungselement', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'c', 'Location of event', 'Location of event', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'd', 'Active date', 'Active date', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'i', 'Explanatory text [CLASSIFICATION FORMAT]', 'Explanatory text [CLASSIFICATION FORMAT]', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', '3', 'Spezifische Materialangaben [CLASSIFICATION FORMAT]', 'Spezifische Materialangaben [CLASSIFICATION FORMAT]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', '3', 'Spezifische Materialangaben [CLASSIFICATION FORMAT]', 'Spezifische Materialangaben [CLASSIFICATION FORMAT]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'a', 'Index term', 'Index term', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'b', 'Index term--Succeeding level', 'Index term--Succeeding level', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'd', 'Index term referred from', 'Index term referred from', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'e', 'Example class number', 'Example class number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 's', 'See also reference term', 'See also reference term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 't', 'See also reference term--Succeeding level', 'See also reference term--Succeeding level', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'u', 'Use reference term', 'Use reference term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'v', 'Use reference term--Succeeding level', 'Use reference term--Succeeding level', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', 'a', 'Focus term', 'Focus term', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', 'b', 'Non-focus term', 'Non-focus term', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', 'c', 'Facet/hierarchy designation', 'Facet/hierarchy designation', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', '3', 'Material specified', 'Material specified', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', 'a', 'Genre/Formschlagwort als Eintragungselement', 'Genre/Formschlagwort als Eintragungselement', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'a', 'Number where instructions are found--Single number or beginnning number of span', 'Number where instructions are found--Single number or beginnning number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'b', 'Base number', 'Base number', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'd', 'Divided like number', 'Divided like number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'e', 'Example class number', 'Example class number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'f', 'Facet designator', 'Facet designator', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'n', 'Negative example class number', 'Negative example class number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'r', 'Root number', 'Root number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'x', 'Andere Notation', 'Andere Notation', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'z', 'Table identification', 'Table identification', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '762', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '762', 'z', 'Table number', 'Table number', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '762', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '762', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'b', 'Base number', 'Base number', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'd', 'Divided like number', 'Divided like number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'e', 'Example class number', 'Example class number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'h', 'Caption hierarchy', 'Caption hierarchy', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'j', 'Caption', 'Caption', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'k', 'Summary number span caption hierarchy', 'Summary number span caption hierarchy', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'm', 'Manual note', 'Manual note', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'n', 'Number where instructions are found', 'Number where instructions are found', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'p', 'Corresponding classification field', 'Corresponding classification field', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'r', 'Root number', 'Root number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 's', 'See reference', 'See reference', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'x', 'Andere Notation', 'Andere Notation', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'z', 'Table identification', 'Table identification', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '764', 'a', 'Rule number', 'Rule number', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '764', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '764', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '764', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'a', 'Number where instructions are found--Single number or beginning number of span', 'Number where instructions are found--Single number or beginning number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'b', 'Base number', 'Base number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'c', 'Number where instructions are found--Ending number of span', 'Number where instructions are found--Ending number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'f', 'Facet designator', 'Facet designator', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'r', 'Root number', 'Root number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 's', 'Digits added from classification number in schedule or external table', 'Digits added from classification number in schedule or external table', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 't', 'Digits added from internal subarrangement or add table', 'Digits added from internal subarrangement or add table', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'u', 'Number being analyzed', 'Number being analyzed', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'v', 'Number in internal subarrangement or add table where instructions are found', 'Number in internal subarrangement or add table where instructions are found', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'w', 'Table identification--Internal subarrangement or add table', 'Table identification--Internal subarrangement or add table', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'z', 'Table identification', 'Table identification', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '766', 'a', 'Secondary table of applicability', 'Secondary table of applicability', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '766', 'y', 'Type of division', 'Type of division', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '766', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '766', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'e', 'Example class number', 'Example class number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'j', 'Caption', 'Caption', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'n', 'Negative example class number', 'Negative example class number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 't', 'Topic used as example of citation and preference order instruction', 'Topic used as example of citation and preference order instruction', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'x', 'Exception to table of preference', 'Exception to table of preference', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'a', 'Host-Name', 'Host-Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'b', 'Zugriffsnummer', 'Zugriffsnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'c', 'Angaben zur Komprimierung', 'Angaben zur Komprimierung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'd', 'Pfad', 'Pfad', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'f', 'Elektronischer Name', 'Elektronischer Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'h', 'Bearbeiter der Anfrage', 'Bearbeiter der Anfrage', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'i', 'Anweisung', 'Anweisung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'j', 'Bits pro Sekunde', 'Bits pro Sekunde', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'k', 'Passwort', 'Passwort', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'l', 'Login', 'Login', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'm', 'Kontaktstelle für Hilfe beim Zugriff', 'Kontaktstelle für Hilfe beim Zugriff', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'n', 'Name des Standortes des Hosts', 'Name des Standortes des Hosts', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'o', 'Betriebssystem', 'Betriebssystem', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'p', 'Port', 'Port', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'q', 'Elektronisches Format', 'Elektronisches Format', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'r', 'Einstellungen', 'Einstellungen', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 's', 'Dateigröße', 'Dateigröße', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 't', 'Terminalemulation', 'Terminalemulation', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'v', 'Zugriffszeiten', 'Zugriffszeiten', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'w', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'x', 'Interne Anmerkungen', 'Interne Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'y', 'Verlinkungstext', 'Verlinkungstext', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'z', 'Allgemeine Anmerkungen', 'Allgemeine Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', '2', 'Zugriffsart', 'Zugriffsart', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', '3', 'Spezifische Materialangaben', 'Spezifische Materialangaben', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'a', 'a', 'a', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'b', 'b', 'b', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'c', 'c', 'c', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'd', 'd', 'd', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'e', 'e', 'e', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'f', 'f', 'f', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'g', 'g', 'g', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'h', 'h', 'h', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'i', 'i', 'i', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'j', 'j', 'j', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'k', 'k', 'k', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'l', 'l', 'l', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'm', 'm', 'm', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'n', 'n', 'n', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'o', 'o', 'o', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'p', 'p', 'p', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'q', 'q', 'q', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'r', 'r', 'r', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 's', 's', 's', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 't', 't', 't', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'u', 'u', 'u', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'v', 'v', 'v', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'w', 'w', 'w', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'x', 'x', 'x', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'y', 'y', 'y', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'z', 'z', 'z', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '0', '0', '0', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '1', '1', '1', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '2', '2', '2', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '3', '3', '3', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '4', '4', '4', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '5', '5', '5', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '6', '6', '6', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '7', '7', '7', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '8', '8', '8', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '9', '9', '9', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '942', 'a', 'Koha-Normsatztyp', 'Koha-Normsatztyp', 0, 1, 9, NULL, NULL, NULL, 0, 8, '', 'auth_header.authtypecode', '');


-- ******************************************************



-- *******************************************************************
-- PERSONAL NAME AUTHORITY FIELDS/SUBFIELDS.
-- *******************************************************************

-- These ought to be adjusted for different less conflicting and more
-- rationally chosen fields and subfields but I had left that for last.

-- ADJUST ME
-- Use values from your dump of auth_tag_structure and auth_subfield_structure
-- to provide support for your Koha database.


INSERT INTO `auth_tag_structure` (`authtypecode`, `tagfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `authorised_value`) VALUES
		('PERSO_NAME', '000', 'Leader', 'Leader', 0, 1, NULL),
		('PERSO_NAME', '001', 'Kontrollnummer', 'Kontrollnummer', 0, 1, NULL),
		('PERSO_NAME', '003', 'Kontrollnummer-Identifier', 'Kontrollnummer-Identifier', 0, 1, NULL),
		('PERSO_NAME', '005', 'Datum und Zeit der letzten Transaktion', 'Datum und Zeit der letzten Transaktion', 0, 1, NULL),
		('PERSO_NAME', '008', 'Datenelemente mit fester Länge', 'Datenelemente mit fester Länge', 0, 1, NULL),
		('PERSO_NAME', '010', 'Kontrollnummer der Library of Congress', 'Kontrollnummer der Library of Congress', 0, 0, NULL),
		('PERSO_NAME', '014', 'Verknüpfung zum bibliographischen Datensatz für Gesamttitel oder mehrteilige Exemplare', 'Verknüpfung zum bibliographischen Datensatz für Gesamttitel oder mehrteilige Exemplare', 1, 0, NULL),
		('PERSO_NAME', '016', 'Kontrollnummer der nationalen bibliografischen Stelle', 'Kontrollnummer der nationalen bibliografischen Stelle', 1, 0, NULL),
		('PERSO_NAME', '020', 'Internationale Standardbuchnummer', 'Internationale Standardbuchnummer', 1, 0, NULL),
		('PERSO_NAME', '022', 'Internationale Standardseriennummer', 'Internationale Standardseriennummer', 1, 0, NULL),
		('PERSO_NAME', '024', 'Anderer Standard-Identifier', 'Anderer Standard-Identifier', 1, 0, NULL),
		('PERSO_NAME', '031', 'Informationen zum Musik-Incipit', 'Informationen zum Musik-Incipit', 1, 0, NULL),
		('PERSO_NAME', '035', 'System-Kontrollnummer', 'System-Kontrollnummer', 1, 0, NULL),
		('PERSO_NAME', '040', 'Katalogisierungsquelle', 'Katalogisierungsquelle', 0, 1, NULL),
		('PERSO_NAME', '042', 'Authentifizierungscode', 'Authentifizierungscode', 0, 0, NULL),
		('PERSO_NAME', '043', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 0, 0, NULL),
		('PERSO_NAME', '045', 'Zeitabschnitt der Ansetzung', 'Zeitabschnitt der Ansetzung', 0, 0, NULL),
		('PERSO_NAME', '050', 'Signatur der Library of Congress', 'Signatur der Library of Congress', 1, 0, NULL),
		('PERSO_NAME', '052', 'Geografische Klassifikation', 'Geografische Klassifikation', 1, 0, NULL),
		('PERSO_NAME', '053', 'Notation der LC', 'Notation der LC', 1, 0, NULL),
		('PERSO_NAME', '055', 'Signatur der Library and Archives Canada', 'Signatur der Library and Archives Canada', 1, 0, NULL),
		('PERSO_NAME', '060', 'Signatur der National Library of Medicine', 'Signatur der National Library of Medicine', 1, 0, NULL),
		('PERSO_NAME', '065', 'Andere Notation', 'Andere Notation', 1, 0, NULL),
		('PERSO_NAME', '066', 'Angewendete Zeichensätze', 'Angewendete Zeichensätze', 0, 0, NULL),
		('PERSO_NAME', '070', 'Signatur der National Agricultural Library', 'Signatur der National Agricultural Library', 1, 0, NULL),
		('PERSO_NAME', '072', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 1, 0, NULL),
		('PERSO_NAME', '073', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 0, 0, NULL),
		('PERSO_NAME', '082', 'Dewey-Dezimal-Signatur', 'Dewey-Dezimal-Signatur', 1, 0, NULL),
		('PERSO_NAME', '083', 'DDC-Notation', 'DDC-Notation', 1, 0, NULL),
		('PERSO_NAME', '086', 'Signatur für Amtsdruckschriften', 'Signatur für Amtsdruckschriften', 1, 0, NULL),
		('PERSO_NAME', '087', 'Notation fürs Amtsdruckschriften', 'Notation fürs Amtsdruckschriften', 1, 0, NULL),
		('PERSO_NAME', '090', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (RLIN)', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (OCLC)', 1, 0, NULL),
		('PERSO_NAME', '091', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 0, 0, NULL),
		('PERSO_NAME', '092', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 1, 0, NULL),
		('PERSO_NAME', '093', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('PERSO_NAME', '096', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 1, 0, NULL),
		('PERSO_NAME', '097', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('PERSO_NAME', '098', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 1, 0, NULL),
		('PERSO_NAME', '099', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 1, 0, NULL),
		('PERSO_NAME', '100', 'Ansetzung - Personenname', 'Ansetzung - Personenname', 0, 0, NULL),
		('PERSO_NAME', '260', 'Komplexer Siehe-Hinweis - Schlagwort', 'Komplexer Siehe-Hinweis - Schlagwort', 1, 0, NULL),
		('PERSO_NAME', '360', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 1, 0, NULL),
		('PERSO_NAME', '400', 'Siehe-Verweisung - Personenname', 'Siehe-Verweisung - Personenname', 1, 0, NULL),
		('PERSO_NAME', '410', 'Siehe-Verweisung - Körperschaftsname', 'Siehe-Verweisung - Körperschaftsname', 1, 0, NULL),
		('PERSO_NAME', '411', 'Siehe-Verweisung - Kongressname', 'Siehe-Verweisung - Kongressname', 1, 0, NULL),
		('PERSO_NAME', '430', 'Siehe-Verweisung - Einheitstitel', 'Siehe-Verweisung - Einheitstitel', 1, 0, NULL),
		('PERSO_NAME', '448', 'Siehe-Verweisung - Zeitschlagwort', 'Siehe-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('PERSO_NAME', '450', 'Siehe-Verweisung - Sachschlagwort', 'Siehe-Verweisung - Sachschlagwort', 1, 0, NULL),
		('PERSO_NAME', '451', 'Siehe-Verweisung - Geografischer Name', 'Siehe-Verweisung - Geografischer Name', 1, 0, NULL),
		('PERSO_NAME', '455', 'Siehe-Verweisung - Genre/Formschlagwort', 'Siehe-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('PERSO_NAME', '480', 'Siehe-Verweisung - Allgemeine Unterteilung', 'Siehe-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('PERSO_NAME', '481', 'Siehe-Verweisung - Geografische Unterteilung', 'Siehe-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('PERSO_NAME', '482', 'Siehe-Verweisung - Chronologische Unterteilung', 'Siehe-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('PERSO_NAME', '485', 'Siehe-Verweisung - Unterteilung nach Form', 'Siehe-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('PERSO_NAME', '500', 'Siehe-auch-Verweisung - Personenname', 'Siehe-auch-Verweisung - Personenname', 1, 0, NULL),
		('PERSO_NAME', '510', 'Siehe-auch-Verweisung - Körperschaftsname', 'Siehe-auch-Verweisung - Körperschaftsname', 1, 0, NULL),
		('PERSO_NAME', '511', 'Siehe-auch-Verweisung - Kongressname', 'Siehe-auch-Verweisung - Kongressname', 1, 0, NULL),
		('PERSO_NAME', '530', 'Siehe-auch-Verweisung - Einheitstitel', 'Siehe-auch-Verweisung - Einheitstitel', 1, 0, NULL),
		('PERSO_NAME', '548', 'Siehe-auch-Verweisung - Zeitschlagwort', 'Siehe-auch-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('PERSO_NAME', '550', 'Siehe-auch-Verweisung - Sachschlagwort', 'Siehe-auch-Verweisung - Sachschlagwort', 1, 0, NULL),
		('PERSO_NAME', '551', 'Siehe-auch-Verweisung - Geografischer Name', 'Siehe-auch-Verweisung - Geografischer Name', 1, 0, NULL),
		('PERSO_NAME', '555', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('PERSO_NAME', '580', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('PERSO_NAME', '581', 'Siehe-auch-Verweisung - Geografische Unterteilung', 'Siehe-auch-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('PERSO_NAME', '582', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('PERSO_NAME', '585', 'Siehe-auch-Verweisung - Unterteilung nach Form', 'Siehe-auch-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('PERSO_NAME', '663', 'Komplexe Siehe-auch-Verweisung - Name', 'Komplexe Siehe-auch-Verweisung - Name', 0, 0, NULL),
		('PERSO_NAME', '664', 'Komplexe Siehe-Verweisung - Name', 'Komplexe Siehe-Verweisung - Name', 0, 0, NULL),
		('PERSO_NAME', '665', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 0, 0, NULL),
		('PERSO_NAME', '666', 'Allgemein erläuternde Verweisung - Name', 'Allgemein erläuternde Verweisung - Name', 0, 0, NULL),
		('PERSO_NAME', '667', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 1, 0, NULL),
		('PERSO_NAME', '670', 'Datenquelle', 'Datenquelle', 1, 0, NULL),
		('PERSO_NAME', '675', 'Datenquelle ohne Information', 'Datenquelle ohne Information', 0, 0, NULL),
		('PERSO_NAME', '678', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, NULL),
		('PERSO_NAME', '680', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, NULL),
		('PERSO_NAME', '681', 'Beispiel für die Schlagwortverweisung', 'Beispiel für die Schlagwortverweisung', 1, 0, NULL),
		('PERSO_NAME', '682', 'Angaben zu gelöschten Ansetzungen', 'Angaben zu gelöschten Ansetzungen', 0, 0, NULL),
		('PERSO_NAME', '683', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('PERSO_NAME', '688', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('PERSO_NAME', '700', 'Verknüpfungseintragung für normierte Ansetzungen - Personenname', 'Verknüpfungseintragung für normierte Ansetzungen - Personenname', 1, 0, NULL),
		('PERSO_NAME', '788', 'Komplexe Verknüpfungseintragungsdaten', 'Komplexe Verknüpfungseintragungsdaten', 0, 0, NULL),
		('PERSO_NAME', '856', 'Elektronische Adresse und Zugriff', 'Elektronische Adresse und Zugriff', 1, 0, NULL),
		('PERSO_NAME', '880', 'Andersschriftliche Darstellung', 'Andersschriftliche Darstellung', 1, 0, NULL),
    ('PERSO_NAME', '942', 'Interne Verwendung (KOHA)', 'Interne Verwendung (KOHA)', 0, 1, NULL);


INSERT INTO `auth_subfield_structure` (`authtypecode`, `tagfield`, `tagsubfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `tab`, `authorised_value`, `value_builder`, `seealso`, `isurl`, `hidden`, `linkid`, `kohafield`, `frameworkcode`) VALUES
		('PERSO_NAME', '000', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_leader_authorities.pl', NULL, 0, 0, '', '', ''),
    ('PERSO_NAME', '001', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', 'auth_header.authid', ''),
    ('PERSO_NAME', '003', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
    ('PERSO_NAME', '005', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_005.pl', NULL, 0, 0, '', '', ''),
    ('PERSO_NAME', '008', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_field_008_authorities.pl', NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '010', 'a', 'LoC-Kontrollnummer', 'LoC-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '010', 'z', 'Gelöschte/ungültige LoC-Kontrollnummer', 'Gelöschte/ungültige LoC-Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '010', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '014', 'a', 'Kontrollnummer des verwandten bibliografischen Datensatzes', 'Kontrollnummer des verwandten bibliografischen Datensatzes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '014', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '014', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '016', 'a', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '016', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '016', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '016', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '020', 'a', 'Internationale Standardbuchnummer', 'Internationale Standardbuchnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '020', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '020', 'z', 'Gelöschte/ungültige ISBN', 'Gelöschte/ungültige ISBN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '020', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '020', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '022', 'a', 'Internationale Standardseriennummer', 'Internationale Standardseriennummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '022', 'y', 'Falsche ISSN', 'Falsche ISSN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '022', 'z', 'Gelöschte ISSN', 'Gelöschte ISSN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '022', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '022', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '024', 'a', 'Standardnummer oder Code', 'Standardnummer oder Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '024', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '024', 'd', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '024', 'z', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '024', '2', 'Quelle der Nummer oder des Codes', 'Quelle der Nummer oder des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '024', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '024', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 'a', 'Number of work', 'Number of work', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 'b', 'Satznummer', 'Satznummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 'c', 'Nummer des Ausschnitts', 'Nummer des Ausschnitts', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 'd', 'Titel oder Ansetzung', 'Titel oder Ansetzung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 'e', 'Partie', 'Partie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 'g', 'Notenschlüssel', 'Notenschlüssel', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 'm', 'Stimme/Instrument', 'Stimme/Instrument', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 'n', 'Tonartvorzeichen', 'Tonartvorzeichen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 'o', 'Taktvorzeichen', 'Taktvorzeichen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 'p', 'Musikalische Notierung', 'Musikalische Notierung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 'q', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 'r', 'Tonart oder Modus', 'Tonart oder Modus', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 's', 'Kodierte Fußnote zur Echtheit', 'Kodierte Fußnote zur Echtheit', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 't', 'Text-Incipit', 'Text-Incipit', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', '2', 'Systemcode', 'Systemcode', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '031', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '035', 'a', 'System-Kontrollnummer', 'System-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '035', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '035', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '035', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '040', 'a', 'Original-Katalogisierungsstelle', 'Original-Katalogisierungsstelle', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '040', 'b', 'Katalogisierungssprache', 'Katalogisierungssprache', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '040', 'c', 'Übertragungsstelle', 'Übertragungsstelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '040', 'd', 'Bearbeitungsstelle', 'Bearbeitungsstelle', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '040', 'e', 'Beschreibungsfestlegungen', 'Beschreibungsfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '040', 'f', 'Schlagwort- oder Thesaurusfestlegungen', 'Schlagwort- oder Thesaurusfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '040', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '040', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '042', 'a', 'Authentifizierungscode', 'Authentifizierungscode', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '043', 'a', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '043', 'b', 'Lokaler GAC-Code', 'Lokaler GAC-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '043', 'c', 'ISO-Code', 'ISO-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '043', '2', 'Quelle des lokalen Codes', 'Quelle des lokalen Codes', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '043', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '043', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '045', 'a', 'Zeitabschnitts-Code', 'Zeitabschnitts-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '045', 'b', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '045', 'c', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '045', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '045', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '050', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '050', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '050', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '050', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '050', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '050', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '052', 'a', 'Klassifikation des geografischen Gebiets', 'Klassifikation des geografischen Gebiets', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '052', 'b', 'Klassifikation des geografischen Teilgebiets', 'Klassifikation des geografischen Teilgebiets', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '052', 'd', 'Eingetragener Ortsname', 'Eingetragener Ortsname', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '052', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '052', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '052', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '053', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '053', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '053', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '053', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '053', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '053', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '055', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '055', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '055', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '055', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '055', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '055', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '060', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '060', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '060', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '060', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '060', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '060', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '065', 'a', 'Classification number element--single number or beginning of span', 'Classification number element--single number or beginning of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '065', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '065', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '065', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '065', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '065', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '065', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '066', 'a', 'Primärer G0-Zeichensatz', 'Primärer G0-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '066', 'b', 'Primärer G1-Zeichensatz', 'Primärer G1-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '066', 'c', 'Wechselnder G0- oder G1-Zeichensatz', 'Wechselnder G0- oder G1-Zeichensatz', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '070', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '070', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '070', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '070', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '070', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '072', 'a', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '072', 'x', 'Subject category code subdivision', 'Subject category code subdivision', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '072', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '072', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '072', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '073', 'a', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '073', 'z', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '073', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '073', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '082', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '082', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '082', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '082', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '082', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '082', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '082', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '083', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '083', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '083', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '083', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '083', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '083', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '083', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '083', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '086', 'a', 'Signatur', 'Signatur', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '086', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '086', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '086', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '086', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '086', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '086', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '087', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '087', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '087', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '087', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '087', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '087', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 'a', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 'b', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 'e', 'Feature heading (OCLC)', 'Feature heading (OCLC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 'f', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 'h', 'Output transaction history, HST (RLIN)', 'Output transaction history, HST (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 'i', 'Output transaction instruction, INS (RLIN)', 'Output transaction instruction, INS (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 'l', 'Extra card control statement, EXT (RLIN)', 'Extra card control statement, EXT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 'n', 'Additional local notes, ANT (RLIN)', 'Additional local notes, ANT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 'p', 'Pathfinder code, PTH (RLIN)', 'Pathfinder code, PTH (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 't', 'Field suppresion, FSP (RLIN)', 'Field suppresion, FSP (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 'v', 'Volumes, VOL (RLIN)', 'Volumes, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 'y', 'Date, VOL (RLIN)', 'Date, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '090', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '091', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '091', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '091', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '091', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '091', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '091', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '091', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '091', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '092', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '092', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '092', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '092', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '092', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '092', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '092', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '092', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '092', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '093', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '093', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '093', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '093', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '093', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '093', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '093', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '093', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '096', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '096', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '096', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '096', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '096', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '096', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '096', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '096', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '096', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '097', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '097', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '097', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '097', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '097', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '097', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '097', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '097', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '098', 'a', 'Call number based on other classification scheme', 'Call number based on other classification scheme', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '098', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '098', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '098', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '098', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '098', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '098', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '098', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '098', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '099', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '099', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '099', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '099', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '099', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '099', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '099', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '099', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '099', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'a', 'Personenname', 'Personenname', 0, 0, 1, NULL, NULL, '''100b'',''100c'',''100q'',''100d'',''100t'',''100o'',''100m'',''100r'',''100s'',''100k'',''100n'',''100p'',''100g'',''100l'',''100f'',''100h'',''100x'',''100z'',''100y'',''100v''', 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'b', 'Zählung', 'Zählung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'h', 'Medium', 'Medium', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'r', 'Tonart', 'Tonart', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 's', 'Version', 'Version', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '100', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '260', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '260', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '260', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '260', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '360', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '360', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '360', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '360', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'a', 'Personenname', 'Personenname', 0, 0, 4, NULL, NULL, '''400b'',''400c'',''400q'',''400d'',''400t'',''400o'',''400m'',''400r'',''400s'',''400k'',''400n'',''400p'',''400g'',''400l'',''400f'',''400h'',''400x'',''400z'',''400y'',''400v''', 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'b', 'Zählung', 'Zählung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '400', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''410b'',''410c'',''410d'',''410t'',''410o'',''410m'',''410r'',''410s'',''410k'',''410n'',''410p'',''410g'',''410l'',''410f'',''410h'',''410x'',''410z'',''410y'',''410v''', 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '410', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''411e'',''411c'',''411d'',''411t'',''411s'',''411k'',''411n'',''411p'',''411g'',''411l'',''411f'',''411h'',''411x'',''411z'',''411y'',''411v''', 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'b', 'Nummer [OBSOLET]', 'Nummer [OBSOLET]', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '411', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 4, NULL, NULL, '''430o'',''430m'',''430r'',''430s'',''430d'',''430k'',''430n'',''430p'',''430g'',''430l'',''430f'',''430h'',''430t'',''430x'',''430z'',''430y'',''430v''', 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '430', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '448', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 4, NULL, NULL, '''448y'',''448x'',''448z'',''448v''', 0, 0, '', '', ''),
		('PERSO_NAME', '448', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '448', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '448', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '448', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '448', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '448', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '448', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '448', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '448', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '450', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 4, NULL, NULL, '''450x'',''450z'',''450y'',''450v''', 0, 0, '', '', ''),
		('PERSO_NAME', '450', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '450', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '450', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '450', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '450', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '450', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '450', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '450', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '450', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '450', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '451', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 4, NULL, NULL, '''451z'',''451x'',''451y'',''451v''', 0, 0, '', '', ''),
		('PERSO_NAME', '451', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '451', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '451', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '451', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '451', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '451', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '451', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '451', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '451', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '455', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 4, NULL, NULL, '''455v'',''455x'',''455z'',''455y''', 0, 0, '', '', ''),
		('PERSO_NAME', '455', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '455', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '455', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '455', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '455', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '455', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '455', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '455', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '455', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '480', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '480', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '480', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '480', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '480', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '480', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '480', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '480', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '480', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '481', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '481', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '481', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '481', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '481', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '481', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '481', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '481', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '481', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '482', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '482', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '482', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '482', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '482', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '482', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '482', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '482', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '482', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '485', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '485', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '485', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '485', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '485', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '485', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '485', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '485', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '485', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'a', 'Personenname', 'Personenname', 0, 0, 5, NULL, NULL, '''500b'',''500c'',''500q'',''500d'',''500t'',''500o'',''500m'',''500r'',''500s'',''500k'',''500n'',''500p'',''500g'',''500l'',''500f'',''500h'',''500x'',''500z'',''500y'',''500v''', 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'b', 'Zählung', 'Zählung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '500', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''510b'',''510c'',''510d'',''510t'',''510o'',''510m'',''510r'',''510s'',''510k'',''510n'',''510p'',''510g'',''510l'',''510f'',''510h'',''510x'',''510z'',''510y'',''510v''', 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '510', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''511e'',''511c'',''511d'',''511t'',''511s'',''511k'',''511n'',''511p'',''511g'',''511l'',''511f'',''511h'',''511x'',''511z'',''511y'',''511v''', 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '511', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 5, NULL, NULL, '''530o'',''530m'',''530r'',''530s'',''530d'',''530k'',''530n'',''530p'',''530g'',''530l'',''530f'',''530h'',''530t'',''530x'',''530z'',''530y'',''530v''', 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '530', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '548', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 5, NULL, NULL, '''548y'',''548x'',''548z'',''548v''', 0, 0, '', '', ''),
		('PERSO_NAME', '548', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '548', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '548', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '548', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '548', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '548', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '548', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '548', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '548', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '548', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '550', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 5, NULL, NULL, '''550x'',''550z'',''550y'',''550v''', 0, 0, '', '', ''),
		('PERSO_NAME', '550', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '550', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '550', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '550', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '550', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '550', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '550', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '550', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '550', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '550', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '550', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '551', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 5, NULL, NULL, '''551z'',''551x'',''551y'',''551v''', 0, 0, '', '', ''),
		('PERSO_NAME', '551', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '551', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '551', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '551', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '551', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '551', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '551', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '551', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '551', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '551', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '555', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 5, NULL, NULL, '''555v'',''555x'',''555z'',''555y''', 0, 0, '', '', ''),
		('PERSO_NAME', '555', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '555', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '555', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '555', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '555', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '555', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '555', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '555', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '555', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '555', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '580', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '580', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '580', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '580', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '580', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '580', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '580', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '580', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '580', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '580', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '581', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '581', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '581', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '581', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '581', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '581', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '581', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '581', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '581', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '581', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '582', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '582', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '582', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '582', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '582', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '582', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '582', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '582', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '582', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '582', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '585', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '585', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '585', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '585', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '585', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '585', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '585', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '585', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '585', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '585', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '663', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '663', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '663', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '663', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '663', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '664', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '664', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '664', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '664', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '664', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '665', 'a', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '665', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '665', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '666', 'a', 'Allgemeine Hinweiserläuterung', 'Allgemeine Hinweiserläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '666', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '666', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '667', 'a', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '667', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '667', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '667', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '670', 'a', 'Quellenangabe', 'Quellenangabe', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '670', 'b', 'Vorhandene Informationen', 'Vorhandene Informationen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '670', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '670', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '670', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '675', 'a', 'Quellenangabe', 'Quellenangabe', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '675', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '675', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '678', 'a', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '678', 'b', 'Erweiterung', 'Erweiterung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '678', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '678', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '678', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '680', 'a', 'Ansetzung oder Unterteilung', 'Ansetzung oder Unterteilung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '680', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '680', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '680', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '680', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '680', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '681', 'a', 'Schlagwort- oder Unterteilungsansetzung', 'Schlagwort- oder Unterteilungsansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '681', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '681', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '681', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '681', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '682', 'a', 'Zu ersetzende Ansetzung', 'Zu ersetzende Ansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '682', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '682', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '682', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '683', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '683', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '683', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '683', 'p', 'Corresponding classification field', 'Corresponding classification field', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '683', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '683', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '683', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '683', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '683', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '688', 'a', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '688', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '688', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '688', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'a', 'Personenname', 'Personenname', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'b', 'Zählung', 'Zählung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'h', 'Medium', 'Medium', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'k', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'r', 'Tonart', 'Tonart', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 's', 'Version', 'Version', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', '4', 'Relator code', 'Relator code', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '700', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '780', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '780', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '780', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '780', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '780', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '780', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '780', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '780', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '780', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '780', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '788', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '788', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '788', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '788', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '788', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '788', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '788', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'a', 'Host-Name', 'Host-Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'b', 'Zugriffsnummer', 'Zugriffsnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'c', 'Angaben zur Komprimierung', 'Angaben zur Komprimierung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'd', 'Pfad', 'Pfad', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'f', 'Elektronischer Name', 'Elektronischer Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'h', 'Bearbeiter der Anfrage', 'Bearbeiter der Anfrage', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'i', 'Anweisung', 'Anweisung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'j', 'Bits pro Sekunde', 'Bits pro Sekunde', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'k', 'Passwort', 'Passwort', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'l', 'Login', 'Login', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'm', 'Kontaktstelle für Hilfe beim Zugriff', 'Kontaktstelle für Hilfe beim Zugriff', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'n', 'Name des Standortes des Hosts', 'Name des Standortes des Hosts', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'o', 'Betriebssystem', 'Betriebssystem', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'p', 'Port', 'Port', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'q', 'Elektronisches Format', 'Elektronisches Format', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'r', 'Einstellungen', 'Einstellungen', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 's', 'Dateigröße', 'Dateigröße', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 't', 'Terminalemulation', 'Terminalemulation', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'v', 'Zugriffszeiten', 'Zugriffszeiten', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'w', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'x', 'Interne Anmerkungen', 'Interne Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'y', 'Verlinkungstext', 'Verlinkungstext', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', 'z', 'Allgemeine Anmerkungen', 'Allgemeine Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', '2', 'Zugriffsart', 'Zugriffsart', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', '3', 'Spezifische Materialangaben', 'Spezifische Materialangaben', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '856', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'a', 'a', 'a', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'b', 'b', 'b', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'c', 'c', 'c', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'd', 'd', 'd', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'e', 'e', 'e', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'f', 'f', 'f', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'g', 'g', 'g', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'h', 'h', 'h', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'i', 'i', 'i', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'j', 'j', 'j', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'k', 'k', 'k', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'l', 'l', 'l', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'm', 'm', 'm', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'n', 'n', 'n', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'o', 'o', 'o', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'p', 'p', 'p', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'q', 'q', 'q', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'r', 'r', 'r', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 's', 's', 's', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 't', 't', 't', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'u', 'u', 'u', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'v', 'v', 'v', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'w', 'w', 'w', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'x', 'x', 'x', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'y', 'y', 'y', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', 'z', 'z', 'z', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', '0', '0', '0', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', '1', '1', '1', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', '2', '2', '2', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', '3', '3', '3', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', '4', '4', '4', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', '5', '5', '5', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', '6', '6', '6', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', '7', '7', '7', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', '8', '8', '8', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '880', '9', '9', '9', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('PERSO_NAME', '942', 'a', 'Koha-Normdatentyp', 'Koha-Normdatentyp', 0, 1, 9, NULL, NULL, NULL, 0, 8, '', 'auth_header.authtypecode', '');


-- ******************************************************



-- *******************************************************************
-- CORPORATE NAME AUTHORITY FIELDS/SUBFIELDS.
-- *******************************************************************

-- These ought to be adjusted for different less conflicting and more
-- rationally chosen fields and subfields but I had left that for last.

-- ADJUST ME
-- Use values from your dump of auth_tag_structure and auth_subfield_structure
-- to provide support for your Koha database.


INSERT INTO `auth_tag_structure` (`authtypecode`, `tagfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `authorised_value`) VALUES
		('CORPO_NAME', '000', 'Leader', 'Leader', 0, 1, NULL),
		('CORPO_NAME', '001', 'Kontrollnummer', 'Kontrollnummer', 0, 1, NULL),
		('CORPO_NAME', '003', 'Kontrollnummer-Identifier', 'Kontrollnummer-Identifier', 0, 1, NULL),
		('CORPO_NAME', '005', 'Datum und Zeit der letzten Transaktion', 'Datum und Zeit der letzten Transaktion', 0, 1, NULL),
		('CORPO_NAME', '008', 'Datenelemente mit fester Länge', 'Datenelemente mit fester Länge', 0, 1, NULL),
		('CORPO_NAME', '010', 'Kontrollnummer der Library of Congress', 'Kontrollnummer der Library of Congress', 0, 0, NULL),
		('CORPO_NAME', '014', 'Verknüpfung zum bibliographischen Datensatz für Gesamttitel oder mehrteilige Exemplare', 'Verknüpfung zum bibliographischen Datensatz für Gesamttitel oder mehrteilige Exemplare', 1, 0, NULL),
		('CORPO_NAME', '016', 'Kontrollnummer der nationalen bibliografischen Stelle', 'Kontrollnummer der nationalen bibliografischen Stelle', 1, 0, NULL),
		('CORPO_NAME', '020', 'Internationale Standardbuchnummer', 'Internationale Standardbuchnummer', 1, 0, NULL),
		('CORPO_NAME', '022', 'Internationale Standardseriennummer', 'Internationale Standardseriennummer', 1, 0, NULL),
		('CORPO_NAME', '024', 'Anderer Standard-Identifier', 'Anderer Standard-Identifier', 1, 0, NULL),
		('CORPO_NAME', '031', 'Informationen zum Musik-Incipit', 'Informationen zum Musik-Incipit', 1, 0, NULL),
		('CORPO_NAME', '035', 'System-Kontrollnummer', 'System-Kontrollnummer', 1, 0, NULL),
		('CORPO_NAME', '040', 'Katalogisierungsquelle', 'Katalogisierungsquelle', 0, 1, NULL),
		('CORPO_NAME', '042', 'Authentifizierungscode', 'Authentifizierungscode', 0, 0, NULL),
		('CORPO_NAME', '043', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 0, 0, NULL),
		('CORPO_NAME', '045', 'Zeitabschnitt der Ansetzung', 'Zeitabschnitt der Ansetzung', 0, 0, NULL),
		('CORPO_NAME', '050', 'Signatur der Library of Congress', 'Signatur der Library of Congress', 1, 0, NULL),
		('CORPO_NAME', '052', 'Geografische Klassifikation', 'Geografische Klassifikation', 1, 0, NULL),
		('CORPO_NAME', '053', 'Notation der LC', 'Notation der LC', 1, 0, NULL),
		('CORPO_NAME', '055', 'Signatur der Library and Archives Canada', 'Signatur der Library and Archives Canada', 1, 0, NULL),
		('CORPO_NAME', '060', 'Signatur der National Library of Medicine', 'Signatur der National Library of Medicine', 1, 0, NULL),
		('CORPO_NAME', '065', 'Andere Notation', 'Andere Notation', 1, 0, NULL),
		('CORPO_NAME', '066', 'Angewendete Zeichensätze', 'Angewendete Zeichensätze', 0, 0, NULL),
		('CORPO_NAME', '070', 'Signatur der National Agricultural Library', 'Signatur der National Agricultural Library', 1, 0, NULL),
		('CORPO_NAME', '072', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 1, 0, NULL),
		('CORPO_NAME', '073', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 0, 0, NULL),
		('CORPO_NAME', '082', 'Dewey-Dezimal-Signatur', 'Dewey-Dezimal-Signatur', 1, 0, NULL),
		('CORPO_NAME', '083', 'DDC-Notation', 'DDC-Notation', 1, 0, NULL),
		('CORPO_NAME', '086', 'Signatur für Amtsdruckschriften', 'Signatur für Amtsdruckschriften', 1, 0, NULL),
		('CORPO_NAME', '087', 'Notation fürs Amtsdruckschriften', 'Notation fürs Amtsdruckschriften', 1, 0, NULL),
		('CORPO_NAME', '090', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (RLIN)', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (OCLC)', 1, 0, NULL),
		('CORPO_NAME', '091', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 0, 0, NULL),
		('CORPO_NAME', '092', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 1, 0, NULL),
		('CORPO_NAME', '093', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('CORPO_NAME', '096', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 1, 0, NULL),
		('CORPO_NAME', '097', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('CORPO_NAME', '098', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 1, 0, NULL),
		('CORPO_NAME', '099', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 1, 0, NULL),
		('CORPO_NAME', '110', 'HEADING--CORPORATE NAME', 'HEADING--CORPORATE NAME', 0, 0, NULL),
		('CORPO_NAME', '260', 'Komplexer Siehe-Hinweis - Schlagwort', 'Komplexer Siehe-Hinweis - Schlagwort', 1, 0, NULL),
		('CORPO_NAME', '360', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 1, 0, NULL),
		('CORPO_NAME', '400', 'Siehe-Verweisung - Personenname', 'Siehe-Verweisung - Personenname', 1, 0, NULL),
		('CORPO_NAME', '410', 'Siehe-Verweisung - Körperschaftsname', 'Siehe-Verweisung - Körperschaftsname', 1, 0, NULL),
		('CORPO_NAME', '411', 'Siehe-Verweisung - Kongressname', 'Siehe-Verweisung - Kongressname', 1, 0, NULL),
		('CORPO_NAME', '430', 'Siehe-Verweisung - Einheitstitel', 'Siehe-Verweisung - Einheitstitel', 1, 0, NULL),
		('CORPO_NAME', '448', 'Siehe-Verweisung - Zeitschlagwort', 'Siehe-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('CORPO_NAME', '450', 'Siehe-Verweisung - Sachschlagwort', 'Siehe-Verweisung - Sachschlagwort', 1, 0, NULL),
		('CORPO_NAME', '451', 'Siehe-Verweisung - Geografischer Name', 'Siehe-Verweisung - Geografischer Name', 1, 0, NULL),
		('CORPO_NAME', '455', 'Siehe-Verweisung - Genre/Formschlagwort', 'Siehe-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('CORPO_NAME', '480', 'Siehe-Verweisung - Allgemeine Unterteilung', 'Siehe-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('CORPO_NAME', '481', 'Siehe-Verweisung - Geografische Unterteilung', 'Siehe-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('CORPO_NAME', '482', 'Siehe-Verweisung - Chronologische Unterteilung', 'Siehe-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('CORPO_NAME', '485', 'Siehe-Verweisung - Unterteilung nach Form', 'Siehe-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('CORPO_NAME', '500', 'Siehe-auch-Verweisung - Personenname', 'Siehe-auch-Verweisung - Personenname', 1, 0, NULL),
		('CORPO_NAME', '510', 'Siehe-auch-Verweisung - Körperschaftsname', 'Siehe-auch-Verweisung - Körperschaftsname', 1, 0, NULL),
		('CORPO_NAME', '511', 'Siehe-auch-Verweisung - Kongressname', 'Siehe-auch-Verweisung - Kongressname', 1, 0, NULL),
		('CORPO_NAME', '530', 'Siehe-auch-Verweisung - Einheitstitel', 'Siehe-auch-Verweisung - Einheitstitel', 1, 0, NULL),
		('CORPO_NAME', '548', 'Siehe-auch-Verweisung - Zeitschlagwort', 'Siehe-auch-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('CORPO_NAME', '550', 'Siehe-auch-Verweisung - Sachschlagwort', 'Siehe-auch-Verweisung - Sachschlagwort', 1, 0, NULL),
		('CORPO_NAME', '551', 'Siehe-auch-Verweisung - Geografischer Name', 'Siehe-auch-Verweisung - Geografischer Name', 1, 0, NULL),
		('CORPO_NAME', '555', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('CORPO_NAME', '580', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('CORPO_NAME', '581', 'Siehe-auch-Verweisung - Geografische Unterteilung', 'Siehe-auch-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('CORPO_NAME', '582', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('CORPO_NAME', '585', 'Siehe-auch-Verweisung - Unterteilung nach Form', 'Siehe-auch-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('CORPO_NAME', '663', 'Komplexe Siehe-auch-Verweisung - Name', 'Komplexe Siehe-auch-Verweisung - Name', 0, 0, NULL),
		('CORPO_NAME', '664', 'Komplexe Siehe-Verweisung - Name', 'Komplexe Siehe-Verweisung - Name', 0, 0, NULL),
		('CORPO_NAME', '665', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 0, 0, NULL),
		('CORPO_NAME', '666', 'Allgemein erläuternde Verweisung - Name', 'Allgemein erläuternde Verweisung - Name', 0, 0, NULL),
		('CORPO_NAME', '667', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 1, 0, NULL),
		('CORPO_NAME', '670', 'Datenquelle', 'Datenquelle', 1, 0, NULL),
		('CORPO_NAME', '675', 'Datenquelle ohne Information', 'Datenquelle ohne Information', 0, 0, NULL),
		('CORPO_NAME', '678', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, NULL),
		('CORPO_NAME', '680', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, NULL),
		('CORPO_NAME', '681', 'Beispiel für die Schlagwortverweisung', 'Beispiel für die Schlagwortverweisung', 1, 0, NULL),
		('CORPO_NAME', '682', 'Angaben zu gelöschten Ansetzungen', 'Angaben zu gelöschten Ansetzungen', 0, 0, NULL),
		('CORPO_NAME', '683', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('CORPO_NAME', '688', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('CORPO_NAME', '700', 'Verknüpfungseintragung für normierte Ansetzungen - Personenname', 'Verknüpfungseintragung für normierte Ansetzungen - Personenname', 1, 0, NULL),
		('CORPO_NAME', '710', 'Verknüpfungseintragung für normierte Ansetzungen - Körperschaftsname', 'Verknüpfungseintragung für normierte Ansetzungen - Körperschaftsname', 1, 0, NULL),
		('CORPO_NAME', '711', 'Verknüpfungseintragung für normierte Ansetzungen - Kongressname', 'Verknüpfungseintragung für normierte Ansetzungen - Kongressname', 1, 0, NULL),
		('CORPO_NAME', '730', 'Verknüpfungseintragung für normierte Ansetzungen - Einheitstitel', 'Verknüpfungseintragung für normierte Ansetzungen - Einheitstitel', 1, 0, NULL),
		('CORPO_NAME', '748', 'Verknüpfungseintragung für normierte Ansetzungen - Zeitschlagwort', 'Verknüpfungseintragung für normierte Ansetzungen - Zeitschlagwort', 1, 0, NULL),
		('CORPO_NAME', '750', 'Verknüpfungselement für normierte Ansetzungen - Sachschlagwort', 'Verknüpfungselement für normierte Ansetzungen - Sachschlagwort', 1, 0, NULL),
		('CORPO_NAME', '751', 'Verknüpfungseintragungen für normierte Ansetzungen - Geografischer Name', 'Verknüpfungseintragungen für normierte Ansetzungen - Geografischer Name', 1, 0, NULL),
		('CORPO_NAME', '755', 'Verknüpfungseintragung für normierte Ansetzungen - Genre/Formschlagwort', 'Verknüpfungseintragung für normierte Ansetzungen - Genre/Formschlagwort', 1, 0, NULL),
		('CORPO_NAME', '780', 'Verknüpfungseintragung der Unterteilung - Allgemeine Unterteilung', 'Verknüpfungseintragung der Unterteilung - Allgemeine Unterteilung', 1, 0, NULL),
		('CORPO_NAME', '781', 'Verknüpfungseintragung der Unterteilung - Geografische Unterteilung', 'Verknüpfungseintragung der Unterteilung - Geografische Unterteilung', 1, 0, NULL),
		('CORPO_NAME', '782', 'Verknüpfungseintragung der Unterteilung - Chronologische Unterteilung', 'Verknüpfungseintragung der Unterteilung - Chronologische Unterteilung', 1, 0, NULL),
		('CORPO_NAME', '785', 'Verknüpfungseintragung der Unterteilung - Unterteilung nach Form', 'Verknüpfungseintragung der Unterteilung - Unterteilung nach Form', 1, 0, NULL),
		('CORPO_NAME', '788', 'Komplexe Verknüpfungseintragungsdaten', 'Komplexe Verknüpfungseintragungsdaten', 0, 0, NULL),
		('CORPO_NAME', '856', 'Elektronische Adresse und Zugriff', 'Elektronische Adresse und Zugriff', 1, 0, NULL),
		('CORPO_NAME', '880', 'Andersschriftliche Darstellung', 'Andersschriftliche Darstellung', 1, 0, NULL),
        ('CORPO_NAME', '942', 'Interne Verwendung (KOHA)', 'Interne Verwendung (KOHA)', 0, 1, NULL);


INSERT INTO `auth_subfield_structure` (`authtypecode`, `tagfield`, `tagsubfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `tab`, `authorised_value`, `value_builder`, `seealso`, `isurl`, `hidden`, `linkid`, `kohafield`, `frameworkcode`) VALUES
		('CORPO_NAME', '000', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_leader_authorities.pl', NULL, 0, 0, '', '', ''),
                ('CORPO_NAME', '001', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', 'auth_header.authid', ''),
                ('CORPO_NAME', '003', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
                ('CORPO_NAME', '005', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_005.pl', NULL, 0, 0, '', '', ''),
                ('CORPO_NAME', '008', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_field_008_authorities.pl', NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '010', 'a', 'LoC-Kontrollnummer', 'LoC-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '010', 'z', 'Gelöschte/ungültige LoC-Kontrollnummer', 'Gelöschte/ungültige LoC-Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '010', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '014', 'a', 'Kontrollnummer des verwandten bibliografischen Datensatzes', 'Kontrollnummer des verwandten bibliografischen Datensatzes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '014', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '014', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '016', 'a', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '016', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '016', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '016', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '020', 'a', 'Internationale Standardbuchnummer', 'Internationale Standardbuchnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '020', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '020', 'z', 'Gelöschte/ungültige ISBN', 'Gelöschte/ungültige ISBN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '020', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '020', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '022', 'a', 'Internationale Standardseriennummer', 'Internationale Standardseriennummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '022', 'y', 'Falsche ISSN', 'Falsche ISSN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '022', 'z', 'Gelöschte ISSN', 'Gelöschte ISSN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '022', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '022', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '024', 'a', 'Standardnummer oder Code', 'Standardnummer oder Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '024', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '024', 'd', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '024', 'z', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '024', '2', 'Quelle der Nummer oder des Codes', 'Quelle der Nummer oder des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '024', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '024', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 'a', 'Number of work', 'Number of work', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 'b', 'Satznummer', 'Satznummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 'c', 'Nummer des Ausschnitts', 'Nummer des Ausschnitts', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 'd', 'Titel oder Ansetzung', 'Titel oder Ansetzung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 'e', 'Partie', 'Partie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 'g', 'Notenschlüssel', 'Notenschlüssel', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 'm', 'Stimme/Instrument', 'Stimme/Instrument', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 'n', 'Tonartvorzeichen', 'Tonartvorzeichen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 'o', 'Taktvorzeichen', 'Taktvorzeichen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 'p', 'Musikalische Notierung', 'Musikalische Notierung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 'q', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 'r', 'Tonart oder Modus', 'Tonart oder Modus', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 's', 'Kodierte Fußnote zur Echtheit', 'Kodierte Fußnote zur Echtheit', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 't', 'Text-Incipit', 'Text-Incipit', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', '2', 'Systemcode', 'Systemcode', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '031', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '035', 'a', 'System-Kontrollnummer', 'System-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '035', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '035', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '035', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '040', 'a', 'Original-Katalogisierungsstelle', 'Original-Katalogisierungsstelle', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '040', 'b', 'Katalogisierungssprache', 'Katalogisierungssprache', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '040', 'c', 'Übertragungsstelle', 'Übertragungsstelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '040', 'd', 'Bearbeitungsstelle', 'Bearbeitungsstelle', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '040', 'e', 'Beschreibungsfestlegungen', 'Beschreibungsfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '040', 'f', 'Schlagwort- oder Thesaurusfestlegungen', 'Schlagwort- oder Thesaurusfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '040', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '040', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '042', 'a', 'Authentifizierungscode', 'Authentifizierungscode', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '043', 'a', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '043', 'b', 'Lokaler GAC-Code', 'Lokaler GAC-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '043', 'c', 'ISO-Code', 'ISO-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '043', '2', 'Quelle des lokalen Codes', 'Quelle des lokalen Codes', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '043', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '043', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '045', 'a', 'Zeitabschnitts-Code', 'Zeitabschnitts-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '045', 'b', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '045', 'c', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '045', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '045', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '050', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '050', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '050', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '050', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '050', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '050', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '052', 'a', 'Klassifikation des geografischen Gebiets', 'Klassifikation des geografischen Gebiets', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '052', 'b', 'Klassifikation des geografischen Teilgebiets', 'Klassifikation des geografischen Teilgebiets', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '052', 'd', 'Eingetragener Ortsname', 'Eingetragener Ortsname', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '052', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '052', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '052', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '053', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '053', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '053', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '053', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '053', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '053', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '055', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '055', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '055', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '055', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '055', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '055', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '060', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '060', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '060', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '060', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '060', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '060', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '065', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '065', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '065', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '065', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '065', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '065', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '065', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '066', 'a', 'Primärer G0-Zeichensatz', 'Primärer G0-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '066', 'b', 'Primärer G1-Zeichensatz', 'Primärer G1-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '066', 'c', 'Wechselnder G0- oder G1-Zeichensatz', 'Wechselnder G0- oder G1-Zeichensatz', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '070', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '070', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '070', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '070', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '070', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '072', 'a', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '072', 'x', 'Subject category code subdivision', 'Subject category code subdivision', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '072', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '072', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '072', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '073', 'a', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '073', 'z', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '073', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '073', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '082', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '082', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '082', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '082', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '082', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '082', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '082', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '083', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '083', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '083', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '083', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '083', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '083', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '083', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '083', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '086', 'a', 'Signatur', 'Signatur', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '086', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '086', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '086', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '086', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '086', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '086', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '087', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '087', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '087', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '087', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '087', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '087', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 'a', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 'b', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 'e', 'Feature heading (OCLC)', 'Feature heading (OCLC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 'f', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 'h', 'Output transaction history, HST (RLIN)', 'Output transaction history, HST (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 'i', 'Output transaction instruction, INS (RLIN)', 'Output transaction instruction, INS (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 'l', 'Extra card control statement, EXT (RLIN)', 'Extra card control statement, EXT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 'n', 'Additional local notes, ANT (RLIN)', 'Additional local notes, ANT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 'p', 'Pathfinder code, PTH (RLIN)', 'Pathfinder code, PTH (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 't', 'Field suppresion, FSP (RLIN)', 'Field suppresion, FSP (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 'v', 'Volumes, VOL (RLIN)', 'Volumes, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 'y', 'Date, VOL (RLIN)', 'Date, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '090', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '091', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '091', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '091', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '091', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '091', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '091', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '091', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '091', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '092', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '092', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '092', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '092', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '092', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '092', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '092', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '092', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '092', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '093', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '093', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '093', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '093', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '093', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '093', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '093', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '093', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '096', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '096', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '096', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '096', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '096', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '096', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '096', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '096', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '096', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '097', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '097', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '097', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '097', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '097', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '097', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '097', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '097', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '098', 'a', 'Call number based on other classification scheme', 'Call number based on other classification scheme', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '098', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '098', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '098', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '098', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '098', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '098', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '098', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '098', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '099', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '099', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '099', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '099', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '099', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '099', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '099', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '099', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '099', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 1, NULL, NULL, '''110b'',''110c'',''110d'',''110t'',''110o'',''110m'',''110r'',''110s'',''110k'',''110n'',''110p'',''110g'',''110l'',''110f'',''110h'',''110x'',''110z'',''110y'',''110v''', 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'h', 'Medium', 'Medium', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'r', 'Tonart', 'Tonart', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 's', 'Version', 'Version', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '110', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '260', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '260', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '260', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '260', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '360', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '360', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '360', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '360', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'a', 'Personenname', 'Personenname', 0, 0, 4, NULL, NULL, '''400b'',''400c'',''400q'',''400d'',''400t'',''400o'',''400m'',''400r'',''400s'',''400k'',''400n'',''400p'',''400g'',''400l'',''400f'',''400h'',''400x'',''400z'',''400y'',''400v''', 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'b', 'Zählung', 'Zählung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '400', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''410b'',''410c'',''410d'',''410t'',''410o'',''410m'',''410r'',''410s'',''410k'',''410n'',''410p'',''410g'',''410l'',''410f'',''410h'',''410x'',''410z'',''410y'',''410v''', 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '410', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''411e'',''411c'',''411d'',''411t'',''411s'',''411k'',''411n'',''411p'',''411g'',''411l'',''411f'',''411h'',''411x'',''411z'',''411y'',''411v''', 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'b', 'Nummer {OBSOLET]', 'Nummer {OBSOLET]', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '411', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 4, NULL, NULL, '''430o'',''430m'',''430r'',''430s'',''430d'',''430k'',''430n'',''430p'',''430g'',''430l'',''430f'',''430h'',''430t'',''430x'',''430z'',''430y'',''430v''', 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '430', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '448', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 4, NULL, NULL, '''448y'',''448x'',''448z'',''448v''', 0, 0, '', '', ''),
		('CORPO_NAME', '448', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '448', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '448', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '448', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '448', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '448', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '448', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '448', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '448', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '450', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 4, NULL, NULL, '''450x'',''450z'',''450y'',''450v''', 0, 0, '', '', ''),
		('CORPO_NAME', '450', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '450', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '450', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '450', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '450', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '450', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '450', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '450', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '450', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '450', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '451', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 4, NULL, NULL, '''451z'',''451x'',''451y'',''451v''', 0, 0, '', '', ''),
		('CORPO_NAME', '451', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '451', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '451', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '451', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '451', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '451', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '451', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '451', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '451', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '455', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 4, NULL, NULL, '''455v'',''455x'',''455z'',''455y''', 0, 0, '', '', ''),
		('CORPO_NAME', '455', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '455', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '455', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '455', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '455', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '455', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '455', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '455', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '455', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '480', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '480', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '480', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '480', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '480', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '480', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '480', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '480', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '480', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '481', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '481', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '481', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '481', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '481', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '481', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '481', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '481', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '481', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '482', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '482', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '482', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '482', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '482', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '482', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '482', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '482', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '482', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '485', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '485', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '485', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '485', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '485', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '485', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '485', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '485', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '485', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'a', 'Personenname', 'Personenname', 0, 0, 5, NULL, NULL, '''500b'',''500c'',''500q'',''500d'',''500t'',''500o'',''500m'',''500r'',''500s'',''500k'',''500n'',''500p'',''500g'',''500l'',''500f'',''500h'',''500x'',''500z'',''500y'',''500v''', 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'b', 'Zählung', 'Zählung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '500', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''510b'',''510c'',''510d'',''510t'',''510o'',''510m'',''510r'',''510s'',''510k'',''510n'',''510p'',''510g'',''510l'',''510f'',''510h'',''510x'',''510z'',''510y'',''510v''', 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '510', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''511e'',''511c'',''511d'',''511t'',''511s'',''511k'',''511n'',''511p'',''511g'',''511l'',''511f'',''511h'',''511x'',''511z'',''511y'',''511v''', 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '511', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 5, NULL, NULL, '''530o'',''530m'',''530r'',''530s'',''530d'',''530k'',''530n'',''530p'',''530g'',''530l'',''530f'',''530h'',''530t'',''530x'',''530z'',''530y'',''530v''', 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '530', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '548', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 5, NULL, NULL, '''548y'',''548x'',''548z'',''548v''', 0, 0, '', '', ''),
		('CORPO_NAME', '548', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '548', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '548', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '548', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '548', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '548', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '548', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '548', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '548', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '548', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '550', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 5, NULL, NULL, '''550x'',''550z'',''550y'',''550v''', 0, 0, '', '', ''),
		('CORPO_NAME', '550', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '550', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '550', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '550', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '550', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '550', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '550', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '550', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '550', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '550', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '550', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '551', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 5, NULL, NULL, '''551z'',''551x'',''551y'',''551v''', 0, 0, '', '', ''),
		('CORPO_NAME', '551', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '551', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '551', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '551', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '551', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '551', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '551', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '551', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '551', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '551', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '555', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 5, NULL, NULL, '''555v'',''555x'',''555z'',''555y''', 0, 0, '', '', ''),
		('CORPO_NAME', '555', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '555', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '555', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '555', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '555', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '555', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '555', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '555', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '555', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '555', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '580', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '580', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '580', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '580', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '580', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '580', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '580', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '580', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '580', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '580', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '581', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '581', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '581', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '581', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '581', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '581', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '581', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '581', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '581', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '581', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '582', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '582', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '582', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '582', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '582', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '582', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '582', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '582', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '582', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '582', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '585', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '585', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '585', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '585', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '585', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '585', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '585', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '585', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '585', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '585', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '663', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '663', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '663', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '663', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '663', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '664', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '664', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '664', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '664', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '664', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '665', 'a', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '665', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '665', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '666', 'a', 'Allgemeine Hinweiserläuterung', 'Allgemeine Hinweiserläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '666', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '666', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '667', 'a', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '667', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '667', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '667', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '670', 'a', 'Quellenangabe', 'Quellenangabe', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '670', 'b', 'Vorhandene Informationen', 'Vorhandene Informationen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '670', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '670', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '670', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '675', 'a', 'Quellenangabe', 'Quellenangabe', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '675', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '675', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '678', 'a', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '678', 'b', 'Erweiterung', 'Erweiterung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '678', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '678', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '678', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '680', 'a', 'Ansetzung oder Unterteilung', 'Ansetzung oder Unterteilung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '680', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '680', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '680', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '680', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '680', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '681', 'a', 'Schlagwort- oder Unterteilungsansetzung', 'Schlagwort- oder Unterteilungsansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '681', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '681', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '681', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '681', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '682', 'a', 'Zu ersetzende Ansetzung', 'Zu ersetzende Ansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '682', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '682', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '682', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '683', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '683', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '683', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '683', 'p', 'Corresponding classification field', 'Corresponding classification field', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '683', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '683', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '683', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '683', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '683', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '688', 'a', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '688', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '688', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '688', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'h', 'Medium', 'Medium', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'r', 'Tonart', 'Tonart', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 's', 'Version', 'Version', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', '4', 'Relator code', 'Relator code', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '710', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '788', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '788', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '788', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '788', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '788', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '788', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '788', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'a', 'Host-Name', 'Host-Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'b', 'Zugriffsnummer', 'Zugriffsnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'c', 'Angaben zur Komprimierung', 'Angaben zur Komprimierung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'd', 'Pfad', 'Pfad', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'f', 'Elektronischer Name', 'Elektronischer Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'h', 'Bearbeiter der Anfrage', 'Bearbeiter der Anfrage', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'i', 'Anweisung', 'Anweisung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'j', 'Bits pro Sekunde', 'Bits pro Sekunde', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'k', 'Passwort', 'Passwort', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'l', 'Login', 'Login', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'm', 'Kontaktstelle für Hilfe beim Zugriff', 'Kontaktstelle für Hilfe beim Zugriff', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'n', 'Name des Standortes des Hosts', 'Name des Standortes des Hosts', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'o', 'Betriebssystem', 'Betriebssystem', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'p', 'Port', 'Port', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'q', 'Elektronisches Format', 'Elektronisches Format', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'r', 'Einstellungen', 'Einstellungen', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 's', 'Dateigröße', 'Dateigröße', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 't', 'Terminalemulation', 'Terminalemulation', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'v', 'Zugriffszeiten', 'Zugriffszeiten', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'w', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'x', 'Interne Anmerkungen', 'Interne Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'y', 'Verlinkungstext', 'Verlinkungstext', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', 'z', 'Allgemeine Anmerkungen', 'Allgemeine Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', '2', 'Zugriffsart', 'Zugriffsart', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', '3', 'Spezifische Materialangaben', 'Spezifische Materialangaben', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '856', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'a', 'a', 'a', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'b', 'b', 'b', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'c', 'c', 'c', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'd', 'd', 'd', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'e', 'e', 'e', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'f', 'f', 'f', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'g', 'g', 'g', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'h', 'h', 'h', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'i', 'i', 'i', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'j', 'j', 'j', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'k', 'k', 'k', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'l', 'l', 'l', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'm', 'm', 'm', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'n', 'n', 'n', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'o', 'o', 'o', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'p', 'p', 'p', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'q', 'q', 'q', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'r', 'r', 'r', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 's', 's', 's', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 't', 't', 't', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'u', 'u', 'u', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'v', 'v', 'v', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'w', 'w', 'w', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'x', 'x', 'x', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'y', 'y', 'y', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', 'z', 'z', 'z', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', '0', '0', '0', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', '1', '1', '1', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', '2', '2', '2', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', '3', '3', '3', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', '4', '4', '4', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', '5', '5', '5', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', '6', '6', '6', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', '7', '7', '7', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', '8', '8', '8', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '880', '9', '9', '9', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CORPO_NAME', '942', 'a', 'Koha-Normdatentyp', 'Koha-Normdatentyp', 0, 1, 9, NULL, NULL, NULL, 0, 8, '', 'auth_header.authtypecode', '');


-- ******************************************************



-- *******************************************************************
-- MEETING NAME AUTHORITY FIELDS/SUBFIELDS.
-- *******************************************************************

-- These ought to be adjusted for different less conflicting and more
-- rationally chosen fields and subfields but I had left that for last.

-- ADJUST ME
-- Use values from your dump of auth_tag_structure and auth_subfield_structure
-- to provide support for your Koha database.


INSERT INTO `auth_tag_structure` (`authtypecode`, `tagfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `authorised_value`) VALUES
		('MEETI_NAME', '000', 'Leader', 'Leader', 0, 1, NULL),
		('MEETI_NAME', '001', 'Kontrollnummer', 'Kontrollnummer', 0, 1, NULL),
		('MEETI_NAME', '003', 'Kontrollnummer-Identifier', 'Kontrollnummer-Identifier', 0, 1, NULL),
		('MEETI_NAME', '005', 'Datum und Zeit der letzten Transaktion', 'Datum und Zeit der letzten Transaktion', 0, 1, NULL),
		('MEETI_NAME', '008', 'Datenelemente mit fester Länge', 'Datenelemente mit fester Länge', 0, 1, NULL),
		('MEETI_NAME', '010', 'Kontrollnummer der Library of Congress', 'Kontrollnummer der Library of Congress', 0, 0, NULL),
		('MEETI_NAME', '014', 'Verknüpfung zum bibliographischen Datensatz für Gesamttitel oder mehrteilige Exemplare', 'Verknüpfung zum bibliographischen Datensatz für Gesamttitel oder mehrteilige Exemplare', 1, 0, NULL),
		('MEETI_NAME', '016', 'Kontrollnummer der nationalen bibliografischen Stelle', 'Kontrollnummer der nationalen bibliografischen Stelle', 1, 0, NULL),
		('MEETI_NAME', '020', 'Internationale Standardbuchnummer', 'Internationale Standardbuchnummer', 1, 0, NULL),
		('MEETI_NAME', '022', 'Internationale Standardseriennummer', 'Internationale Standardseriennummer', 1, 0, NULL),
		('MEETI_NAME', '024', 'Anderer Standard-Identifier', 'Anderer Standard-Identifier', 1, 0, NULL),
		('MEETI_NAME', '031', 'Informationen zum Musik-Incipit', 'Informationen zum Musik-Incipit', 1, 0, NULL),
		('MEETI_NAME', '034', 'Kodierte kartografische mathematische Daten', 'Kodierte kartografische mathematische Daten', 1, 0, NULL),
		('MEETI_NAME', '035', 'System-Kontrollnummer', 'System-Kontrollnummer', 1, 0, NULL),
		('MEETI_NAME', '040', 'Katalogisierungsquelle', 'Katalogisierungsquelle', 0, 1, NULL),
		('MEETI_NAME', '042', 'Authentifizierungscode', 'Authentifizierungscode', 0, 0, NULL),
		('MEETI_NAME', '043', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 0, 0, NULL),
		('MEETI_NAME', '045', 'Zeitabschnitt der Ansetzung', 'Zeitabschnitt der Ansetzung', 0, 0, NULL),
		('MEETI_NAME', '050', 'Signatur der Library of Congress', 'Signatur der Library of Congress', 1, 0, NULL),
		('MEETI_NAME', '052', 'Geografische Klassifikation', 'Geografische Klassifikation', 1, 0, NULL),
		('MEETI_NAME', '053', 'Notation der LC', 'Notation der LC', 1, 0, NULL),
		('MEETI_NAME', '055', 'Signatur der Library and Archives Canada', 'Signatur der Library and Archives Canada', 1, 0, NULL),
		('MEETI_NAME', '060', 'Signatur der National Library of Medicine', 'Signatur der National Library of Medicine', 1, 0, NULL),
		('MEETI_NAME', '065', 'Andere Notation', 'Andere Notation', 1, 0, NULL),
		('MEETI_NAME', '066', 'Angewendete Zeichensätze', 'Angewendete Zeichensätze', 0, 0, NULL),
		('MEETI_NAME', '070', 'Signatur der National Agricultural Library', 'Signatur der National Agricultural Library', 1, 0, NULL),
		('MEETI_NAME', '072', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 1, 0, NULL),
		('MEETI_NAME', '073', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 0, 0, NULL),
		('MEETI_NAME', '082', 'Dewey-Dezimal-Signatur', 'Dewey-Dezimal-Signatur', 1, 0, NULL),
		('MEETI_NAME', '083', 'DDC-Notation', 'DDC-Notation', 1, 0, NULL),
		('MEETI_NAME', '086', 'Signatur für Amtsdruckschriften', 'Signatur für Amtsdruckschriften', 1, 0, NULL),
		('MEETI_NAME', '087', 'Notation fürs Amtsdruckschriften', 'Notation fürs Amtsdruckschriften', 1, 0, NULL),
		('MEETI_NAME', '090', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (RLIN)', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (OCLC)', 1, 0, NULL),
		('MEETI_NAME', '091', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 0, 0, NULL),
		('MEETI_NAME', '092', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 1, 0, NULL),
		('MEETI_NAME', '093', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('MEETI_NAME', '096', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 1, 0, NULL),
		('MEETI_NAME', '097', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('MEETI_NAME', '098', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 1, 0, NULL),
		('MEETI_NAME', '099', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 1, 0, NULL),
		('MEETI_NAME', '111', 'Ansetzung - Kongressname', 'Ansetzung - Kongressname', 0, 0, NULL),
		('MEETI_NAME', '260', 'Komplexer Siehe-Hinweis - Schlagwort', 'Komplexer Siehe-Hinweis - Schlagwort', 1, 0, NULL),
		('MEETI_NAME', '360', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 1, 0, NULL),
		('MEETI_NAME', '400', 'Siehe-Verweisung - Personenname', 'Siehe-Verweisung - Personenname', 1, 0, NULL),
		('MEETI_NAME', '410', 'Siehe-Verweisung - Körperschaftsname', 'Siehe-Verweisung - Körperschaftsname', 1, 0, NULL),
		('MEETI_NAME', '411', 'Siehe-Verweisung - Kongressname', 'Siehe-Verweisung - Kongressname', 1, 0, NULL),
		('MEETI_NAME', '430', 'Siehe-Verweisung - Einheitstitel', 'Siehe-Verweisung - Einheitstitel', 1, 0, NULL),
		('MEETI_NAME', '448', 'Siehe-Verweisung - Zeitschlagwort', 'Siehe-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('MEETI_NAME', '450', 'Siehe-Verweisung - Sachschlagwort', 'Siehe-Verweisung - Sachschlagwort', 1, 0, NULL),
		('MEETI_NAME', '451', 'Siehe-Verweisung - Geografischer Name', 'Siehe-Verweisung - Geografischer Name', 1, 0, NULL),
		('MEETI_NAME', '455', 'Siehe-Verweisung - Genre/Formschlagwort', 'Siehe-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('MEETI_NAME', '480', 'Siehe-Verweisung - Allgemeine Unterteilung', 'Siehe-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('MEETI_NAME', '481', 'Siehe-Verweisung - Geografische Unterteilung', 'Siehe-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('MEETI_NAME', '482', 'Siehe-Verweisung - Chronologische Unterteilung', 'Siehe-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('MEETI_NAME', '485', 'Siehe-Verweisung - Unterteilung nach Form', 'Siehe-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('MEETI_NAME', '500', 'Siehe-auch-Verweisung - Personenname', 'Siehe-auch-Verweisung - Personenname', 1, 0, NULL),
		('MEETI_NAME', '510', 'Siehe-auch-Verweisung - Körperschaftsname', 'Siehe-auch-Verweisung - Körperschaftsname', 1, 0, NULL),
		('MEETI_NAME', '511', 'Siehe-auch-Verweisung - Kongressname', 'Siehe-auch-Verweisung - Kongressname', 1, 0, NULL),
		('MEETI_NAME', '530', 'Siehe-auch-Verweisung - Einheitstitel', 'Siehe-auch-Verweisung - Einheitstitel', 1, 0, NULL),
		('MEETI_NAME', '548', 'Siehe-auch-Verweisung - Zeitschlagwort', 'Siehe-auch-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('MEETI_NAME', '550', 'Siehe-auch-Verweisung - Sachschlagwort', 'Siehe-auch-Verweisung - Sachschlagwort', 1, 0, NULL),
		('MEETI_NAME', '551', 'Siehe-auch-Verweisung - Geografischer Name', 'Siehe-auch-Verweisung - Geografischer Name', 1, 0, NULL),
		('MEETI_NAME', '555', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('MEETI_NAME', '580', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('MEETI_NAME', '581', 'Siehe-auch-Verweisung - Geografische Unterteilung', 'Siehe-auch-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('MEETI_NAME', '582', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('MEETI_NAME', '585', 'Siehe-auch-Verweisung - Unterteilung nach Form', 'Siehe-auch-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('MEETI_NAME', '663', 'Komplexe Siehe-auch-Verweisung - Name', 'Komplexe Siehe-auch-Verweisung - Name', 0, 0, NULL),
		('MEETI_NAME', '664', 'Komplexe Siehe-Verweisung - Name', 'Komplexe Siehe-Verweisung - Name', 0, 0, NULL),
		('MEETI_NAME', '665', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 0, 0, NULL),
		('MEETI_NAME', '666', 'Allgemein erläuternde Verweisung - Name', 'Allgemein erläuternde Verweisung - Name', 0, 0, NULL),
		('MEETI_NAME', '667', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 1, 0, NULL),
		('MEETI_NAME', '670', 'Datenquelle', 'Datenquelle', 1, 0, NULL),
		('MEETI_NAME', '675', 'Datenquelle ohne Information', 'Datenquelle ohne Information', 0, 0, NULL),
		('MEETI_NAME', '678', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, NULL),
		('MEETI_NAME', '680', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, NULL),
		('MEETI_NAME', '681', 'Beispiel für die Schlagwortverweisung', 'Beispiel für die Schlagwortverweisung', 1, 0, NULL),
		('MEETI_NAME', '682', 'Angaben zu gelöschten Ansetzungen', 'Angaben zu gelöschten Ansetzungen', 0, 0, NULL),
		('MEETI_NAME', '683', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('MEETI_NAME', '688', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('MEETI_NAME', '711', 'Verknüpfungseintragung für normierte Ansetzungen - Kongressname', 'Verknüpfungseintragung für normierte Ansetzungen - Kongressname', 1, 0, NULL),
		('MEETI_NAME', '788', 'Komplexe Verknüpfungseintragungsdaten', 'Komplexe Verknüpfungseintragungsdaten', 0, 0, NULL),
		('MEETI_NAME', '856', 'Elektronische Adresse und Zugriff', 'Elektronische Adresse und Zugriff', 1, 0, NULL),
		('MEETI_NAME', '880', 'Andersschriftliche Darstellung', 'Andersschriftliche Darstellung', 1, 0, NULL),
        ('MEETI_NAME', '942', 'Interne Verwendung (KOHA)', 'Interne Verwendung (KOHA)', 0, 1, NULL);


INSERT INTO `auth_subfield_structure` (`authtypecode`, `tagfield`, `tagsubfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `tab`, `authorised_value`, `value_builder`, `seealso`, `isurl`, `hidden`, `linkid`, `kohafield`, `frameworkcode`) VALUES
		('MEETI_NAME', '000', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_leader_authorities.pl', NULL, 0, 0, '', '', ''),
                ('MEETI_NAME', '001', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', 'auth_header.authid', ''),
                ('MEETI_NAME', '003', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
                ('MEETI_NAME', '005', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_005.pl', NULL, 0, 0, '', '', ''),
                ('MEETI_NAME', '008', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_field_008_authorities.pl', NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '010', 'a', 'LoC-Kontrollnummer', 'LoC-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '010', 'z', 'Gelöschte/ungültige LoC-Kontrollnummer', 'Gelöschte/ungültige LoC-Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '010', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '014', 'a', 'Kontrollnummer des verwandten bibliografischen Datensatzes', 'Kontrollnummer des verwandten bibliografischen Datensatzes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '014', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '014', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '016', 'a', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '016', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '016', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '016', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '020', 'a', 'Internationale Standardbuchnummer', 'Internationale Standardbuchnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '020', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '020', 'z', 'Gelöschte/ungültige ISBN', 'Gelöschte/ungültige ISBN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '020', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '020', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '022', 'a', 'Internationale Standardseriennummer', 'Internationale Standardseriennummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '022', 'y', 'Falsche ISSN', 'Falsche ISSN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '022', 'z', 'Gelöschte ISSN', 'Gelöschte ISSN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '022', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '022', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '024', 'a', 'Standardnummer oder Code', 'Standardnummer oder Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '024', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '024', 'd', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '024', 'z', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '024', '2', 'Quelle der Nummer oder des Codes', 'Quelle der Nummer oder des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '024', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '024', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 'a', 'Number of work', 'Number of work', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 'b', 'Satznummer', 'Satznummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 'c', 'Nummer des Ausschnitts', 'Nummer des Ausschnitts', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 'd', 'Titel oder Ansetzung', 'Titel oder Ansetzung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 'e', 'Partie', 'Partie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 'g', 'Notenschlüssel', 'Notenschlüssel', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 'm', 'Stimme/Instrument', 'Stimme/Instrument', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 'n', 'Tonartvorzeichen', 'Tonartvorzeichen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 'o', 'Taktvorzeichen', 'Taktvorzeichen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 'p', 'Musikalische Notierung', 'Musikalische Notierung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 'q', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 'r', 'Tonart oder Modus', 'Tonart oder Modus', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 's', 'Kodierte Fußnote zur Echtheit', 'Kodierte Fußnote zur Echtheit', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 't', 'Text-Incipit', 'Text-Incipit', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', '2', 'Systemcode', 'Systemcode', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '031', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 'd', 'Koordinaten - westlichster Längengrad', 'Koordinaten - westlichster Längengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 'e', 'Koordinaten - östlichster Längengrad', 'Koordinaten - östlichster Längengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 'f', 'Koordinaten - nördlichster Breitengrad', 'Koordinaten - nördlichster Breitengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 'g', 'Koordinaten - südlichster Breitengrad', 'Koordinaten - südlichster Breitengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 'j', 'Deklination - nördliche Grenze', 'Deklination - nördliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 'k', 'Deklination - südliche Grenze', 'Deklination - südliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 'm', 'Rektaszension - östliche Grenze', 'Rektaszension - östliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 'n', 'Rektaszension - westliche Grenze', 'Rektaszension - westliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 'p', 'Äquinoktium', 'Äquinoktium', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 'r', 'Entfernung von der Erde', 'Entfernung von der Erde', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 's', 'G-Ring Breitengrad', 'G-Ring Breitengrad', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 't', 'G-Ring Längengrad', 'G-Ring Längengrad', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 'x', 'Anfangsdatum', 'Anfangsdatum', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 'y', 'Enddatum', 'Enddatum', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', 'z', 'Name des außerirdischen Himmelskörpers', 'Name des außerirdischen Himmelskörpers', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '034', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '035', 'a', 'System-Kontrollnummer', 'System-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '035', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '035', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '035', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '040', 'a', 'Original-Katalogisierungsstelle', 'Original-Katalogisierungsstelle', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '040', 'b', 'Katalogisierungssprache', 'Katalogisierungssprache', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '040', 'c', 'Übertragungsstelle', 'Übertragungsstelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '040', 'd', 'Bearbeitungsstelle', 'Bearbeitungsstelle', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '040', 'e', 'Beschreibungsfestlegungen', 'Beschreibungsfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '040', 'f', 'Schlagwort- oder Thesaurusfestlegungen', 'Schlagwort- oder Thesaurusfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '040', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '040', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '042', 'a', 'Authentifizierungscode', 'Authentifizierungscode', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '043', 'a', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '043', 'b', 'Lokaler GAC-Code', 'Lokaler GAC-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '043', 'c', 'ISO-Code', 'ISO-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '043', '2', 'Quelle des lokalen Codes', 'Quelle des lokalen Codes', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '043', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '043', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '045', 'a', 'Zeitabschnitts-Code', 'Zeitabschnitts-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '045', 'b', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '045', 'c', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '045', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '045', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '050', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '050', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '050', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '050', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '050', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '050', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '052', 'a', 'Klassifikation des geografischen Gebiets', 'Klassifikation des geografischen Gebiets', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '052', 'b', 'Klassifikation des geografischen Teilgebiets', 'Klassifikation des geografischen Teilgebiets', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '052', 'd', 'Eingetragener Ortsname', 'Eingetragener Ortsname', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '052', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '052', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '052', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '053', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '053', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '053', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '053', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '053', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '053', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '055', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '055', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '055', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '055', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '055', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '055', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '060', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '060', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '060', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '060', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '060', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '060', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '065', 'a', 'Classification number element--single number or beginning of span', 'Classification number element--single number or beginning of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '065', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '065', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '065', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '065', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '065', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '065', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '066', 'a', 'Primärer G0-Zeichensatz', 'Primärer G0-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '066', 'b', 'Primärer G1-Zeichensatz', 'Primärer G1-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '066', 'c', 'Wechselnder G0- oder G1-Zeichensatz', 'Wechselnder G0- oder G1-Zeichensatz', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '070', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '070', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '070', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '070', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '070', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '072', 'a', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '072', 'x', 'Subject category code subdivision', 'Subject category code subdivision', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '072', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '072', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '072', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '073', 'a', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '073', 'z', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '073', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '073', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '082', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '082', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '082', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '082', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '082', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '082', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '082', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '083', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '083', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '083', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '083', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '083', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '083', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '083', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '083', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '086', 'a', 'Signatur', 'Signatur', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '086', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '086', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '086', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '086', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '086', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '086', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '087', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '087', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '087', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '087', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '087', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '087', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 'a', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 'b', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 'e', 'Feature heading (OCLC)', 'Feature heading (OCLC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 'f', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 'h', 'Output transaction history, HST (RLIN)', 'Output transaction history, HST (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 'i', 'Output transaction instruction, INS (RLIN)', 'Output transaction instruction, INS (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 'l', 'Extra card control statement, EXT (RLIN)', 'Extra card control statement, EXT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 'n', 'Additional local notes, ANT (RLIN)', 'Additional local notes, ANT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 'p', 'Pathfinder code, PTH (RLIN)', 'Pathfinder code, PTH (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 't', 'Field suppresion, FSP (RLIN)', 'Field suppresion, FSP (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 'v', 'Volumes, VOL (RLIN)', 'Volumes, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 'y', 'Date, VOL (RLIN)', 'Date, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '090', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '091', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '091', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '091', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '091', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '091', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '091', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '091', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '091', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '092', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '092', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '092', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '092', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '092', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '092', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '092', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '092', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '092', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '093', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '093', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '093', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '093', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '093', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '093', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '093', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '093', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '096', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '096', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '096', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '096', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '096', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '096', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '096', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '096', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '096', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '097', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '097', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '097', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '097', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '097', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '097', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '097', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '097', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '098', 'a', 'Call number based on other classification scheme', 'Call number based on other classification scheme', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '098', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '098', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '098', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '098', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '098', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '098', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '098', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '098', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '099', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '099', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '099', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '099', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '099', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '099', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '099', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '099', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '099', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 1, NULL, NULL, '''111e'',''111c'',''111d'',''111t'',''111s'',''111k'',''111n'',''111p'',''111g'',''111l'',''111f'',''111h'',''111x'',''111z'',''111y'',''111v''', 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'b', 'Nummer [OBSOLET]', 'Nummer [OBSOLET]', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'h', 'Medium', 'Medium', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'j', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 's', 'Version', 'Version', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '111', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '260', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '260', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '260', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '260', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '360', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '360', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '360', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '360', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'a', 'Personenname', 'Personenname', 0, 0, 4, NULL, NULL, '''400b'',''400c'',''400q'',''400d'',''400t'',''400o'',''400m'',''400r'',''400s'',''400k'',''400n'',''400p'',''400g'',''400l'',''400f'',''400h'',''400x'',''400z'',''400y'',''400v''', 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'b', 'Zählung', 'Zählung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '400', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''410b'',''410c'',''410d'',''410t'',''410o'',''410m'',''410r'',''410s'',''410k'',''410n'',''410p'',''410g'',''410l'',''410f'',''410h'',''410x'',''410z'',''410y'',''410v''', 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '410', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''411e'',''411c'',''411d'',''411t'',''411s'',''411k'',''411n'',''411p'',''411g'',''411l'',''411f'',''411h'',''411x'',''411z'',''411y'',''411v''', 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'b', 'Nummer [OBSOLET]', 'Nummer [OBSOLET]', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '411', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 4, NULL, NULL, '''430o'',''430m'',''430r'',''430s'',''430d'',''430k'',''430n'',''430p'',''430g'',''430l'',''430f'',''430h'',''430t'',''430x'',''430z'',''430y'',''430v''', 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '430', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '448', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 4, NULL, NULL, '''448y'',''448x'',''448z'',''448v''', 0, 0, '', '', ''),
		('MEETI_NAME', '448', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '448', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '448', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '448', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '448', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '448', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '448', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '448', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '448', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '450', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 4, NULL, NULL, '''450x'',''450z'',''450y'',''450v''', 0, 0, '', '', ''),
		('MEETI_NAME', '450', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '450', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '450', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '450', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '450', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '450', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '450', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '450', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '450', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '450', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '451', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 4, NULL, NULL, '''451z'',''451x'',''451y'',''451v''', 0, 0, '', '', ''),
		('MEETI_NAME', '451', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '451', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '451', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '451', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '451', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '451', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '451', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '451', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '451', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '455', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 4, NULL, NULL, '''455v'',''455x'',''455z'',''455y''', 0, 0, '', '', ''),
		('MEETI_NAME', '455', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '455', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '455', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '455', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '455', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '455', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '455', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '455', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '455', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '480', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '480', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '480', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '480', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '480', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '480', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '480', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '480', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '480', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '481', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '481', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '481', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '481', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '481', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '481', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '481', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '481', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '481', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '482', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '482', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '482', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '482', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '482', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '482', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '482', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '482', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '482', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '485', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '485', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '485', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '485', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '485', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '485', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '485', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '485', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '485', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'a', 'Personenname', 'Personenname', 0, 0, 5, NULL, NULL, '''500b'',''500c'',''500q'',''500d'',''500t'',''500o'',''500m'',''500r'',''500s'',''500k'',''500n'',''500p'',''500g'',''500l'',''500f'',''500h'',''500x'',''500z'',''500y'',''500v''', 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'b', 'Zählung', 'Zählung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '500', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''510b'',''510c'',''510d'',''510t'',''510o'',''510m'',''510r'',''510s'',''510k'',''510n'',''510p'',''510g'',''510l'',''510f'',''510h'',''510x'',''510z'',''510y'',''510v''', 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '510', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''511e'',''511c'',''511d'',''511t'',''511s'',''511k'',''511n'',''511p'',''511g'',''511l'',''511f'',''511h'',''511x'',''511z'',''511y'',''511v''', 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '511', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 5, NULL, NULL, '''530o'',''530m'',''530r'',''530s'',''530d'',''530k'',''530n'',''530p'',''530g'',''530l'',''530f'',''530h'',''530t'',''530x'',''530z'',''530y'',''530v''', 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '530', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '548', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 5, NULL, NULL, '''548y'',''548x'',''548z'',''548v''', 0, 0, '', '', ''),
		('MEETI_NAME', '548', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '548', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '548', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '548', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '548', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '548', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '548', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '548', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '548', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '548', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '550', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 5, NULL, NULL, '''550x'',''550z'',''550y'',''550v''', 0, 0, '', '', ''),
		('MEETI_NAME', '550', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '550', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '550', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '550', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '550', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '550', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '550', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '550', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '550', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '550', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '550', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '551', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 5, NULL, NULL, '''551z'',''551x'',''551y'',''551v''', 0, 0, '', '', ''),
		('MEETI_NAME', '551', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '551', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '551', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '551', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '551', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '551', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '551', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '551', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '551', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '551', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '555', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 5, NULL, NULL, '''555v'',''555x'',''555z'',''555y''', 0, 0, '', '', ''),
		('MEETI_NAME', '555', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '555', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '555', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '555', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '555', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '555', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '555', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '555', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '555', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '555', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '580', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '580', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '580', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '580', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '580', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '580', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '580', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '580', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '580', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '580', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '581', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '581', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '581', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '581', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '581', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '581', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '581', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '581', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '581', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '581', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '582', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '582', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '582', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '582', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '582', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '582', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '582', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '582', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '582', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '582', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '585', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '585', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '585', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '585', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '585', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '585', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '585', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '585', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '585', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '585', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '663', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '663', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '663', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '663', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '663', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '664', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '664', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '664', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '664', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '664', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '665', 'a', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '665', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '665', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '666', 'a', 'Allgemeine Hinweiserläuterung', 'Allgemeine Hinweiserläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '666', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '666', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '667', 'a', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '667', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '667', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '667', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '670', 'a', 'Quellenangabe', 'Quellenangabe', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '670', 'b', 'Vorhandene Informationen', 'Vorhandene Informationen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '670', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '670', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '670', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '675', 'a', 'Quellenangabe', 'Quellenangabe', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '675', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '675', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '678', 'a', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '678', 'b', 'Erweiterung', 'Erweiterung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '678', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '678', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '678', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '680', 'a', 'Ansetzung oder Unterteilung', 'Ansetzung oder Unterteilung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '680', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '680', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '680', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '680', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '680', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '681', 'a', 'Schlagwort- oder Unterteilungsansetzung', 'Schlagwort- oder Unterteilungsansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '681', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '681', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '681', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '681', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '682', 'a', 'Zu ersetzende Ansetzung', 'Zu ersetzende Ansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '682', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '682', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '682', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '683', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '683', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '683', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '683', 'p', 'Corresponding classification field', 'Corresponding classification field', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '683', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '683', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '683', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '683', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '683', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '688', 'a', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '688', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '688', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '688', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'h', 'Medium', 'Medium', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 's', 'Version', 'Version', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', '3', 'Spezifische Materialangaben', 'Spezifische Materialangaben', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', '4', 'Relator code', 'Relator code', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '711', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '788', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '788', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '788', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '788', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '788', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '788', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '788', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'a', 'Host-Name', 'Host-Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'b', 'Zugriffsnummer', 'Zugriffsnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'c', 'Angaben zur Komprimierung', 'Angaben zur Komprimierung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'd', 'Pfad', 'Pfad', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'f', 'Elektronischer Name', 'Elektronischer Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'h', 'Bearbeiter der Anfrage', 'Bearbeiter der Anfrage', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'i', 'Anweisung', 'Anweisung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'j', 'Bits pro Sekunde', 'Bits pro Sekunde', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'k', 'Passwort', 'Passwort', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'l', 'Login', 'Login', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'm', 'Kontaktstelle für Hilfe beim Zugriff', 'Kontaktstelle für Hilfe beim Zugriff', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'n', 'Name des Standortes des Hosts', 'Name des Standortes des Hosts', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'o', 'Betriebssystem', 'Betriebssystem', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'p', 'Port', 'Port', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'q', 'Elektronisches Format', 'Elektronisches Format', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'r', 'Einstellungen', 'Einstellungen', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 's', 'Dateigröße', 'Dateigröße', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 't', 'Terminalemulation', 'Terminalemulation', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'v', 'Zugriffszeiten', 'Zugriffszeiten', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'w', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'x', 'Interne Anmerkungen', 'Interne Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'y', 'Verlinkungstext', 'Verlinkungstext', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', 'z', 'Allgemeine Anmerkungen', 'Allgemeine Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', '2', 'Zugriffsart', 'Zugriffsart', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', '3', 'Spezifische Materialangaben', 'Spezifische Materialangaben', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '856', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'a', 'a', 'a', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'b', 'b', 'b', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'c', 'c', 'c', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'd', 'd', 'd', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'e', 'e', 'e', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'f', 'f', 'f', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'g', 'g', 'g', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'h', 'h', 'h', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'i', 'i', 'i', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'j', 'j', 'j', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'k', 'k', 'k', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'l', 'l', 'l', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'm', 'm', 'm', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'n', 'n', 'n', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'o', 'o', 'o', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'p', 'p', 'p', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'q', 'q', 'q', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'r', 'r', 'r', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 's', 's', 's', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 't', 't', 't', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'u', 'u', 'u', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'v', 'v', 'v', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'w', 'w', 'w', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'x', 'x', 'x', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'y', 'y', 'y', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', 'z', 'z', 'z', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', '0', '0', '0', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', '1', '1', '1', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', '2', '2', '2', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', '3', '3', '3', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', '4', '4', '4', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', '5', '5', '5', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', '6', '6', '6', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', '7', '7', '7', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', '8', '8', '8', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '880', '9', '9', '9', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('MEETI_NAME', '942', 'a', 'Koha-Normdatentyp', 'Koha-Normdatentyp', 0, 1, 9, NULL, NULL, NULL, 0, 8, '', 'auth_header.authtypecode', '');


-- ******************************************************



-- *******************************************************************
-- UNIFORM TITLE AUTHORITY FIELDS/SUBFIELDS.
-- *******************************************************************

-- These ought to be adjusted for different less conflicting and more
-- rationally chosen fields and subfields but I had left that for last.

-- ADJUST ME
-- Use values from your dump of auth_tag_structure and auth_subfield_structure
-- to provide support for your Koha database.


INSERT INTO `auth_tag_structure` (`authtypecode`, `tagfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `authorised_value`) VALUES
		('UNIF_TITLE', '000', 'Leader', 'Leader', 0, 1, NULL),
		('UNIF_TITLE', '001', 'Kontrollnummer', 'Kontrollnummer', 0, 1, NULL),
		('UNIF_TITLE', '003', 'Kontrollnummer-Identifier', 'Kontrollnummer-Identifier', 0, 1, NULL),
		('UNIF_TITLE', '005', 'Datum und Zeit der letzten Transaktion', 'Datum und Zeit der letzten Transaktion', 0, 1, NULL),
		('UNIF_TITLE', '008', 'Datenelemente mit fester Länge', 'Datenelemente mit fester Länge', 0, 1, NULL),
		('UNIF_TITLE', '010', 'Kontrollnummer der Library of Congress', 'Kontrollnummer der Library of Congress', 0, 0, NULL),
		('UNIF_TITLE', '014', 'Verknüpfung zum bibliographischen Datensatz für Gesamttitel oder mehrteilige Exemplare', 'Verknüpfung zum bibliographischen Datensatz für Gesamttitel oder mehrteilige Exemplare', 1, 0, NULL),
		('UNIF_TITLE', '016', 'Kontrollnummer der nationalen bibliografischen Stelle', 'Kontrollnummer der nationalen bibliografischen Stelle', 1, 0, NULL),
		('UNIF_TITLE', '020', 'Internationale Standardbuchnummer', 'Internationale Standardbuchnummer', 1, 0, NULL),
		('UNIF_TITLE', '022', 'Internationale Standardseriennummer', 'Internationale Standardseriennummer', 1, 0, NULL),
		('UNIF_TITLE', '024', 'Anderer Standard-Identifier', 'Anderer Standard-Identifier', 1, 0, NULL),
		('UNIF_TITLE', '031', 'Informationen zum Musik-Incipit', 'Informationen zum Musik-Incipit', 1, 0, NULL),
		('UNIF_TITLE', '034', 'Kodierte kartografische mathematische Daten', 'Kodierte kartografische mathematische Daten', 1, 0, NULL),
		('UNIF_TITLE', '035', 'System-Kontrollnummer', 'System-Kontrollnummer', 1, 0, NULL),
		('UNIF_TITLE', '040', 'Katalogisierungsquelle', 'Katalogisierungsquelle', 0, 1, NULL),
		('UNIF_TITLE', '042', 'Authentifizierungscode', 'Authentifizierungscode', 0, 0, NULL),
		('UNIF_TITLE', '043', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 0, 0, NULL),
		('UNIF_TITLE', '045', 'Zeitabschnitt der Ansetzung', 'Zeitabschnitt der Ansetzung', 0, 0, NULL),
		('UNIF_TITLE', '050', 'Signatur der Library of Congress', 'Signatur der Library of Congress', 1, 0, NULL),
		('UNIF_TITLE', '052', 'Geografische Klassifikation', 'Geografische Klassifikation', 1, 0, NULL),
		('UNIF_TITLE', '053', 'Notation der LC', 'Notation der LC', 1, 0, NULL),
		('UNIF_TITLE', '055', 'Signatur der Library and Archives Canada', 'Signatur der Library and Archives Canada', 1, 0, NULL),
		('UNIF_TITLE', '060', 'Signatur der National Library of Medicine', 'Signatur der National Library of Medicine', 1, 0, NULL),
		('UNIF_TITLE', '065', 'Andere Notation', 'Andere Notation', 1, 0, NULL),
		('UNIF_TITLE', '066', 'Angewendete Zeichensätze', 'Angewendete Zeichensätze', 0, 0, NULL),
		('UNIF_TITLE', '070', 'Signatur der National Agricultural Library', 'Signatur der National Agricultural Library', 1, 0, NULL),
		('UNIF_TITLE', '072', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 1, 0, NULL),
		('UNIF_TITLE', '073', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 0, 0, NULL),
		('UNIF_TITLE', '082', 'Dewey-Dezimal-Signatur', 'Dewey-Dezimal-Signatur', 1, 0, NULL),
		('UNIF_TITLE', '083', 'DDC-Notation', 'DDC-Notation', 1, 0, NULL),
		('UNIF_TITLE', '086', 'Signatur für Amtsdruckschriften', 'Signatur für Amtsdruckschriften', 1, 0, NULL),
		('UNIF_TITLE', '087', 'Notation fürs Amtsdruckschriften', 'Notation fürs Amtsdruckschriften', 1, 0, NULL),
		('UNIF_TITLE', '090', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (RLIN)', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (OCLC)', 1, 0, NULL),
		('UNIF_TITLE', '091', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 0, 0, NULL),
		('UNIF_TITLE', '092', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 1, 0, NULL),
		('UNIF_TITLE', '093', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('UNIF_TITLE', '096', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 1, 0, NULL),
		('UNIF_TITLE', '097', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('UNIF_TITLE', '098', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 1, 0, NULL),
		('UNIF_TITLE', '099', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 1, 0, NULL),
		('UNIF_TITLE', '130', 'Ansetzung - Einheitstitel', 'Ansetzung - Einheitstitel', 0, 0, NULL),
		('UNIF_TITLE', '260', 'Komplexer Siehe-Hinweis - Schlagwort', 'Komplexer Siehe-Hinweis - Schlagwort', 1, 0, NULL),
		('UNIF_TITLE', '360', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 1, 0, NULL),
		('UNIF_TITLE', '400', 'Siehe-Verweisung - Personenname', 'Siehe-Verweisung - Personenname', 1, 0, NULL),
		('UNIF_TITLE', '410', 'Siehe-Verweisung - Körperschaftsname', 'Siehe-Verweisung - Körperschaftsname', 1, 0, NULL),
		('UNIF_TITLE', '411', 'Siehe-Verweisung - Kongressname', 'Siehe-Verweisung - Kongressname', 1, 0, NULL),
		('UNIF_TITLE', '430', 'Siehe-Verweisung - Einheitstitel', 'Siehe-Verweisung - Einheitstitel', 1, 0, NULL),
		('UNIF_TITLE', '448', 'Siehe-Verweisung - Zeitschlagwort', 'Siehe-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('UNIF_TITLE', '450', 'Siehe-Verweisung - Sachschlagwort', 'Siehe-Verweisung - Sachschlagwort', 1, 0, NULL),
		('UNIF_TITLE', '451', 'Siehe-Verweisung - Geografischer Name', 'Siehe-Verweisung - Geografischer Name', 1, 0, NULL),
		('UNIF_TITLE', '455', 'Siehe-Verweisung - Genre/Formschlagwort', 'Siehe-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('UNIF_TITLE', '480', 'Siehe-Verweisung - Allgemeine Unterteilung', 'Siehe-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('UNIF_TITLE', '481', 'Siehe-Verweisung - Geografische Unterteilung', 'Siehe-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('UNIF_TITLE', '482', 'Siehe-Verweisung - Chronologische Unterteilung', 'Siehe-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('UNIF_TITLE', '485', 'Siehe-Verweisung - Unterteilung nach Form', 'Siehe-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('UNIF_TITLE', '500', 'Siehe-auch-Verweisung - Personenname', 'Siehe-auch-Verweisung - Personenname', 1, 0, NULL),
		('UNIF_TITLE', '510', 'Siehe-auch-Verweisung - Körperschaftsname', 'Siehe-auch-Verweisung - Körperschaftsname', 1, 0, NULL),
		('UNIF_TITLE', '511', 'Siehe-auch-Verweisung - Kongressname', 'Siehe-auch-Verweisung - Kongressname', 1, 0, NULL),
		('UNIF_TITLE', '530', 'Siehe-auch-Verweisung - Einheitstitel', 'Siehe-auch-Verweisung - Einheitstitel', 1, 0, NULL),
		('UNIF_TITLE', '548', 'Siehe-auch-Verweisung - Zeitschlagwort', 'Siehe-auch-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('UNIF_TITLE', '550', 'Siehe-auch-Verweisung - Sachschlagwort', 'Siehe-auch-Verweisung - Sachschlagwort', 1, 0, NULL),
		('UNIF_TITLE', '551', 'Siehe-auch-Verweisung - Geografischer Name', 'Siehe-auch-Verweisung - Geografischer Name', 1, 0, NULL),
		('UNIF_TITLE', '555', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('UNIF_TITLE', '580', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('UNIF_TITLE', '581', 'Siehe-auch-Verweisung - Geografische Unterteilung', 'Siehe-auch-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('UNIF_TITLE', '582', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('UNIF_TITLE', '585', 'Siehe-auch-Verweisung - Unterteilung nach Form', 'Siehe-auch-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('UNIF_TITLE', '640', 'Erscheinungsjahr und/oder Erscheinungsverlauf von Gesamttiteln', 'Erscheinungsjahr und/oder Erscheinungsverlauf von Gesamttiteln', 1, 0, NULL),
		('UNIF_TITLE', '641', 'Besonderheiten der Zählung von Gesamttiteln', 'Besonderheiten der Zählung von Gesamttiteln', 1, 0, NULL),
		('UNIF_TITLE', '642', 'Beispiel für die Zählung von Gesamttiteln', 'Beispiel für die Zählung von Gesamttiteln', 1, 0, NULL),
		('UNIF_TITLE', '643', 'Erscheinungsort und herausgebende Körperschaft von Gesamttiteln', 'Erscheinungsort und herausgebende Körperschaft von Gesamttiteln', 1, 0, NULL),
		('UNIF_TITLE', '644', 'Analyse-Praxis von Gesamttiteln', 'Analyse-Praxis von Gesamttiteln', 1, 0, NULL),
		('UNIF_TITLE', '645', 'Verweisungspraxis von Gesamttiteln', 'Verweisungspraxis von Gesamttiteln', 1, 0, NULL),
		('UNIF_TITLE', '646', 'Klassifizierungspraxis von Gesamttiteln', 'Klassifizierungspraxis von Gesamttiteln', 1, 0, NULL),
		('UNIF_TITLE', '663', 'Komplexe Siehe-auch-Verweisung - Name', 'Komplexe Siehe-auch-Verweisung - Name', 0, 0, NULL),
		('UNIF_TITLE', '664', 'Komplexe Siehe-Verweisung - Name', 'Komplexe Siehe-Verweisung - Name', 0, 0, NULL),
		('UNIF_TITLE', '665', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 0, 0, NULL),
		('UNIF_TITLE', '666', 'Allgemein erläuternde Verweisung - Name', 'Allgemein erläuternde Verweisung - Name', 0, 0, NULL),
		('UNIF_TITLE', '667', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 1, 0, NULL),
		('UNIF_TITLE', '670', 'Datenquelle', 'Datenquelle', 1, 0, NULL),
		('UNIF_TITLE', '675', 'Datenquelle ohne Information', 'Datenquelle ohne Information', 0, 0, NULL),
		('UNIF_TITLE', '678', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, NULL),
		('UNIF_TITLE', '680', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, NULL),
		('UNIF_TITLE', '681', 'Beispiel für die Schlagwortverweisung', 'Beispiel für die Schlagwortverweisung', 1, 0, NULL),
		('UNIF_TITLE', '682', 'Angaben zu gelöschten Ansetzungen', 'Angaben zu gelöschten Ansetzungen', 0, 0, NULL),
		('UNIF_TITLE', '683', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('UNIF_TITLE', '688', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('UNIF_TITLE', '730', 'Verknüpfungseintragung für normierte Ansetzungen - Einheitstitel', 'Verknüpfungseintragung für normierte Ansetzungen - Einheitstitel', 1, 0, NULL),
		('UNIF_TITLE', '788', 'Komplexe Verknüpfungseintragungsdaten', 'Komplexe Verknüpfungseintragungsdaten', 0, 0, NULL),
		('UNIF_TITLE', '856', 'Elektronische Adresse und Zugriff', 'Elektronische Adresse und Zugriff', 1, 0, NULL),
		('UNIF_TITLE', '880', 'Andersschriftliche Darstellung', 'Andersschriftliche Darstellung', 1, 0, NULL),
        ('UNIF_TITLE', '942', 'Interne Verwendung (KOHA)', 'Interne Verwendung (KOHA)', 0, 1, NULL);


INSERT INTO `auth_subfield_structure` (`authtypecode`, `tagfield`, `tagsubfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `tab`, `authorised_value`, `value_builder`, `seealso`, `isurl`, `hidden`, `linkid`, `kohafield`, `frameworkcode`) VALUES
		('UNIF_TITLE', '000', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_leader_authorities.pl', NULL, 0, 0, '', '', ''),
                ('UNIF_TITLE', '001', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', 'auth_header.authid', ''),
                ('UNIF_TITLE', '003', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
                ('UNIF_TITLE', '005', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_005.pl', NULL, 0, 0, '', '', ''),
                ('UNIF_TITLE', '008', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_field_008_authorities.pl', NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '010', 'a', 'LoC-Kontrollnummer', 'LoC-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '010', 'z', 'Gelöschte/ungültige LoC-Kontrollnummer', 'Gelöschte/ungültige LoC-Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '010', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '014', 'a', 'Kontrollnummer des verwandten bibliografischen Datensatzes', 'Kontrollnummer des verwandten bibliografischen Datensatzes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '014', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '014', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '016', 'a', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '016', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '016', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '016', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '020', 'a', 'Internationale Standardbuchnummer', 'Internationale Standardbuchnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '020', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '020', 'z', 'Gelöschte/ungültige ISBN', 'Gelöschte/ungültige ISBN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '020', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '020', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '022', 'a', 'Internationale Standardseriennummer', 'Internationale Standardseriennummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '022', 'y', 'Falsche ISSN', 'Falsche ISSN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '022', 'z', 'Gelöschte ISSN', 'Gelöschte ISSN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '022', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '022', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '024', 'a', 'Standardnummer oder Code', 'Standardnummer oder Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '024', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '024', 'd', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '024', 'z', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '024', '2', 'Quelle der Nummer oder des Codes', 'Quelle der Nummer oder des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '024', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '024', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 'a', 'Number of work', 'Number of work', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 'b', 'Satznummer', 'Satznummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 'c', 'Nummer des Ausschnitts', 'Nummer des Ausschnitts', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 'd', 'Titel oder Ansetzung', 'Titel oder Ansetzung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 'e', 'Partie', 'Partie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 'g', 'Notenschlüssel', 'Notenschlüssel', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 'm', 'Stimme/Instrument', 'Stimme/Instrument', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 'n', 'Tonartvorzeichen', 'Tonartvorzeichen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 'o', 'Taktvorzeichen', 'Taktvorzeichen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 'p', 'Musikalische Notierung', 'Musikalische Notierung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 'q', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 'r', 'Tonart oder Modus', 'Tonart oder Modus', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 's', 'Kodierte Fußnote zur Echtheit', 'Kodierte Fußnote zur Echtheit', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 't', 'Text-Incipit', 'Text-Incipit', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', '2', 'Systemcode', 'Systemcode', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '031', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 'd', 'Koordinaten - westlichster Längengrad', 'Koordinaten - westlichster Längengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 'e', 'Koordinaten - östlichster Längengrad', 'Koordinaten - östlichster Längengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 'f', 'Koordinaten - nördlichster Breitengrad', 'Koordinaten - nördlichster Breitengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 'g', 'Koordinaten - südlichster Breitengrad', 'Koordinaten - südlichster Breitengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 'j', 'Deklination - nördliche Grenze', 'Deklination - nördliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 'k', 'Deklination - südliche Grenze', 'Deklination - südliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 'm', 'Rektaszension - östliche Grenze', 'Rektaszension - östliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 'n', 'Rektaszension - westliche Grenze', 'Rektaszension - westliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 'p', 'Äquinoktium', 'Äquinoktium', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 'r', 'Entfernung von der Erde', 'Entfernung von der Erde', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 's', 'G-Ring Breitengrad', 'G-Ring Breitengrad', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 't', 'G-Ring Längengrad', 'G-Ring Längengrad', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 'x', 'Anfangsdatum', 'Anfangsdatum', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 'y', 'Enddatum', 'Enddatum', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', 'z', 'Name des außerirdischen Himmelskörpers', 'Name des außerirdischen Himmelskörpers', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '034', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '035', 'a', 'System-Kontrollnummer', 'System-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '035', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '035', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '035', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '040', 'a', 'Original-Katalogisierungsstelle', 'Original-Katalogisierungsstelle', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '040', 'b', 'Katalogisierungssprache', 'Katalogisierungssprache', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '040', 'c', 'Übertragungsstelle', 'Übertragungsstelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '040', 'd', 'Bearbeitungsstelle', 'Bearbeitungsstelle', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '040', 'e', 'Beschreibungsfestlegungen', 'Beschreibungsfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '040', 'f', 'Schlagwort- oder Thesaurusfestlegungen', 'Schlagwort- oder Thesaurusfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '040', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '040', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '042', 'a', 'Authentifizierungscode', 'Authentifizierungscode', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '043', 'a', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '043', 'b', 'Lokaler GAC-Code', 'Lokaler GAC-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '043', 'c', 'ISO-Code', 'ISO-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '043', '2', 'Quelle des lokalen Codes', 'Quelle des lokalen Codes', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '043', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '043', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '045', 'a', 'Zeitabschnitts-Code', 'Zeitabschnitts-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '045', 'b', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '045', 'c', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '045', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '045', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '050', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '050', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '050', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '050', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '050', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '050', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '052', 'a', 'Klassifikation des geografischen Gebiets', 'Klassifikation des geografischen Gebiets', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '052', 'b', 'Klassifikation des geografischen Teilgebiets', 'Klassifikation des geografischen Teilgebiets', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '052', 'd', 'Eingetragener Ortsname', 'Eingetragener Ortsname', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '052', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '052', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '052', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '053', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '053', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '053', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '053', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '053', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '053', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '055', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '055', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '055', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '055', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '055', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '055', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '060', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '060', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '060', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '060', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '060', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '060', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '065', 'a', 'Classification number element--single number or beginning of span', 'Classification number element--single number or beginning of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '065', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '065', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '065', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '065', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '065', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '065', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '066', 'a', 'Primärer G0-Zeichensatz', 'Primärer G0-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '066', 'b', 'Primärer G1-Zeichensatz', 'Primärer G1-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '066', 'c', 'Wechselnder G0- oder G1-Zeichensatz', 'Wechselnder G0- oder G1-Zeichensatz', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '070', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '070', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '070', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '070', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '070', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '072', 'a', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '072', 'x', 'Subject category code subdivision', 'Subject category code subdivision', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '072', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '072', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '072', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '073', 'a', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '073', 'z', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '073', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '073', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '082', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '082', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '082', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '082', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '082', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '082', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '082', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '083', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '083', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '083', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '083', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '083', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '083', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '083', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '083', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '086', 'a', 'Signatur', 'Signatur', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '086', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '086', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '086', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '086', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '086', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '086', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '087', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '087', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '087', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '087', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '087', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '087', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 'a', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 'b', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 'e', 'Feature heading (OCLC)', 'Feature heading (OCLC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 'f', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 'h', 'Output transaction history, HST (RLIN)', 'Output transaction history, HST (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 'i', 'Output transaction instruction, INS (RLIN)', 'Output transaction instruction, INS (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 'l', 'Extra card control statement, EXT (RLIN)', 'Extra card control statement, EXT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 'n', 'Additional local notes, ANT (RLIN)', 'Additional local notes, ANT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 'p', 'Pathfinder code, PTH (RLIN)', 'Pathfinder code, PTH (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 't', 'Field suppresion, FSP (RLIN)', 'Field suppresion, FSP (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 'v', 'Volumes, VOL (RLIN)', 'Volumes, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 'y', 'Date, VOL (RLIN)', 'Date, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '090', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '091', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '091', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '091', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '091', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '091', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '091', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '091', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '091', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '092', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '092', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '092', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '092', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '092', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '092', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '092', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '092', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '092', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '093', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '093', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '093', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '093', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '093', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '093', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '093', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '093', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '096', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '096', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '096', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '096', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '096', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '096', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '096', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '096', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '096', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '097', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '097', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '097', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '097', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '097', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '097', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '097', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '097', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '098', 'a', 'Call number based on other classification scheme', 'Call number based on other classification scheme', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '098', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '098', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '098', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '098', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '098', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '098', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '098', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '098', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '099', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '099', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '099', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '099', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '099', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '099', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '099', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '099', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '099', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 1, NULL, NULL, '''130o'',''130m'',''130r'',''130s'',''130d'',''130k'',''130n'',''130p'',''130g'',''130l'',''130f'',''130h'',''130t'',''130x'',''130z'',''130y'',''130v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'h', 'Medium', 'Medium', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'r', 'Tonart', 'Tonart', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 's', 'Version', 'Version', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '130', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '260', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '260', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '260', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '260', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '360', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '360', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '360', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '360', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'a', 'Personenname', 'Personenname', 0, 0, 4, NULL, NULL, '''400b'',''400c'',''400q'',''400d'',''400t'',''400o'',''400m'',''400r'',''400s'',''400k'',''400n'',''400p'',''400g'',''400l'',''400f'',''400h'',''400x'',''400z'',''400y'',''400v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'b', 'Zählung', 'Zählung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '400', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''410b'',''410c'',''410d'',''410t'',''410o'',''410m'',''410r'',''410s'',''410k'',''410n'',''410p'',''410g'',''410l'',''410f'',''410h'',''410x'',''410z'',''410y'',''410v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '410', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''411e'',''411c'',''411d'',''411t'',''411s'',''411k'',''411n'',''411p'',''411g'',''411l'',''411f'',''411h'',''411x'',''411z'',''411y'',''411v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'b', 'Nummer [OBSOLET]', 'Nummer [OBSOLET]', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '411', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 4, NULL, NULL, '''430o'',''430m'',''430r'',''430s'',''430d'',''430k'',''430n'',''430p'',''430g'',''430l'',''430f'',''430h'',''430t'',''430x'',''430z'',''430y'',''430v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '430', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '448', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 4, NULL, NULL, '''448y'',''448x'',''448z'',''448v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '448', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '448', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '448', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '448', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '448', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '448', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '448', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '448', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '448', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '450', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 4, NULL, NULL, '''450x'',''450z'',''450y'',''450v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '450', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '450', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '450', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '450', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '450', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '450', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '450', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '450', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '450', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '450', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '451', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 4, NULL, NULL, '''451z'',''451x'',''451y'',''451v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '451', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '451', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '451', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '451', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '451', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '451', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '451', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '451', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '451', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '455', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 4, NULL, NULL, '''455v'',''455x'',''455z'',''455y''', 0, 0, '', '', ''),
		('UNIF_TITLE', '455', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '455', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '455', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '455', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '455', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '455', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '455', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '455', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '455', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '480', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '480', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '480', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '480', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '480', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '480', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '480', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '480', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '480', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '481', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '481', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '481', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '481', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '481', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '481', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '481', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '481', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '481', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '482', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '482', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '482', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '482', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '482', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '482', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '482', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '482', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '482', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '485', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '485', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '485', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '485', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '485', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '485', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '485', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '485', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '485', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'a', 'Personenname', 'Personenname', 0, 0, 5, NULL, NULL, '''500b'',''500c'',''500q'',''500d'',''500t'',''500o'',''500m'',''500r'',''500s'',''500k'',''500n'',''500p'',''500g'',''500l'',''500f'',''500h'',''500x'',''500z'',''500y'',''500v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'b', 'Zählung', 'Zählung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '500', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''510b'',''510c'',''510d'',''510t'',''510o'',''510m'',''510r'',''510s'',''510k'',''510n'',''510p'',''510g'',''510l'',''510f'',''510h'',''510x'',''510z'',''510y'',''510v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '510', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''511e'',''511c'',''511d'',''511t'',''511s'',''511k'',''511n'',''511p'',''511g'',''511l'',''511f'',''511h'',''511x'',''511z'',''511y'',''511v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '511', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 5, NULL, NULL, '''530o'',''530m'',''530r'',''530s'',''530d'',''530k'',''530n'',''530p'',''530g'',''530l'',''530f'',''530h'',''530t'',''530x'',''530z'',''530y'',''530v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '530', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '548', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 5, NULL, NULL, '''548y'',''548x'',''548z'',''548v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '548', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '548', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '548', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '548', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '548', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '548', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '548', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '548', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '548', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '548', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '550', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 5, NULL, NULL, '''550x'',''550z'',''550y'',''550v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '550', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '550', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '550', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '550', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '550', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '550', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '550', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '550', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '550', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '550', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '550', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '551', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 5, NULL, NULL, '''551z'',''551x'',''551y'',''551v''', 0, 0, '', '', ''),
		('UNIF_TITLE', '551', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '551', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '551', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '551', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '551', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '551', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '551', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '551', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '551', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '551', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '555', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 5, NULL, NULL, '''555v'',''555x'',''555z'',''555y''', 0, 0, '', '', ''),
		('UNIF_TITLE', '555', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '555', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '555', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '555', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '555', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '555', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '555', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '555', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '555', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '555', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '580', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '580', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '580', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '580', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '580', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '580', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '580', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '580', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '580', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '580', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '581', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '581', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '581', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '581', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '581', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '581', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '581', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '581', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '581', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '581', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '582', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '582', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '582', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '582', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '582', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '582', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '582', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '582', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '582', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '582', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '585', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '585', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '585', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '585', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '585', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '585', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '585', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '585', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '585', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '585', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '640', 'a', 'Erscheinungsjahr und/oder Erscheinungsverlauf', 'Erscheinungsjahr und/oder Erscheinungsverlauf', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '640', 'z', 'Quelle der Information', 'Quelle der Information', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '640', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '640', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '641', 'a', 'Fußnote zu Besonderheiten der Zählung', 'Fußnote zu Besonderheiten der Zählung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '641', 'z', 'Quelle der Information', 'Quelle der Information', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '641', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '641', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '642', 'a', 'Beispiel für die Zählung von Gesamttiteln', 'Beispiel für die Zählung von Gesamttiteln', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '642', 'd', 'Band-/Datumsangaben, auf die sich das Beispiel für die Zählung von Gesamttiteln bezieht', 'Band-/Datumsangaben, auf die sich das Beispiel für die Zählung von Gesamttiteln bezieht', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '642', '5', 'Institution/Kopie, auf die sich das Feld bezieht', 'Institution/Kopie, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '642', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '642', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '643', 'a', 'Ort', 'Ort', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '643', 'b', 'Herausgebende Körperschaft', 'Herausgebende Körperschaft', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '643', 'd', 'Band-/Datumsangaben, auf die sich Ort und herausgebende Körperschaft bezieht', 'Band-/Datumsangaben, auf die sich Ort und herausgebende Körperschaft bezieht', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '643', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '643', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '644', 'a', 'Analyse-Praxis von Gesamttiteln', 'Analyse-Praxis von Gesamttiteln', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '644', 'b', 'Ausnahmen von der Analyse-Praxis', 'Ausnahmen von der Analyse-Praxis', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '644', 'd', 'Band-/Datumsangaben auf die sich die Analyse-Praxis beziehen', 'Band-/Datumsangaben auf die sich die Analyse-Praxis beziehen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '644', '5', 'Institution/Kopie, auf die sich das Feld bezieht', 'Institution/Kopie, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '644', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '644', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '645', 'a', 'Verweisungspraxis von Gesamttiteln', 'Verweisungspraxis von Gesamttiteln', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '645', 'd', 'Band-/Datumsangaben, auf die sich die Verweisungs-Praxis beziehen', 'Band-/Datumsangaben, auf die sich die Verweisungs-Praxis beziehen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '645', '5', 'Institution/Kopie, auf die sich das Feld bezieht', 'Institution/Kopie, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '645', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '645', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '646', 'a', 'Klassifizierungspraxis von Gesamttiteln', 'Klassifizierungspraxis von Gesamttiteln', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '646', 'd', 'Band-/Datumsangaben, auf die sich die Klassifizierungspraxis beziehen', 'Band-/Datumsangaben, auf die sich die Klassifizierungspraxis beziehen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '646', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '646', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '646', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '663', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '663', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '663', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '663', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '663', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '664', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '664', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '664', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '664', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '664', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '665', 'a', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '665', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '665', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '666', 'a', 'Allgemeine Hinweiserläuterung', 'Allgemeine Hinweiserläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '666', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '666', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '667', 'a', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '667', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '667', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '667', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '670', 'a', 'Quellenangabe', 'Quellenangabe', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '670', 'b', 'Vorhandene Informationen', 'Vorhandene Informationen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '670', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '670', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '670', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '675', 'a', 'Quellenangabe', 'Quellenangabe', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '675', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '675', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '678', 'a', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '678', 'b', 'Erweiterung', 'Erweiterung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '678', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '678', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '678', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '680', 'a', 'Ansetzung oder Unterteilung', 'Ansetzung oder Unterteilung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '680', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '680', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '680', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '680', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '680', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '681', 'a', 'Schlagwort- oder Unterteilungsansetzung', 'Schlagwort- oder Unterteilungsansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '681', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '681', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '681', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '681', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '682', 'a', 'Zu ersetzende Ansetzung', 'Zu ersetzende Ansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '682', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '682', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '682', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '683', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '683', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '683', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '683', 'p', 'Corresponding classification field', 'Corresponding classification field', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '683', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '683', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '683', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '683', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '683', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '688', 'a', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '688', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '688', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '688', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'h', 'Medium', 'Medium', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'r', 'Tonart', 'Tonart', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 's', 'Version', 'Version', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '730', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '788', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '788', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '788', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '788', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '788', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '788', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '788', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'a', 'Host-Name', 'Host-Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'b', 'Zugriffsnummer', 'Zugriffsnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'c', 'Angaben zur Komprimierung', 'Angaben zur Komprimierung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'd', 'Pfad', 'Pfad', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'f', 'Elektronischer Name', 'Elektronischer Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'h', 'Bearbeiter der Anfrage', 'Bearbeiter der Anfrage', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'i', 'Anweisung', 'Anweisung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'j', 'Bits pro Sekunde', 'Bits pro Sekunde', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'k', 'Passwort', 'Passwort', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'l', 'Login', 'Login', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'm', 'Kontaktstelle für Hilfe beim Zugriff', 'Kontaktstelle für Hilfe beim Zugriff', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'n', 'Name des Standortes des Hosts', 'Name des Standortes des Hosts', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'o', 'Betriebssystem', 'Betriebssystem', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'p', 'Port', 'Port', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'q', 'Elektronisches Format', 'Elektronisches Format', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'r', 'Einstellungen', 'Einstellungen', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 's', 'Dateigröße', 'Dateigröße', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 't', 'Terminalemulation', 'Terminalemulation', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'v', 'Zugriffszeiten', 'Zugriffszeiten', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'w', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'x', 'Interne Anmerkungen', 'Interne Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'y', 'Verlinkungstext', 'Verlinkungstext', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', 'z', 'Allgemeine Anmerkungen', 'Allgemeine Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', '2', 'Zugriffsart', 'Zugriffsart', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', '3', 'Spezifische Materialangaben', 'Spezifische Materialangaben', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '856', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'a', 'a', 'a', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'b', 'b', 'b', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'c', 'c', 'c', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'd', 'd', 'd', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'e', 'e', 'e', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'f', 'f', 'f', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'g', 'g', 'g', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'h', 'h', 'h', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'i', 'i', 'i', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'j', 'j', 'j', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'k', 'k', 'k', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'l', 'l', 'l', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'm', 'm', 'm', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'n', 'n', 'n', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'o', 'o', 'o', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'p', 'p', 'p', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'q', 'q', 'q', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'r', 'r', 'r', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 's', 's', 's', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 't', 't', 't', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'u', 'u', 'u', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'v', 'v', 'v', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'w', 'w', 'w', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'x', 'x', 'x', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'y', 'y', 'y', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', 'z', 'z', 'z', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', '0', '0', '0', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', '1', '1', '1', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', '2', '2', '2', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', '3', '3', '3', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', '4', '4', '4', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', '5', '5', '5', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', '6', '6', '6', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', '7', '7', '7', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', '8', '8', '8', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '880', '9', '9', '9', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('UNIF_TITLE', '942', 'a', 'Koha-Normdatentyp', 'Koha-Normdatentyp', 0, 1, 9, NULL, NULL, NULL, 0, 8, '', 'auth_header.authtypecode', '');


-- ******************************************************



-- *******************************************************************
-- TOPICAL TERM AUTHORITY FIELDS/SUBFIELDS.
-- *******************************************************************

-- These ought to be adjusted for different less conflicting and more
-- rationally chosen fields and subfields but I had left that for last.

-- ADJUST ME
-- Use values from your dump of auth_tag_structure and auth_subfield_structure
-- to provide support for your Koha database.


INSERT INTO `auth_tag_structure` (`authtypecode`, `tagfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `authorised_value`) VALUES
		('CHRON_TERM', '000', 'Leader', 'Leader', 0, 1, NULL),
		('CHRON_TERM', '001', 'Kontrollnummer', 'Kontrollnummer', 0, 1, NULL),
		('CHRON_TERM', '003', 'Kontrollnummer-Identifier', 'Kontrollnummer-Identifier', 0, 1, NULL),
		('CHRON_TERM', '005', 'Datum und Zeit der letzten Transaktion', 'Datum und Zeit der letzten Transaktion', 0, 1, NULL),
		('CHRON_TERM', '008', 'Datenelemente mit fester Länge', 'Datenelemente mit fester Länge', 0, 1, NULL),
		('CHRON_TERM', '010', 'Kontrollnummer der Library of Congress', 'Kontrollnummer der Library of Congress', 0, 0, NULL),
		('CHRON_TERM', '016', 'Kontrollnummer der nationalen bibliografischen Stelle', 'Kontrollnummer der nationalen bibliografischen Stelle', 1, 0, NULL),
		('CHRON_TERM', '024', 'Anderer Standard-Identifier', 'Anderer Standard-Identifier', 1, 0, NULL),
		('CHRON_TERM', '034', 'Kodierte kartografische mathematische Daten', 'Kodierte kartografische mathematische Daten', 1, 0, NULL),
		('CHRON_TERM', '035', 'System-Kontrollnummer', 'System-Kontrollnummer', 1, 0, NULL),
		('CHRON_TERM', '040', 'Katalogisierungsquelle', 'Katalogisierungsquelle', 0, 1, NULL),
		('CHRON_TERM', '042', 'Authentifizierungscode', 'Authentifizierungscode', 0, 0, NULL),
		('CHRON_TERM', '043', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 0, 0, NULL),
		('CHRON_TERM', '045', 'Zeitabschnitt der Ansetzung', 'Zeitabschnitt der Ansetzung', 0, 0, NULL),
		('CHRON_TERM', '050', 'Signatur der Library of Congress', 'Signatur der Library of Congress', 1, 0, NULL),
		('CHRON_TERM', '052', 'Geografische Klassifikation', 'Geografische Klassifikation', 1, 0, NULL),
		('CHRON_TERM', '053', 'Notation der LC', 'Notation der LC', 1, 0, NULL),
		('CHRON_TERM', '055', 'Signatur der Library and Archives Canada', 'Signatur der Library and Archives Canada', 1, 0, NULL),
		('CHRON_TERM', '060', 'Signatur der National Library of Medicine', 'Signatur der National Library of Medicine', 1, 0, NULL),
		('CHRON_TERM', '065', 'Andere Notation', 'Andere Notation', 1, 0, NULL),
		('CHRON_TERM', '066', 'Angewendete Zeichensätze', 'Angewendete Zeichensätze', 0, 0, NULL),
		('CHRON_TERM', '070', 'Signatur der National Agricultural Library', 'Signatur der National Agricultural Library', 1, 0, NULL),
		('CHRON_TERM', '072', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 1, 0, NULL),
		('CHRON_TERM', '073', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 0, 0, NULL),
		('CHRON_TERM', '082', 'Dewey-Dezimal-Signatur', 'Dewey-Dezimal-Signatur', 1, 0, NULL),
		('CHRON_TERM', '083', 'DDC-Notation', 'DDC-Notation', 1, 0, NULL),
		('CHRON_TERM', '086', 'Signatur für Amtsdruckschriften', 'Signatur für Amtsdruckschriften', 1, 0, NULL),
		('CHRON_TERM', '087', 'Notation fürs Amtsdruckschriften', 'Notation fürs Amtsdruckschriften', 1, 0, NULL),
		('CHRON_TERM', '090', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (RLIN)', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (OCLC)', 1, 0, NULL),
		('CHRON_TERM', '091', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 0, 0, NULL),
		('CHRON_TERM', '092', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 1, 0, NULL),
		('CHRON_TERM', '093', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('CHRON_TERM', '096', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 1, 0, NULL),
		('CHRON_TERM', '097', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('CHRON_TERM', '098', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 1, 0, NULL),
		('CHRON_TERM', '099', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 1, 0, NULL),
		('CHRON_TERM', '148', 'Ansetzung - Zeitschlagwort', 'Ansetzung - Zeitschlagwort', 0, 0, NULL),
		('CHRON_TERM', '182', 'Ansetzung - Chronologische Unterteilung', 'Ansetzung - Chronologische Unterteilung', 0, 0, NULL),
		('CHRON_TERM', '260', 'Komplexer Siehe-Hinweis - Schlagwort', 'Komplexer Siehe-Hinweis - Schlagwort', 1, 0, NULL),
		('CHRON_TERM', '360', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 1, 0, NULL),
		('CHRON_TERM', '400', 'Siehe-Verweisung - Personenname', 'Siehe-Verweisung - Personenname', 1, 0, NULL),
		('CHRON_TERM', '410', 'Siehe-Verweisung - Körperschaftsname', 'Siehe-Verweisung - Körperschaftsname', 1, 0, NULL),
		('CHRON_TERM', '411', 'Siehe-Verweisung - Kongressname', 'Siehe-Verweisung - Kongressname', 1, 0, NULL),
		('CHRON_TERM', '430', 'Siehe-Verweisung - Einheitstitel', 'Siehe-Verweisung - Einheitstitel', 1, 0, NULL),
		('CHRON_TERM', '448', 'Siehe-Verweisung - Zeitschlagwort', 'Siehe-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('CHRON_TERM', '450', 'Siehe-Verweisung - Sachschlagwort', 'Siehe-Verweisung - Sachschlagwort', 1, 0, NULL),
		('CHRON_TERM', '451', 'Siehe-Verweisung - Geografischer Name', 'Siehe-Verweisung - Geografischer Name', 1, 0, NULL),
		('CHRON_TERM', '455', 'Siehe-Verweisung - Genre/Formschlagwort', 'Siehe-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('CHRON_TERM', '480', 'Siehe-Verweisung - Allgemeine Unterteilung', 'Siehe-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('CHRON_TERM', '481', 'Siehe-Verweisung - Geografische Unterteilung', 'Siehe-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('CHRON_TERM', '482', 'Siehe-Verweisung - Chronologische Unterteilung', 'Siehe-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('CHRON_TERM', '485', 'Siehe-Verweisung - Unterteilung nach Form', 'Siehe-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('CHRON_TERM', '500', 'Siehe-auch-Verweisung - Personenname', 'Siehe-auch-Verweisung - Personenname', 1, 0, NULL),
		('CHRON_TERM', '510', 'Siehe-auch-Verweisung - Körperschaftsname', 'Siehe-auch-Verweisung - Körperschaftsname', 1, 0, NULL),
		('CHRON_TERM', '511', 'Siehe-auch-Verweisung - Kongressname', 'Siehe-auch-Verweisung - Kongressname', 1, 0, NULL),
		('CHRON_TERM', '530', 'Siehe-auch-Verweisung - Einheitstitel', 'Siehe-auch-Verweisung - Einheitstitel', 1, 0, NULL),
		('CHRON_TERM', '548', 'Siehe-auch-Verweisung - Zeitschlagwort', 'Siehe-auch-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('CHRON_TERM', '550', 'Siehe-auch-Verweisung - Sachschlagwort', 'Siehe-auch-Verweisung - Sachschlagwort', 1, 0, NULL),
		('CHRON_TERM', '551', 'Siehe-auch-Verweisung - Geografischer Name', 'Siehe-auch-Verweisung - Geografischer Name', 1, 0, NULL),
		('CHRON_TERM', '555', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('CHRON_TERM', '580', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('CHRON_TERM', '581', 'Siehe-auch-Verweisung - Geografische Unterteilung', 'Siehe-auch-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('CHRON_TERM', '582', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('CHRON_TERM', '585', 'Siehe-auch-Verweisung - Unterteilung nach Form', 'Siehe-auch-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('CHRON_TERM', '663', 'Komplexe Siehe-auch-Verweisung - Name', 'Komplexe Siehe-auch-Verweisung - Name', 0, 0, NULL),
		('CHRON_TERM', '664', 'Komplexe Siehe-Verweisung - Name', 'Komplexe Siehe-Verweisung - Name', 0, 0, NULL),
		('CHRON_TERM', '665', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 0, 0, NULL),
		('CHRON_TERM', '666', 'Allgemein erläuternde Verweisung - Name', 'Allgemein erläuternde Verweisung - Name', 0, 0, NULL),
		('CHRON_TERM', '667', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 1, 0, NULL),
		('CHRON_TERM', '670', 'Datenquelle', 'Datenquelle', 1, 0, NULL),
		('CHRON_TERM', '675', 'Datenquelle ohne Information', 'Datenquelle ohne Information', 0, 0, NULL),
		('CHRON_TERM', '678', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, NULL),
		('CHRON_TERM', '680', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, NULL),
		('CHRON_TERM', '681', 'Beispiel für die Schlagwortverweisung', 'Beispiel für die Schlagwortverweisung', 1, 0, NULL),
		('CHRON_TERM', '682', 'Angaben zu gelöschten Ansetzungen', 'Angaben zu gelöschten Ansetzungen', 0, 0, NULL),
		('CHRON_TERM', '683', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('CHRON_TERM', '688', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('CHRON_TERM', '748', 'Verknüpfungseintragung für normierte Ansetzungen - Zeitschlagwort', 'Verknüpfungseintragung für normierte Ansetzungen - Zeitschlagwort', 1, 0, NULL),
		('CHRON_TERM', '782', 'Verknüpfungseintragung der Unterteilung - Chronologische Unterteilung', 'Verknüpfungseintragung der Unterteilung - Chronologische Unterteilung', 1, 0, NULL),
		('CHRON_TERM', '788', 'Komplexe Verknüpfungseintragungsdaten', 'Komplexe Verknüpfungseintragungsdaten', 0, 0, NULL),
		('CHRON_TERM', '856', 'Elektronische Adresse und Zugriff', 'Elektronische Adresse und Zugriff', 1, 0, NULL),
		('CHRON_TERM', '880', 'Andersschriftliche Darstellung', 'Andersschriftliche Darstellung', 1, 0, NULL),
        ('CHRON_TERM', '942', 'Interne Verwendung (KOHA)', 'Interne Verwendung (KOHA)', 0, 1, NULL);


INSERT INTO `auth_subfield_structure` (`authtypecode`, `tagfield`, `tagsubfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `tab`, `authorised_value`, `value_builder`, `seealso`, `isurl`, `hidden`, `linkid`, `kohafield`, `frameworkcode`) VALUES
		('CHRON_TERM', '000', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_leader_authorities.pl', NULL, 0, 0, '', '', ''),
                ('CHRON_TERM', '001', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', 'auth_header.authid', ''),
                ('CHRON_TERM', '003', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
                ('CHRON_TERM', '005', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_005.pl', NULL, 0, 0, '', '', ''),
                ('CHRON_TERM', '008', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_field_008_authorities.pl', NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '010', 'a', 'LoC-Kontrollnummer', 'LoC-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '010', 'z', 'Gelöschte/ungültige LoC-Kontrollnummer', 'Gelöschte/ungültige LoC-Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '010', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '016', 'a', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '016', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '016', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '016', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '024', 'a', 'Standardnummer oder Code', 'Standardnummer oder Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '024', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '024', 'd', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '024', 'z', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '024', '2', 'Quelle der Nummer oder des Codes', 'Quelle der Nummer oder des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '024', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '024', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 'd', 'Koordinaten - westlichster Längengrad', 'Koordinaten - westlichster Längengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 'e', 'Koordinaten - östlichster Längengrad', 'Koordinaten - östlichster Längengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 'f', 'Koordinaten - nördlichster Breitengrad', 'Koordinaten - nördlichster Breitengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 'g', 'Koordinaten - südlichster Breitengrad', 'Koordinaten - südlichster Breitengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 'j', 'Deklination - nördliche Grenze', 'Deklination - nördliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 'k', 'Deklination - südliche Grenze', 'Deklination - südliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 'm', 'Rektaszension - östliche Grenze', 'Rektaszension - östliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 'n', 'Rektaszension - westliche Grenze', 'Rektaszension - westliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 'p', 'Äquinoktium', 'Äquinoktium', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 'r', 'Entfernung von der Erde', 'Entfernung von der Erde', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 's', 'G-Ring Breitengrad', 'G-Ring Breitengrad', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 't', 'G-Ring Längengrad', 'G-Ring Längengrad', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 'x', 'Anfangsdatum', 'Anfangsdatum', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 'y', 'Enddatum', 'Enddatum', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', 'z', 'Name des außerirdischen Himmelskörpers', 'Name des außerirdischen Himmelskörpers', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '034', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '035', 'a', 'System-Kontrollnummer', 'System-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '035', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '035', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '035', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '040', 'a', 'Original-Katalogisierungsstelle', 'Original-Katalogisierungsstelle', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '040', 'b', 'Katalogisierungssprache', 'Katalogisierungssprache', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '040', 'c', 'Übertragungsstelle', 'Übertragungsstelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '040', 'd', 'Bearbeitungsstelle', 'Bearbeitungsstelle', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '040', 'e', 'Beschreibungsfestlegungen', 'Beschreibungsfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '040', 'f', 'Schlagwort- oder Thesaurusfestlegungen', 'Schlagwort- oder Thesaurusfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '040', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '040', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '042', 'a', 'Authentifizierungscode', 'Authentifizierungscode', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '043', 'a', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '043', 'b', 'Lokaler GAC-Code', 'Lokaler GAC-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '043', 'c', 'ISO-Code', 'ISO-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '043', '2', 'Quelle des lokalen Codes', 'Quelle des lokalen Codes', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '043', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '043', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '045', 'a', 'Zeitabschnitts-Code', 'Zeitabschnitts-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '045', 'b', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '045', 'c', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '045', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '045', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '050', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '050', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '050', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '050', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '050', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '050', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '052', 'a', 'Klassifikation des geografischen Gebiets', 'Klassifikation des geografischen Gebiets', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '052', 'b', 'Klassifikation des geografischen Teilgebiets', 'Klassifikation des geografischen Teilgebiets', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '052', 'd', 'Eingetragener Ortsname', 'Eingetragener Ortsname', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '052', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '052', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '052', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '053', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '053', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '053', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '053', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '053', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '053', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '055', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '055', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '055', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '055', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '055', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '055', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '060', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '060', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '060', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '060', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '060', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '060', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '065', 'a', 'Classification number element--single number or beginning of span', 'Classification number element--single number or beginning of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '065', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '065', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '065', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '065', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '065', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '065', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '066', 'a', 'Primärer G0-Zeichensatz', 'Primärer G0-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '066', 'b', 'Primärer G1-Zeichensatz', 'Primärer G1-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '066', 'c', 'Wechselnder G0- oder G1-Zeichensatz', 'Wechselnder G0- oder G1-Zeichensatz', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '070', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '070', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '070', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '070', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '070', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '072', 'a', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '072', 'x', 'Subject category code subdivision', 'Subject category code subdivision', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '072', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '072', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '072', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '073', 'a', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '073', 'z', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '073', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '073', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '082', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '082', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '082', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '082', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '082', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '082', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '082', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '083', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '083', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '083', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '083', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '083', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '083', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '083', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '083', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '086', 'a', 'Signatur', 'Signatur', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '086', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '086', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '086', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '086', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '086', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '086', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '087', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '087', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '087', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '087', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '087', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '087', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 'a', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 'b', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 'e', 'Feature heading (OCLC)', 'Feature heading (OCLC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 'f', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 'h', 'Output transaction history, HST (RLIN)', 'Output transaction history, HST (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 'i', 'Output transaction instruction, INS (RLIN)', 'Output transaction instruction, INS (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 'l', 'Extra card control statement, EXT (RLIN)', 'Extra card control statement, EXT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 'n', 'Additional local notes, ANT (RLIN)', 'Additional local notes, ANT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 'p', 'Pathfinder code, PTH (RLIN)', 'Pathfinder code, PTH (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 't', 'Field suppresion, FSP (RLIN)', 'Field suppresion, FSP (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 'v', 'Volumes, VOL (RLIN)', 'Volumes, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 'y', 'Date, VOL (RLIN)', 'Date, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '090', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '091', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '091', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '091', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '091', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '091', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '091', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '091', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '091', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '092', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '092', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '092', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '092', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '092', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '092', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '092', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '092', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '092', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '093', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '093', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '093', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '093', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '093', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '093', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '093', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '093', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '096', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '096', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '096', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '096', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '096', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '096', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '096', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '096', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '096', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '097', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '097', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '097', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '097', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '097', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '097', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '097', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '097', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '098', 'a', 'Call number based on other classification scheme', 'Call number based on other classification scheme', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '098', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '098', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '098', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '098', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '098', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '098', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '098', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '098', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '099', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '099', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '099', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '099', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '099', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '099', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '099', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '099', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '099', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '148', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 1, NULL, NULL, '''148y'',''148x'',''148z'',''148v''', 0, 0, '', '', ''),
		('CHRON_TERM', '148', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '148', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '148', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '148', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '148', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '148', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '182', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '182', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '182', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '182', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '182', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '182', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '260', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '260', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '260', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '260', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '360', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '360', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '360', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '360', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'a', 'Personenname', 'Personenname', 0, 0, 4, NULL, NULL, '''400b'',''400c'',''400q'',''400d'',''400t'',''400o'',''400m'',''400r'',''400s'',''400k'',''400n'',''400p'',''400g'',''400l'',''400f'',''400h'',''400x'',''400z'',''400y'',''400v''', 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'b', 'Zählung', 'Zählung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '400', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''410b'',''410c'',''410d'',''410t'',''410o'',''410m'',''410r'',''410s'',''410k'',''410n'',''410p'',''410g'',''410l'',''410f'',''410h'',''410x'',''410z'',''410y'',''410v''', 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '410', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''411e'',''411c'',''411d'',''411t'',''411s'',''411k'',''411n'',''411p'',''411g'',''411l'',''411f'',''411h'',''411x'',''411z'',''411y'',''411v''', 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'b', 'Nummer [OBSOLET]', 'Nummer [OBSOLET]', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '411', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 4, NULL, NULL, '''430o'',''430m'',''430r'',''430s'',''430d'',''430k'',''430n'',''430p'',''430g'',''430l'',''430f'',''430h'',''430t'',''430x'',''430z'',''430y'',''430v''', 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '430', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '448', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 4, NULL, NULL, '''448y'',''448x'',''448z'',''448v''', 0, 0, '', '', ''),
		('CHRON_TERM', '448', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '448', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '448', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '448', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '448', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '448', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '448', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '448', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '448', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '450', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 4, NULL, NULL, '''450x'',''450z'',''450y'',''450v''', 0, 0, '', '', ''),
		('CHRON_TERM', '450', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '450', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '450', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '450', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '450', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '450', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '450', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '450', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '450', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '450', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '451', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 4, NULL, NULL, '''451z'',''451x'',''451y'',''451v''', 0, 0, '', '', ''),
		('CHRON_TERM', '451', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '451', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '451', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '451', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '451', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '451', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '451', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '451', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '451', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '455', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 4, NULL, NULL, '''455v'',''455x'',''455z'',''455y''', 0, 0, '', '', ''),
		('CHRON_TERM', '455', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '455', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '455', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '455', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '455', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '455', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '455', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '455', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '455', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '480', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '480', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '480', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '480', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '480', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '480', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '480', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '480', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '480', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '481', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '481', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '481', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '481', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '481', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '481', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '481', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '481', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '481', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '482', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '482', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '482', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '482', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '482', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '482', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '482', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '482', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '482', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '485', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '485', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '485', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '485', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '485', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '485', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '485', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '485', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '485', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'a', 'Personenname', 'Personenname', 0, 0, 5, NULL, NULL, '''500b'',''500c'',''500q'',''500d'',''500t'',''500o'',''500m'',''500r'',''500s'',''500k'',''500n'',''500p'',''500g'',''500l'',''500f'',''500h'',''500x'',''500z'',''500y'',''500v''', 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'b', 'Zählung', 'Zählung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '500', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''510b'',''510c'',''510d'',''510t'',''510o'',''510m'',''510r'',''510s'',''510k'',''510n'',''510p'',''510g'',''510l'',''510f'',''510h'',''510x'',''510z'',''510y'',''510v''', 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '510', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''511e'',''511c'',''511d'',''511t'',''511s'',''511k'',''511n'',''511p'',''511g'',''511l'',''511f'',''511h'',''511x'',''511z'',''511y'',''511v''', 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '511', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 5, NULL, NULL, '''530o'',''530m'',''530r'',''530s'',''530d'',''530k'',''530n'',''530p'',''530g'',''530l'',''530f'',''530h'',''530t'',''530x'',''530z'',''530y'',''530v''', 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '530', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '548', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 5, NULL, NULL, '''548y'',''548x'',''548z'',''548v''', 0, 0, '', '', ''),
		('CHRON_TERM', '548', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '548', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '548', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '548', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '548', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '548', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '548', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '548', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '548', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '548', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '550', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 5, NULL, NULL, '''550x'',''550z'',''550y'',''550v''', 0, 0, '', '', ''),
		('CHRON_TERM', '550', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '550', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '550', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '550', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '550', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '550', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '550', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '550', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '550', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '550', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '550', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '551', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 5, NULL, NULL, '''551z'',''551x'',''551y'',''551v''', 0, 0, '', '', ''),
		('CHRON_TERM', '551', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '551', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '551', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '551', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '551', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '551', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '551', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '551', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '551', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '551', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '555', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 5, NULL, NULL, '''555v'',''555x'',''555z'',''555y''', 0, 0, '', '', ''),
		('CHRON_TERM', '555', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '555', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '555', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '555', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '555', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '555', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '555', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '555', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '555', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '555', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '580', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '580', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '580', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '580', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '580', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '580', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '580', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '580', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '580', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '580', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '581', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '581', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '581', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '581', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '581', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '581', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '581', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '581', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '581', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '581', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '582', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '582', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '582', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '582', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '582', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '582', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '582', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '582', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '582', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '582', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '585', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '585', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '585', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '585', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '585', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '585', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '585', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '585', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '585', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '585', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '663', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '663', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '663', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '663', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '663', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '664', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '664', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '664', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '664', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '664', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '665', 'a', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '665', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '665', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '666', 'a', 'Allgemeine Hinweiserläuterung', 'Allgemeine Hinweiserläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '666', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '666', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '667', 'a', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '667', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '667', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '667', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '670', 'a', 'Quellenangabe', 'Quellenangabe', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '670', 'b', 'Vorhandene Informationen', 'Vorhandene Informationen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '670', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '670', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '670', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '675', 'a', 'Quellenangabe', 'Quellenangabe', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '675', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '675', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '678', 'a', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '678', 'b', 'Erweiterung', 'Erweiterung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '678', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '678', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '678', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '680', 'a', 'Ansetzung oder Unterteilung', 'Ansetzung oder Unterteilung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '680', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '680', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '680', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '680', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '680', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '681', 'a', 'Schlagwort- oder Unterteilungsansetzung', 'Schlagwort- oder Unterteilungsansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '681', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '681', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '681', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '681', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '682', 'a', 'Zu ersetzende Ansetzung', 'Zu ersetzende Ansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '682', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '682', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '682', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '683', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '683', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '683', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '683', 'p', 'Corresponding classification field', 'Corresponding classification field', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '683', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '683', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '683', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '683', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '683', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '688', 'a', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '688', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '688', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '688', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '748', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '748', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '748', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '748', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '748', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '748', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '748', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '748', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '748', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '748', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '748', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '782', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '782', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '782', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '782', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '782', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '782', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '782', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '782', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '782', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '782', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '788', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '788', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '788', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '788', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '788', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '788', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '788', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'a', 'Host-Name', 'Host-Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'b', 'Zugriffsnummer', 'Zugriffsnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'c', 'Angaben zur Komprimierung', 'Angaben zur Komprimierung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'd', 'Pfad', 'Pfad', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'f', 'Elektronischer Name', 'Elektronischer Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'h', 'Bearbeiter der Anfrage', 'Bearbeiter der Anfrage', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'i', 'Anweisung', 'Anweisung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'j', 'Bits pro Sekunde', 'Bits pro Sekunde', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'k', 'Passwort', 'Passwort', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'l', 'Login', 'Login', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'm', 'Kontaktstelle für Hilfe beim Zugriff', 'Kontaktstelle für Hilfe beim Zugriff', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'n', 'Name des Standortes des Hosts', 'Name des Standortes des Hosts', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'o', 'Betriebssystem', 'Betriebssystem', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'p', 'Port', 'Port', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'q', 'Elektronisches Format', 'Elektronisches Format', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'r', 'Einstellungen', 'Einstellungen', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 's', 'Dateigröße', 'Dateigröße', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 't', 'Terminalemulation', 'Terminalemulation', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'v', 'Zugriffszeiten', 'Zugriffszeiten', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'w', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'x', 'Interne Anmerkungen', 'Interne Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'y', 'Verlinkungstext', 'Verlinkungstext', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', 'z', 'Allgemeine Anmerkungen', 'Allgemeine Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', '2', 'Zugriffsart', 'Zugriffsart', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', '3', 'Spezifische Materialangaben', 'Spezifische Materialangaben', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '856', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'a', 'a', 'a', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'b', 'b', 'b', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'c', 'c', 'c', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'd', 'd', 'd', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'e', 'e', 'e', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'f', 'f', 'f', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'g', 'g', 'g', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'h', 'h', 'h', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'i', 'i', 'i', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'j', 'j', 'j', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'k', 'k', 'k', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'l', 'l', 'l', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'm', 'm', 'm', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'n', 'n', 'n', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'o', 'o', 'o', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'p', 'p', 'p', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'q', 'q', 'q', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'r', 'r', 'r', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 's', 's', 's', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 't', 't', 't', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'u', 'u', 'u', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'v', 'v', 'v', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'w', 'w', 'w', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'x', 'x', 'x', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'y', 'y', 'y', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', 'z', 'z', 'z', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', '0', '0', '0', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', '1', '1', '1', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', '2', '2', '2', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', '3', '3', '3', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', '4', '4', '4', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', '5', '5', '5', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', '6', '6', '6', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', '7', '7', '7', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', '8', '8', '8', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '880', '9', '9', '9', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('CHRON_TERM', '942', 'a', 'Koha-Normdatentyp', 'Koha-Normdatentyp', 0, 1, 9, NULL, NULL, NULL, 0, 8, '', 'auth_header.authtypecode', '');


-- ******************************************************



-- *******************************************************************
-- TOPICAL TERM AUTHORITY FIELDS/SUBFIELDS.
-- *******************************************************************

-- These ought to be adjusted for different less conflicting and more
-- rationally chosen fields and subfields but I had left that for last.

-- ADJUST ME
-- Use values from your dump of auth_tag_structure and auth_subfield_structure
-- to provide support for your Koha database.


INSERT INTO `auth_tag_structure` (`authtypecode`, `tagfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `authorised_value`) VALUES
		('TOPIC_TERM', '000', 'Leader', 'Leader', 0, 1, NULL),
		('TOPIC_TERM', '001', 'Kontrollnummer', 'Kontrollnummer', 0, 1, NULL),
		('TOPIC_TERM', '003', 'Kontrollnummer-Identifier', 'Kontrollnummer-Identifier', 0, 1, NULL),
		('TOPIC_TERM', '005', 'Datum und Zeit der letzten Transaktion', 'Datum und Zeit der letzten Transaktion', 0, 1, NULL),
		('TOPIC_TERM', '008', 'Datenelemente mit fester Länge', 'Datenelemente mit fester Länge', 0, 1, NULL),
		('TOPIC_TERM', '010', 'Kontrollnummer der Library of Congress', 'Kontrollnummer der Library of Congress', 0, 0, NULL),
		('TOPIC_TERM', '016', 'Kontrollnummer der nationalen bibliografischen Stelle', 'Kontrollnummer der nationalen bibliografischen Stelle', 1, 0, NULL),
		('TOPIC_TERM', '024', 'Anderer Standard-Identifier', 'Anderer Standard-Identifier', 1, 0, NULL),
		('TOPIC_TERM', '034', 'Kodierte kartografische mathematische Daten', 'Kodierte kartografische mathematische Daten', 1, 0, NULL),
		('TOPIC_TERM', '035', 'System-Kontrollnummer', 'System-Kontrollnummer', 1, 0, NULL),
		('TOPIC_TERM', '040', 'Katalogisierungsquelle', 'Katalogisierungsquelle', 0, 1, NULL),
		('TOPIC_TERM', '042', 'Authentifizierungscode', 'Authentifizierungscode', 0, 0, NULL),
		('TOPIC_TERM', '043', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 0, 0, NULL),
		('TOPIC_TERM', '045', 'Zeitabschnitt der Ansetzung', 'Zeitabschnitt der Ansetzung', 0, 0, NULL),
		('TOPIC_TERM', '050', 'Signatur der Library of Congress', 'Signatur der Library of Congress', 1, 0, NULL),
		('TOPIC_TERM', '052', 'Geografische Klassifikation', 'Geografische Klassifikation', 1, 0, NULL),
		('TOPIC_TERM', '053', 'Notation der LC', 'Notation der LC', 1, 0, NULL),
		('TOPIC_TERM', '055', 'Signatur der Library and Archives Canada', 'Signatur der Library and Archives Canada', 1, 0, NULL),
		('TOPIC_TERM', '060', 'Signatur der National Library of Medicine', 'Signatur der National Library of Medicine', 1, 0, NULL),
		('TOPIC_TERM', '065', 'Andere Notation', 'Andere Notation', 1, 0, NULL),
		('TOPIC_TERM', '066', 'Angewendete Zeichensätze', 'Angewendete Zeichensätze', 0, 0, NULL),
		('TOPIC_TERM', '070', 'Signatur der National Agricultural Library', 'Signatur der National Agricultural Library', 1, 0, NULL),
		('TOPIC_TERM', '072', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 1, 0, NULL),
		('TOPIC_TERM', '073', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 0, 0, NULL),
		('TOPIC_TERM', '082', 'Dewey-Dezimal-Signatur', 'Dewey-Dezimal-Signatur', 1, 0, NULL),
		('TOPIC_TERM', '083', 'DDC-Notation', 'DDC-Notation', 1, 0, NULL),
		('TOPIC_TERM', '086', 'Signatur für Amtsdruckschriften', 'Signatur für Amtsdruckschriften', 1, 0, NULL),
		('TOPIC_TERM', '087', 'Notation fürs Amtsdruckschriften', 'Notation fürs Amtsdruckschriften', 1, 0, NULL),
		('TOPIC_TERM', '090', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (RLIN)', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (OCLC)', 1, 0, NULL),
		('TOPIC_TERM', '091', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 0, 0, NULL),
		('TOPIC_TERM', '092', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 1, 0, NULL),
		('TOPIC_TERM', '093', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('TOPIC_TERM', '096', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 1, 0, NULL),
		('TOPIC_TERM', '097', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('TOPIC_TERM', '098', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 1, 0, NULL),
		('TOPIC_TERM', '099', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 1, 0, NULL),
		('TOPIC_TERM', '150', 'Ansetzung - Sachschlagwort', 'Ansetzung - Sachschlagwort', 0, 0, NULL),
		('TOPIC_TERM', '180', 'Ansetzung - Allgemeine Unterteilung', 'Ansetzung - Allgemeine Unterteilung', 0, 0, NULL),
		('TOPIC_TERM', '260', 'Komplexer Siehe-Hinweis - Schlagwort', 'Komplexer Siehe-Hinweis - Schlagwort', 1, 0, NULL),
		('TOPIC_TERM', '360', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 1, 0, NULL),
		('TOPIC_TERM', '400', 'Siehe-Verweisung - Personenname', 'Siehe-Verweisung - Personenname', 1, 0, NULL),
		('TOPIC_TERM', '410', 'Siehe-Verweisung - Körperschaftsname', 'Siehe-Verweisung - Körperschaftsname', 1, 0, NULL),
		('TOPIC_TERM', '411', 'Siehe-Verweisung - Kongressname', 'Siehe-Verweisung - Kongressname', 1, 0, NULL),
		('TOPIC_TERM', '430', 'Siehe-Verweisung - Einheitstitel', 'Siehe-Verweisung - Einheitstitel', 1, 0, NULL),
		('TOPIC_TERM', '448', 'Siehe-Verweisung - Zeitschlagwort', 'Siehe-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('TOPIC_TERM', '450', 'Siehe-Verweisung - Sachschlagwort', 'Siehe-Verweisung - Sachschlagwort', 1, 0, NULL),
		('TOPIC_TERM', '451', 'Siehe-Verweisung - Geografischer Name', 'Siehe-Verweisung - Geografischer Name', 1, 0, NULL),
		('TOPIC_TERM', '455', 'Siehe-Verweisung - Genre/Formschlagwort', 'Siehe-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('TOPIC_TERM', '480', 'Siehe-Verweisung - Allgemeine Unterteilung', 'Siehe-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('TOPIC_TERM', '481', 'Siehe-Verweisung - Geografische Unterteilung', 'Siehe-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('TOPIC_TERM', '482', 'Siehe-Verweisung - Chronologische Unterteilung', 'Siehe-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('TOPIC_TERM', '485', 'Siehe-Verweisung - Unterteilung nach Form', 'Siehe-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('TOPIC_TERM', '500', 'Siehe-auch-Verweisung - Personenname', 'Siehe-auch-Verweisung - Personenname', 1, 0, NULL),
		('TOPIC_TERM', '510', 'Siehe-auch-Verweisung - Körperschaftsname', 'Siehe-auch-Verweisung - Körperschaftsname', 1, 0, NULL),
		('TOPIC_TERM', '511', 'Siehe-auch-Verweisung - Kongressname', 'Siehe-auch-Verweisung - Kongressname', 1, 0, NULL),
		('TOPIC_TERM', '530', 'Siehe-auch-Verweisung - Einheitstitel', 'Siehe-auch-Verweisung - Einheitstitel', 1, 0, NULL),
		('TOPIC_TERM', '548', 'Siehe-auch-Verweisung - Zeitschlagwort', 'Siehe-auch-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('TOPIC_TERM', '550', 'Siehe-auch-Verweisung - Sachschlagwort', 'Siehe-auch-Verweisung - Sachschlagwort', 1, 0, NULL),
		('TOPIC_TERM', '551', 'Siehe-auch-Verweisung - Geografischer Name', 'Siehe-auch-Verweisung - Geografischer Name', 1, 0, NULL),
		('TOPIC_TERM', '555', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('TOPIC_TERM', '580', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('TOPIC_TERM', '581', 'Siehe-auch-Verweisung - Geografische Unterteilung', 'Siehe-auch-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('TOPIC_TERM', '582', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('TOPIC_TERM', '585', 'Siehe-auch-Verweisung - Unterteilung nach Form', 'Siehe-auch-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('TOPIC_TERM', '663', 'Komplexe Siehe-auch-Verweisung - Name', 'Komplexe Siehe-auch-Verweisung - Name', 0, 0, NULL),
		('TOPIC_TERM', '664', 'Komplexe Siehe-Verweisung - Name', 'Komplexe Siehe-Verweisung - Name', 0, 0, NULL),
		('TOPIC_TERM', '665', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 0, 0, NULL),
		('TOPIC_TERM', '666', 'Allgemein erläuternde Verweisung - Name', 'Allgemein erläuternde Verweisung - Name', 0, 0, NULL),
		('TOPIC_TERM', '667', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 1, 0, NULL),
		('TOPIC_TERM', '670', 'Datenquelle', 'Datenquelle', 1, 0, NULL),
		('TOPIC_TERM', '675', 'Datenquelle ohne Information', 'Datenquelle ohne Information', 0, 0, NULL),
		('TOPIC_TERM', '678', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, NULL),
		('TOPIC_TERM', '680', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, NULL),
		('TOPIC_TERM', '681', 'Beispiel für die Schlagwortverweisung', 'Beispiel für die Schlagwortverweisung', 1, 0, NULL),
		('TOPIC_TERM', '682', 'Angaben zu gelöschten Ansetzungen', 'Angaben zu gelöschten Ansetzungen', 0, 0, NULL),
		('TOPIC_TERM', '683', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('TOPIC_TERM', '688', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('TOPIC_TERM', '750', 'Verknüpfungselement für normierte Ansetzungen - Sachschlagwort', 'Verknüpfungselement für normierte Ansetzungen - Sachschlagwort', 1, 0, NULL),
		('TOPIC_TERM', '780', 'Verknüpfungseintragung der Unterteilung - Allgemeine Unterteilung', 'Verknüpfungseintragung der Unterteilung - Allgemeine Unterteilung', 1, 0, NULL),
		('TOPIC_TERM', '788', 'Komplexe Verknüpfungseintragungsdaten', 'Komplexe Verknüpfungseintragungsdaten', 0, 0, NULL),
		('TOPIC_TERM', '856', 'Elektronische Adresse und Zugriff', 'Elektronische Adresse und Zugriff', 1, 0, NULL),
		('TOPIC_TERM', '880', 'Andersschriftliche Darstellung', 'Andersschriftliche Darstellung', 1, 0, NULL),
        ('TOPIC_TERM', '942', 'Interne Verwendung (KOHA)', 'Interne Verwendung (KOHA)', 0, 1, NULL);


INSERT INTO `auth_subfield_structure` (`authtypecode`, `tagfield`, `tagsubfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `tab`, `authorised_value`, `value_builder`, `seealso`, `isurl`, `hidden`, `linkid`, `kohafield`, `frameworkcode`) VALUES
		('TOPIC_TERM', '000', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_leader_authorities.pl', NULL, 0, 0, '', '', ''),
                ('TOPIC_TERM', '001', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', 'auth_header.authid', ''),
                ('TOPIC_TERM', '003', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
                ('TOPIC_TERM', '005', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_005.pl', NULL, 0, 0, '', '', ''),
                ('TOPIC_TERM', '008', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_field_008_authorities.pl', NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '010', 'a', 'LoC-Kontrollnummer', 'LoC-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '010', 'z', 'Gelöschte/ungültige LoC-Kontrollnummer', 'Gelöschte/ungültige LoC-Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '010', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '016', 'a', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '016', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '016', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '016', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '024', 'a', 'Standardnummer oder Code', 'Standardnummer oder Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '024', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '024', 'd', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '024', 'z', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '024', '2', 'Quelle der Nummer oder des Codes', 'Quelle der Nummer oder des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '024', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '024', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 'd', 'Koordinaten - westlichster Längengrad', 'Koordinaten - westlichster Längengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 'e', 'Koordinaten - östlichster Längengrad', 'Koordinaten - östlichster Längengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 'f', 'Koordinaten - nördlichster Breitengrad', 'Koordinaten - nördlichster Breitengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 'g', 'Koordinaten - südlichster Breitengrad', 'Koordinaten - südlichster Breitengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 'j', 'Deklination - nördliche Grenze', 'Deklination - nördliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 'k', 'Deklination - südliche Grenze', 'Deklination - südliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 'm', 'Rektaszension - östliche Grenze', 'Rektaszension - östliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 'n', 'Rektaszension - westliche Grenze', 'Rektaszension - westliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 'p', 'Äquinoktium', 'Äquinoktium', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 'r', 'Entfernung von der Erde', 'Entfernung von der Erde', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 's', 'G-Ring Breitengrad', 'G-Ring Breitengrad', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 't', 'G-Ring Längengrad', 'G-Ring Längengrad', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 'x', 'Anfangsdatum', 'Anfangsdatum', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 'y', 'Enddatum', 'Enddatum', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', 'z', 'Name des außerirdischen Himmelskörpers', 'Name des außerirdischen Himmelskörpers', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '034', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '035', 'a', 'System-Kontrollnummer', 'System-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '035', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '035', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '035', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '040', 'a', 'Original-Katalogisierungsstelle', 'Original-Katalogisierungsstelle', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '040', 'b', 'Katalogisierungssprache', 'Katalogisierungssprache', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '040', 'c', 'Übertragungsstelle', 'Übertragungsstelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '040', 'd', 'Bearbeitungsstelle', 'Bearbeitungsstelle', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '040', 'e', 'Beschreibungsfestlegungen', 'Beschreibungsfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '040', 'f', 'Schlagwort- oder Thesaurusfestlegungen', 'Schlagwort- oder Thesaurusfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '040', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '040', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '042', 'a', 'Authentifizierungscode', 'Authentifizierungscode', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '043', 'a', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '043', 'b', 'Lokaler GAC-Code', 'Lokaler GAC-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '043', 'c', 'ISO-Code', 'ISO-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '043', '2', 'Quelle des lokalen Codes', 'Quelle des lokalen Codes', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '043', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '043', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '045', 'a', 'Zeitabschnitts-Code', 'Zeitabschnitts-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '045', 'b', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '045', 'c', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '045', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '045', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '050', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '050', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '050', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '050', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '050', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '050', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '052', 'a', 'Klassifikation des geografischen Gebiets', 'Klassifikation des geografischen Gebiets', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '052', 'b', 'Klassifikation des geografischen Teilgebiets', 'Klassifikation des geografischen Teilgebiets', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '052', 'd', 'Eingetragener Ortsname', 'Eingetragener Ortsname', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '052', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '052', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '052', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '053', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '053', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '053', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '053', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '053', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '053', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '055', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '055', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '055', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '055', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '055', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '055', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '060', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '060', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '060', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '060', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '060', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '060', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '065', 'a', 'Classification number element--single number or beginning of span', 'Classification number element--single number or beginning of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '065', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '065', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '065', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '065', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '065', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '065', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '066', 'a', 'Primärer G0-Zeichensatz', 'Primärer G0-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '066', 'b', 'Primärer G1-Zeichensatz', 'Primärer G1-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '066', 'c', 'Wechselnder G0- oder G1-Zeichensatz', 'Wechselnder G0- oder G1-Zeichensatz', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '070', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '070', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '070', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '070', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '070', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '072', 'a', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '072', 'x', 'Subject category code subdivision', 'Subject category code subdivision', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '072', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '072', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '072', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '073', 'a', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '073', 'z', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '073', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '073', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '082', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '082', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '082', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '082', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '082', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '082', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '082', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '083', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '083', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '083', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '083', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '083', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '083', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '083', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '083', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '086', 'a', 'Signatur', 'Signatur', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '086', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '086', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '086', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '086', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '086', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '086', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '087', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '087', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '087', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '087', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '087', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '087', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 'a', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 'b', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 'e', 'Feature heading (OCLC)', 'Feature heading (OCLC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 'f', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 'h', 'Output transaction history, HST (RLIN)', 'Output transaction history, HST (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 'i', 'Output transaction instruction, INS (RLIN)', 'Output transaction instruction, INS (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 'l', 'Extra card control statement, EXT (RLIN)', 'Extra card control statement, EXT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 'n', 'Additional local notes, ANT (RLIN)', 'Additional local notes, ANT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 'p', 'Pathfinder code, PTH (RLIN)', 'Pathfinder code, PTH (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 't', 'Field suppresion, FSP (RLIN)', 'Field suppresion, FSP (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 'v', 'Volumes, VOL (RLIN)', 'Volumes, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 'y', 'Date, VOL (RLIN)', 'Date, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '090', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '091', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '091', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '091', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '091', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '091', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '091', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '091', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '091', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '092', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '092', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '092', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '092', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '092', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '092', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '092', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '092', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '092', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '093', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '093', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '093', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '093', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '093', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '093', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '093', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '093', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '096', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '096', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '096', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '096', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '096', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '096', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '096', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '096', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '096', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '097', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '097', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '097', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '097', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '097', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '097', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '097', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '097', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '098', 'a', 'Call number based on other classification scheme', 'Call number based on other classification scheme', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '098', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '098', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '098', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '098', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '098', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '098', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '098', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '098', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '099', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '099', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '099', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '099', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '099', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '099', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '099', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '099', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '099', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '150', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 1, NULL, NULL, '''150x'',''150z'',''150y'',''150v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '150', 'b', 'Einem geografischen Namen folgendes Sachschlagwort als Eintragungselement', 'Einem geografischen Namen folgendes Sachschlagwort als Eintragungselement', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '150', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '150', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '150', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '150', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '150', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '150', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '180', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '180', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '180', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '180', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '180', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '180', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '260', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '260', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '260', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '260', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '360', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '360', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '360', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '360', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'a', 'Personenname', 'Personenname', 0, 0, 4, NULL, NULL, '''400b'',''400c'',''400q'',''400d'',''400t'',''400o'',''400m'',''400r'',''400s'',''400k'',''400n'',''400p'',''400g'',''400l'',''400f'',''400h'',''400x'',''400z'',''400y'',''400v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'b', 'Zählung', 'Zählung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '400', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''410b'',''410c'',''410d'',''410t'',''410o'',''410m'',''410r'',''410s'',''410k'',''410n'',''410p'',''410g'',''410l'',''410f'',''410h'',''410x'',''410z'',''410y'',''410v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '410', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''411e'',''411c'',''411d'',''411t'',''411s'',''411k'',''411n'',''411p'',''411g'',''411l'',''411f'',''411h'',''411x'',''411z'',''411y'',''411v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'b', 'Nummer {OBSOLET]', 'Nummer {OBSOLET]', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '411', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 4, NULL, NULL, '''430o'',''430m'',''430r'',''430s'',''430d'',''430k'',''430n'',''430p'',''430g'',''430l'',''430f'',''430h'',''430t'',''430x'',''430z'',''430y'',''430v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '430', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '448', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 4, NULL, NULL, '''448y'',''448x'',''448z'',''448v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '448', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '448', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '448', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '448', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '448', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '448', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '448', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '448', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '448', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '450', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 4, NULL, NULL, '''450x'',''450z'',''450y'',''450v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '450', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '450', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '450', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '450', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '450', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '450', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '450', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '450', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '450', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '450', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '451', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 4, NULL, NULL, '''451z'',''451x'',''451y'',''451v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '451', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '451', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '451', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '451', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '451', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '451', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '451', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '451', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '451', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '455', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 4, NULL, NULL, '''455v'',''455x'',''455z'',''455y''', 0, 0, '', '', ''),
		('TOPIC_TERM', '455', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '455', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '455', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '455', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '455', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '455', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '455', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '455', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '455', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '480', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '480', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '480', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '480', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '480', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '480', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '480', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '480', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '480', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '481', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '481', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '481', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '481', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '481', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '481', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '481', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '481', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '481', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '482', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '482', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '482', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '482', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '482', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '482', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '482', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '482', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '482', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '485', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '485', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '485', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '485', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '485', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '485', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '485', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '485', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '485', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'a', 'Personenname', 'Personenname', 0, 0, 5, NULL, NULL, '''500b'',''500c'',''500q'',''500d'',''500t'',''500o'',''500m'',''500r'',''500s'',''500k'',''500n'',''500p'',''500g'',''500l'',''500f'',''500h'',''500x'',''500z'',''500y'',''500v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'b', 'Zählung', 'Zählung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '500', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''510b'',''510c'',''510d'',''510t'',''510o'',''510m'',''510r'',''510s'',''510k'',''510n'',''510p'',''510g'',''510l'',''510f'',''510h'',''510x'',''510z'',''510y'',''510v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '510', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''511e'',''511c'',''511d'',''511t'',''511s'',''511k'',''511n'',''511p'',''511g'',''511l'',''511f'',''511h'',''511x'',''511z'',''511y'',''511v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '511', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 5, NULL, NULL, '''530o'',''530m'',''530r'',''530s'',''530d'',''530k'',''530n'',''530p'',''530g'',''530l'',''530f'',''530h'',''530t'',''530x'',''530z'',''530y'',''530v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '530', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '548', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 5, NULL, NULL, '''548y'',''548x'',''548z'',''548v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '548', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '548', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '548', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '548', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '548', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '548', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '548', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '548', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '548', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '548', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '550', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 5, NULL, NULL, '''550x'',''550z'',''550y'',''550v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '550', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '550', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '550', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '550', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '550', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '550', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '550', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '550', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '550', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '550', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '550', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '551', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 5, NULL, NULL, '''551z'',''551x'',''551y'',''551v''', 0, 0, '', '', ''),
		('TOPIC_TERM', '551', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '551', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '551', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '551', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '551', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '551', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '551', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '551', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '551', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '551', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '555', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 5, NULL, NULL, '''555v'',''555x'',''555z'',''555y''', 0, 0, '', '', ''),
		('TOPIC_TERM', '555', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '555', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '555', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '555', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '555', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '555', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '555', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '555', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '555', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '555', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '580', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '580', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '580', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '580', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '580', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '580', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '580', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '580', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '580', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '580', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '581', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '581', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '581', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '581', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '581', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '581', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '581', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '581', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '581', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '581', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '582', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '582', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '582', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '582', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '582', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '582', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '582', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '582', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '582', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '582', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '585', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '585', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '585', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '585', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '585', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '585', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '585', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '585', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '585', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '585', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '663', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '663', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '663', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '663', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '663', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '664', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '664', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '664', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '664', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '664', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '665', 'a', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '665', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '665', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '666', 'a', 'Allgemeine Hinweiserläuterung', 'Allgemeine Hinweiserläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '666', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '666', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '667', 'a', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '667', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '667', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '667', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '670', 'a', 'Quellenangabe', 'Quellenangabe', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '670', 'b', 'Vorhandene Informationen', 'Vorhandene Informationen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '670', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '670', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '670', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '675', 'a', 'Quellenangabe', 'Quellenangabe', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '675', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '675', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '678', 'a', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '678', 'b', 'Erweiterung', 'Erweiterung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '678', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '678', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '678', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '680', 'a', 'Ansetzung oder Unterteilung', 'Ansetzung oder Unterteilung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '680', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '680', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '680', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '680', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '680', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '681', 'a', 'Schlagwort- oder Unterteilungsansetzung', 'Schlagwort- oder Unterteilungsansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '681', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '681', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '681', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '681', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '682', 'a', 'Zu ersetzende Ansetzung', 'Zu ersetzende Ansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '682', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '682', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '682', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '683', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '683', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '683', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '683', 'p', 'Corresponding classification field', 'Corresponding classification field', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '683', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '683', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '683', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '683', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '683', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '688', 'a', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '688', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '688', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '688', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', 'b', 'Einem geografischen Namen folgendes Sachschlagwort als Eintragungselement', 'Einem geografischen Namen folgendes Sachschlagwort als Eintragungselement', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', 'c', 'Location of event', 'Location of event', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', 'd', 'Active date', 'Active date', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '750', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '780', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '780', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '780', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '780', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '780', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '780', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '780', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '780', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '780', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '780', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '788', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '788', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '788', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '788', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '788', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '788', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '788', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'a', 'Host-Name', 'Host-Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'b', 'Zugriffsnummer', 'Zugriffsnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'c', 'Angaben zur Komprimierung', 'Angaben zur Komprimierung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'd', 'Pfad', 'Pfad', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'f', 'Elektronischer Name', 'Elektronischer Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'h', 'Bearbeiter der Anfrage', 'Bearbeiter der Anfrage', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'i', 'Anweisung', 'Anweisung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'j', 'Bits pro Sekunde', 'Bits pro Sekunde', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'k', 'Passwort', 'Passwort', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'l', 'Login', 'Login', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'm', 'Kontaktstelle für Hilfe beim Zugriff', 'Kontaktstelle für Hilfe beim Zugriff', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'n', 'Name des Standortes des Hosts', 'Name des Standortes des Hosts', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'o', 'Betriebssystem', 'Betriebssystem', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'p', 'Port', 'Port', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'q', 'Elektronisches Format', 'Elektronisches Format', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'r', 'Einstellungen', 'Einstellungen', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 's', 'Dateigröße', 'Dateigröße', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 't', 'Terminalemulation', 'Terminalemulation', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'v', 'Zugriffszeiten', 'Zugriffszeiten', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'w', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'x', 'Interne Anmerkungen', 'Interne Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'y', 'Verlinkungstext', 'Verlinkungstext', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', 'z', 'Allgemeine Anmerkungen', 'Allgemeine Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', '2', 'Zugriffsart', 'Zugriffsart', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', '3', 'Spezifische Materialangaben', 'Spezifische Materialangaben', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '856', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'a', 'a', 'a', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'b', 'b', 'b', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'c', 'c', 'c', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'd', 'd', 'd', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'e', 'e', 'e', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'f', 'f', 'f', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'g', 'g', 'g', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'h', 'h', 'h', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'i', 'i', 'i', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'j', 'j', 'j', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'k', 'k', 'k', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'l', 'l', 'l', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'm', 'm', 'm', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'n', 'n', 'n', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'o', 'o', 'o', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'p', 'p', 'p', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'q', 'q', 'q', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'r', 'r', 'r', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 's', 's', 's', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 't', 't', 't', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'u', 'u', 'u', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'v', 'v', 'v', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'w', 'w', 'w', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'x', 'x', 'x', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'y', 'y', 'y', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', 'z', 'z', 'z', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', '0', '0', '0', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', '1', '1', '1', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', '2', '2', '2', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', '3', '3', '3', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', '4', '4', '4', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', '5', '5', '5', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', '6', '6', '6', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', '7', '7', '7', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', '8', '8', '8', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '880', '9', '9', '9', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('TOPIC_TERM', '942', 'a', 'Koha-Normdatentyp', 'Koha-Normdatentyp', 0, 1, 9, NULL, NULL, NULL, 0, 8, '', 'auth_header.authtypecode', '');


-- ******************************************************



-- *******************************************************************
-- GEOGRAPHIC NAME AUTHORITY FIELDS/SUBFIELDS.
-- *******************************************************************

-- These ought to be adjusted for different less conflicting and more
-- rationally chosen fields and subfields but I had left that for last.

-- ADJUST ME
-- Use values from your dump of auth_tag_structure and auth_subfield_structure
-- to provide support for your Koha database.


INSERT INTO `auth_tag_structure` (`authtypecode`, `tagfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `authorised_value`) VALUES
		('GEOGR_NAME', '000', 'Leader', 'Leader', 0, 1, NULL),
		('GEOGR_NAME', '001', 'Kontrollnummer', 'Kontrollnummer', 0, 1, NULL),
		('GEOGR_NAME', '003', 'Kontrollnummer-Identifier', 'Kontrollnummer-Identifier', 0, 1, NULL),
		('GEOGR_NAME', '005', 'Datum und Zeit der letzten Transaktion', 'Datum und Zeit der letzten Transaktion', 0, 1, NULL),
		('GEOGR_NAME', '008', 'Datenelemente mit fester Länge', 'Datenelemente mit fester Länge', 0, 1, NULL),
		('GEOGR_NAME', '010', 'Kontrollnummer der Library of Congress', 'Kontrollnummer der Library of Congress', 0, 0, NULL),
		('GEOGR_NAME', '016', 'Kontrollnummer der nationalen bibliografischen Stelle', 'Kontrollnummer der nationalen bibliografischen Stelle', 1, 0, NULL),
		('GEOGR_NAME', '024', 'Anderer Standard-Identifier', 'Anderer Standard-Identifier', 1, 0, NULL),
		('GEOGR_NAME', '034', 'Kodierte kartografische mathematische Daten', 'Kodierte kartografische mathematische Daten', 1, 0, NULL),
		('GEOGR_NAME', '035', 'System-Kontrollnummer', 'System-Kontrollnummer', 1, 0, NULL),
		('GEOGR_NAME', '040', 'Katalogisierungsquelle', 'Katalogisierungsquelle', 0, 1, NULL),
		('GEOGR_NAME', '042', 'Authentifizierungscode', 'Authentifizierungscode', 0, 0, NULL),
		('GEOGR_NAME', '043', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 0, 0, NULL),
		('GEOGR_NAME', '045', 'Zeitabschnitt der Ansetzung', 'Zeitabschnitt der Ansetzung', 0, 0, NULL),
		('GEOGR_NAME', '050', 'Signatur der Library of Congress', 'Signatur der Library of Congress', 1, 0, NULL),
		('GEOGR_NAME', '052', 'Geografische Klassifikation', 'Geografische Klassifikation', 1, 0, NULL),
		('GEOGR_NAME', '053', 'Notation der LC', 'Notation der LC', 1, 0, NULL),
		('GEOGR_NAME', '055', 'Signatur der Library and Archives Canada', 'Signatur der Library and Archives Canada', 1, 0, NULL),
		('GEOGR_NAME', '060', 'Signatur der National Library of Medicine', 'Signatur der National Library of Medicine', 1, 0, NULL),
		('GEOGR_NAME', '065', 'Andere Notation', 'Andere Notation', 1, 0, NULL),
		('GEOGR_NAME', '066', 'Angewendete Zeichensätze', 'Angewendete Zeichensätze', 0, 0, NULL),
		('GEOGR_NAME', '070', 'Signatur der National Agricultural Library', 'Signatur der National Agricultural Library', 1, 0, NULL),
		('GEOGR_NAME', '072', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 1, 0, NULL),
		('GEOGR_NAME', '073', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 0, 0, NULL),
		('GEOGR_NAME', '082', 'Dewey-Dezimal-Signatur', 'Dewey-Dezimal-Signatur', 1, 0, NULL),
		('GEOGR_NAME', '083', 'DDC-Notation', 'DDC-Notation', 1, 0, NULL),
		('GEOGR_NAME', '086', 'Signatur für Amtsdruckschriften', 'Signatur für Amtsdruckschriften', 1, 0, NULL),
		('GEOGR_NAME', '087', 'Notation fürs Amtsdruckschriften', 'Notation fürs Amtsdruckschriften', 1, 0, NULL),
		('GEOGR_NAME', '090', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (RLIN)', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (OCLC)', 1, 0, NULL),
		('GEOGR_NAME', '091', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 0, 0, NULL),
		('GEOGR_NAME', '092', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 1, 0, NULL),
		('GEOGR_NAME', '093', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('GEOGR_NAME', '096', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 1, 0, NULL),
		('GEOGR_NAME', '097', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('GEOGR_NAME', '098', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 1, 0, NULL),
		('GEOGR_NAME', '099', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 1, 0, NULL),
		('GEOGR_NAME', '151', 'Ansetzung - Geografischer Name', 'Ansetzung - Geografischer Name', 0, 0, NULL),
		('GEOGR_NAME', '181', 'Ansetzung - Geografische Unterteilung', 'Ansetzung - Geografische Unterteilung', 0, 0, NULL),
		('GEOGR_NAME', '260', 'Komplexer Siehe-Hinweis - Schlagwort', 'Komplexer Siehe-Hinweis - Schlagwort', 1, 0, NULL),
		('GEOGR_NAME', '360', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 1, 0, NULL),
		('GEOGR_NAME', '400', 'Siehe-Verweisung - Personenname', 'Siehe-Verweisung - Personenname', 1, 0, NULL),
		('GEOGR_NAME', '410', 'Siehe-Verweisung - Körperschaftsname', 'Siehe-Verweisung - Körperschaftsname', 1, 0, NULL),
		('GEOGR_NAME', '411', 'Siehe-Verweisung - Kongressname', 'Siehe-Verweisung - Kongressname', 1, 0, NULL),
		('GEOGR_NAME', '430', 'Siehe-Verweisung - Einheitstitel', 'Siehe-Verweisung - Einheitstitel', 1, 0, NULL),
		('GEOGR_NAME', '448', 'Siehe-Verweisung - Zeitschlagwort', 'Siehe-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('GEOGR_NAME', '450', 'Siehe-Verweisung - Sachschlagwort', 'Siehe-Verweisung - Sachschlagwort', 1, 0, NULL),
		('GEOGR_NAME', '451', 'Siehe-Verweisung - Geografischer Name', 'Siehe-Verweisung - Geografischer Name', 1, 0, NULL),
		('GEOGR_NAME', '455', 'Siehe-Verweisung - Genre/Formschlagwort', 'Siehe-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('GEOGR_NAME', '480', 'Siehe-Verweisung - Allgemeine Unterteilung', 'Siehe-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('GEOGR_NAME', '481', 'Siehe-Verweisung - Geografische Unterteilung', 'Siehe-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('GEOGR_NAME', '482', 'Siehe-Verweisung - Chronologische Unterteilung', 'Siehe-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('GEOGR_NAME', '485', 'Siehe-Verweisung - Unterteilung nach Form', 'Siehe-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('GEOGR_NAME', '500', 'Siehe-auch-Verweisung - Personenname', 'Siehe-auch-Verweisung - Personenname', 1, 0, NULL),
		('GEOGR_NAME', '510', 'Siehe-auch-Verweisung - Körperschaftsname', 'Siehe-auch-Verweisung - Körperschaftsname', 1, 0, NULL),
		('GEOGR_NAME', '511', 'Siehe-auch-Verweisung - Kongressname', 'Siehe-auch-Verweisung - Kongressname', 1, 0, NULL),
		('GEOGR_NAME', '530', 'Siehe-auch-Verweisung - Einheitstitel', 'Siehe-auch-Verweisung - Einheitstitel', 1, 0, NULL),
		('GEOGR_NAME', '548', 'Siehe-auch-Verweisung - Zeitschlagwort', 'Siehe-auch-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('GEOGR_NAME', '550', 'Siehe-auch-Verweisung - Sachschlagwort', 'Siehe-auch-Verweisung - Sachschlagwort', 1, 0, NULL),
		('GEOGR_NAME', '551', 'Siehe-auch-Verweisung - Geografischer Name', 'Siehe-auch-Verweisung - Geografischer Name', 1, 0, NULL),
		('GEOGR_NAME', '555', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('GEOGR_NAME', '580', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('GEOGR_NAME', '581', 'Siehe-auch-Verweisung - Geografische Unterteilung', 'Siehe-auch-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('GEOGR_NAME', '582', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('GEOGR_NAME', '585', 'Siehe-auch-Verweisung - Unterteilung nach Form', 'Siehe-auch-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('GEOGR_NAME', '663', 'Komplexe Siehe-auch-Verweisung - Name', 'Komplexe Siehe-auch-Verweisung - Name', 0, 0, NULL),
		('GEOGR_NAME', '664', 'Komplexe Siehe-Verweisung - Name', 'Komplexe Siehe-Verweisung - Name', 0, 0, NULL),
		('GEOGR_NAME', '665', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 0, 0, NULL),
		('GEOGR_NAME', '666', 'Allgemein erläuternde Verweisung - Name', 'Allgemein erläuternde Verweisung - Name', 0, 0, NULL),
		('GEOGR_NAME', '667', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 1, 0, NULL),
		('GEOGR_NAME', '670', 'Datenquelle', 'Datenquelle', 1, 0, NULL),
		('GEOGR_NAME', '675', 'Datenquelle ohne Information', 'Datenquelle ohne Information', 0, 0, NULL),
		('GEOGR_NAME', '678', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, NULL),
		('GEOGR_NAME', '680', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, NULL),
		('GEOGR_NAME', '681', 'Beispiel für die Schlagwortverweisung', 'Beispiel für die Schlagwortverweisung', 1, 0, NULL),
		('GEOGR_NAME', '682', 'Angaben zu gelöschten Ansetzungen', 'Angaben zu gelöschten Ansetzungen', 0, 0, NULL),
		('GEOGR_NAME', '683', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('GEOGR_NAME', '688', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('GEOGR_NAME', '751', 'Verknüpfungseintragungen für normierte Ansetzungen - Geografischer Name', 'Verknüpfungseintragungen für normierte Ansetzungen - Geografischer Name', 1, 0, NULL),
		('GEOGR_NAME', '781', 'Verknüpfungseintragung der Unterteilung - Geografische Unterteilung', 'Verknüpfungseintragung der Unterteilung - Geografische Unterteilung', 1, 0, NULL),
		('GEOGR_NAME', '788', 'Komplexe Verknüpfungseintragungsdaten', 'Komplexe Verknüpfungseintragungsdaten', 0, 0, NULL),
		('GEOGR_NAME', '856', 'Elektronische Adresse und Zugriff', 'Elektronische Adresse und Zugriff', 1, 0, NULL),
		('GEOGR_NAME', '880', 'Andersschriftliche Darstellung', 'Andersschriftliche Darstellung', 1, 0, NULL),
        ('GEOGR_NAME', '942', 'Interne Verwendung (KOHA)', 'Interne Verwendung (KOHA)', 0, 1, NULL);


INSERT INTO `auth_subfield_structure` (`authtypecode`, `tagfield`, `tagsubfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `tab`, `authorised_value`, `value_builder`, `seealso`, `isurl`, `hidden`, `linkid`, `kohafield`, `frameworkcode`) VALUES
		('GEOGR_NAME', '000', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_leader_authorities.pl', NULL, 0, 0, '', '', ''),
                ('GEOGR_NAME', '001', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', 'auth_header.authid', ''),
                ('GEOGR_NAME', '003', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
                ('GEOGR_NAME', '005', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_005.pl', NULL, 0, 0, '', '', ''),
                ('GEOGR_NAME', '008', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_field_008_authorities.pl', NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '010', 'a', 'LoC-Kontrollnummer', 'LoC-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '010', 'z', 'Gelöschte/ungültige LoC-Kontrollnummer', 'Gelöschte/ungültige LoC-Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '010', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '016', 'a', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '016', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '016', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '016', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '024', 'a', 'Standardnummer oder Code', 'Standardnummer oder Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '024', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '024', 'd', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '024', 'z', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '024', '2', 'Quelle der Nummer oder des Codes', 'Quelle der Nummer oder des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '024', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '024', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 'd', 'Koordinaten - westlichster Längengrad', 'Koordinaten - westlichster Längengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 'e', 'Koordinaten - östlichster Längengrad', 'Koordinaten - östlichster Längengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 'f', 'Koordinaten - nördlichster Breitengrad', 'Koordinaten - nördlichster Breitengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 'g', 'Koordinaten - südlichster Breitengrad', 'Koordinaten - südlichster Breitengrad', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 'j', 'Deklination - nördliche Grenze', 'Deklination - nördliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 'k', 'Deklination - südliche Grenze', 'Deklination - südliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 'm', 'Rektaszension - östliche Grenze', 'Rektaszension - östliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 'n', 'Rektaszension - westliche Grenze', 'Rektaszension - westliche Grenze', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 'p', 'Äquinoktium', 'Äquinoktium', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 'r', 'Entfernung von der Erde', 'Entfernung von der Erde', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 's', 'G-Ring Breitengrad', 'G-Ring Breitengrad', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 't', 'G-Ring Längengrad', 'G-Ring Längengrad', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 'x', 'Anfangsdatum', 'Anfangsdatum', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 'y', 'Enddatum', 'Enddatum', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', 'z', 'Name des außerirdischen Himmelskörpers', 'Name des außerirdischen Himmelskörpers', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '034', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '035', 'a', 'System-Kontrollnummer', 'System-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '035', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '035', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '035', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '040', 'a', 'Original-Katalogisierungsstelle', 'Original-Katalogisierungsstelle', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '040', 'b', 'Katalogisierungssprache', 'Katalogisierungssprache', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '040', 'c', 'Übertragungsstelle', 'Übertragungsstelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '040', 'd', 'Bearbeitungsstelle', 'Bearbeitungsstelle', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '040', 'e', 'Beschreibungsfestlegungen', 'Beschreibungsfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '040', 'f', 'Schlagwort- oder Thesaurusfestlegungen', 'Schlagwort- oder Thesaurusfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '040', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '040', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '042', 'a', 'Authentifizierungscode', 'Authentifizierungscode', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '043', 'a', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '043', 'b', 'Lokaler GAC-Code', 'Lokaler GAC-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '043', 'c', 'ISO-Code', 'ISO-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '043', '2', 'Quelle des lokalen Codes', 'Quelle des lokalen Codes', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '043', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '043', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '045', 'a', 'Zeitabschnitts-Code', 'Zeitabschnitts-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '045', 'b', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '045', 'c', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '045', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '045', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '050', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '050', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '050', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '050', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '050', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '050', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '052', 'a', 'Klassifikation des geografischen Gebiets', 'Klassifikation des geografischen Gebiets', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '052', 'b', 'Klassifikation des geografischen Teilgebiets', 'Klassifikation des geografischen Teilgebiets', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '052', 'd', 'Eingetragener Ortsname', 'Eingetragener Ortsname', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '052', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '052', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '052', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '053', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '053', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '053', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '053', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '053', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '053', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '055', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '055', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '055', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '055', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '055', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '055', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '060', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '060', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '060', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '060', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '060', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '060', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '065', 'a', 'Classification number element--single number or beginning of span', 'Classification number element--single number or beginning of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '065', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '065', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '065', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '065', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '065', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '065', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '066', 'a', 'Primärer G0-Zeichensatz', 'Primärer G0-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '066', 'b', 'Primärer G1-Zeichensatz', 'Primärer G1-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '066', 'c', 'Wechselnder G0- oder G1-Zeichensatz', 'Wechselnder G0- oder G1-Zeichensatz', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '070', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '070', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '070', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '070', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '070', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '072', 'a', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '072', 'x', 'Subject category code subdivision', 'Subject category code subdivision', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '072', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '072', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '072', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '073', 'a', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '073', 'z', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '073', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '073', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '082', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '082', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '082', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '082', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '082', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '082', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '082', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '083', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '083', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '083', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '083', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '083', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '083', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '083', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '083', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '086', 'a', 'Signatur', 'Signatur', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '086', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '086', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '086', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '086', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '086', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '086', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '087', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '087', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '087', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '087', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '087', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '087', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 'a', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 'b', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 'e', 'Feature heading (OCLC)', 'Feature heading (OCLC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 'f', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 'h', 'Output transaction history, HST (RLIN)', 'Output transaction history, HST (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 'i', 'Output transaction instruction, INS (RLIN)', 'Output transaction instruction, INS (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 'l', 'Extra card control statement, EXT (RLIN)', 'Extra card control statement, EXT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 'n', 'Additional local notes, ANT (RLIN)', 'Additional local notes, ANT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 'p', 'Pathfinder code, PTH (RLIN)', 'Pathfinder code, PTH (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 't', 'Field suppresion, FSP (RLIN)', 'Field suppresion, FSP (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 'v', 'Volumes, VOL (RLIN)', 'Volumes, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 'y', 'Date, VOL (RLIN)', 'Date, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '090', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '091', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '091', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '091', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '091', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '091', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '091', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '091', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '091', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '092', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '092', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '092', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '092', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '092', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '092', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '092', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '092', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '092', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '093', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '093', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '093', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '093', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '093', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '093', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '093', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '093', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '096', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '096', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '096', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '096', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '096', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '096', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '096', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '096', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '096', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '097', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '097', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '097', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '097', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '097', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '097', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '097', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '097', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '098', 'a', 'Call number based on other classification scheme', 'Call number based on other classification scheme', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '098', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '098', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '098', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '098', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '098', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '098', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '098', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '098', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '099', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '099', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '099', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '099', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '099', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '099', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '099', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '099', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '099', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '151', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 1, NULL, NULL, '''151z'',''151x'',''151y'',''151v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '151', 'b', 'Name following place as an entry element {OBSOLETE]', 'Name following place as an entry element {OBSOLETE]', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '151', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '151', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '151', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '151', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '151', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '151', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '181', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '181', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '181', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '181', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '181', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '181', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '260', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '260', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '260', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '260', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '360', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '360', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '360', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '360', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'a', 'Personenname', 'Personenname', 0, 0, 4, NULL, NULL, '''400b'',''400c'',''400q'',''400d'',''400t'',''400o'',''400m'',''400r'',''400s'',''400k'',''400n'',''400p'',''400g'',''400l'',''400f'',''400h'',''400x'',''400z'',''400y'',''400v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'b', 'Zählung', 'Zählung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '400', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''410b'',''410c'',''410d'',''410t'',''410o'',''410m'',''410r'',''410s'',''410k'',''410n'',''410p'',''410g'',''410l'',''410f'',''410h'',''410x'',''410z'',''410y'',''410v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '410', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''411e'',''411c'',''411d'',''411t'',''411s'',''411k'',''411n'',''411p'',''411g'',''411l'',''411f'',''411h'',''411x'',''411z'',''411y'',''411v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'b', 'Nummer [OBSOLET]', 'Nummer [OBSOLET]', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '411', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 4, NULL, NULL, '''430o'',''430m'',''430r'',''430s'',''430d'',''430k'',''430n'',''430p'',''430g'',''430l'',''430f'',''430h'',''430t'',''430x'',''430z'',''430y'',''430v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '430', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '448', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 4, NULL, NULL, '''448y'',''448x'',''448z'',''448v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '448', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '448', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '448', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '448', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '448', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '448', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '448', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '448', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '448', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '450', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 4, NULL, NULL, '''450x'',''450z'',''450y'',''450v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '450', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '450', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '450', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '450', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '450', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '450', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '450', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '450', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '450', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '450', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '451', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 4, NULL, NULL, '''451z'',''451x'',''451y'',''451v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '451', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '451', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '451', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '451', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '451', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '451', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '451', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '451', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '451', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '455', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 4, NULL, NULL, '''455v'',''455x'',''455z'',''455y''', 0, 0, '', '', ''),
		('GEOGR_NAME', '455', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '455', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '455', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '455', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '455', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '455', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '455', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '455', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '455', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '480', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '480', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '480', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '480', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '480', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '480', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '480', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '480', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '480', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '481', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '481', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '481', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '481', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '481', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '481', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '481', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '481', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '481', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '482', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '482', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '482', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '482', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '482', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '482', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '482', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '482', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '482', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '485', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '485', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '485', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '485', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '485', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '485', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '485', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '485', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '485', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'a', 'Personenname', 'Personenname', 0, 0, 5, NULL, NULL, '''500b'',''500c'',''500q'',''500d'',''500t'',''500o'',''500m'',''500r'',''500s'',''500k'',''500n'',''500p'',''500g'',''500l'',''500f'',''500h'',''500x'',''500z'',''500y'',''500v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'b', 'Zählung', 'Zählung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '500', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''510b'',''510c'',''510d'',''510t'',''510o'',''510m'',''510r'',''510s'',''510k'',''510n'',''510p'',''510g'',''510l'',''510f'',''510h'',''510x'',''510z'',''510y'',''510v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '510', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''511e'',''511c'',''511d'',''511t'',''511s'',''511k'',''511n'',''511p'',''511g'',''511l'',''511f'',''511h'',''511x'',''511z'',''511y'',''511v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '511', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 5, NULL, NULL, '''530o'',''530m'',''530r'',''530s'',''530d'',''530k'',''530n'',''530p'',''530g'',''530l'',''530f'',''530h'',''530t'',''530x'',''530z'',''530y'',''530v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '530', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '548', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 5, NULL, NULL, '''548y'',''548x'',''548z'',''548v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '548', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '548', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '548', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '548', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '548', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '548', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '548', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '548', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '548', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '548', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '550', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 5, NULL, NULL, '''550x'',''550z'',''550y'',''550v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '550', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '550', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '550', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '550', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '550', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '550', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '550', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '550', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '550', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '550', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '550', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '551', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 5, NULL, NULL, '''551z'',''551x'',''551y'',''551v''', 0, 0, '', '', ''),
		('GEOGR_NAME', '551', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '551', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '551', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '551', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '551', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '551', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '551', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '551', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '551', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '551', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '555', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 5, NULL, NULL, '''555v'',''555x'',''555z'',''555y''', 0, 0, '', '', ''),
		('GEOGR_NAME', '555', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '555', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '555', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '555', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '555', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '555', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '555', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '555', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '555', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '555', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '580', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '580', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '580', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '580', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '580', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '580', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '580', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '580', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '580', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '580', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '581', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '581', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '581', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '581', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '581', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '581', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '581', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '581', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '581', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '581', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '582', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '582', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '582', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '582', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '582', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '582', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '582', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '582', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '582', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '582', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '585', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '585', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '585', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '585', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '585', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '585', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '585', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '585', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '585', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '585', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '663', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '663', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '663', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '663', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '663', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '664', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '664', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '664', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '664', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '664', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '665', 'a', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '665', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '665', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '666', 'a', 'Allgemeine Hinweiserläuterung', 'Allgemeine Hinweiserläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '666', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '666', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '667', 'a', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '667', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '667', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '667', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '670', 'a', 'Quellenangabe', 'Quellenangabe', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '670', 'b', 'Vorhandene Informationen', 'Vorhandene Informationen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '670', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '670', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '670', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '675', 'a', 'Quellenangabe', 'Quellenangabe', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '675', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '675', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '678', 'a', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '678', 'b', 'Erweiterung', 'Erweiterung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '678', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '678', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '678', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '680', 'a', 'Ansetzung oder Unterteilung', 'Ansetzung oder Unterteilung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '680', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '680', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '680', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '680', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '680', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '681', 'a', 'Schlagwort- oder Unterteilungsansetzung', 'Schlagwort- oder Unterteilungsansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '681', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '681', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '681', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '681', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '682', 'a', 'Zu ersetzende Ansetzung', 'Zu ersetzende Ansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '682', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '682', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '682', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '683', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '683', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '683', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '683', 'p', 'Corresponding classification field', 'Corresponding classification field', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '683', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '683', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '683', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '683', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '683', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '688', 'a', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '688', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '688', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '688', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '751', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '751', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '751', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '751', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '751', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '751', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '751', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '751', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '751', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '751', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '751', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '751', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '781', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '781', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '781', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '781', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '781', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '781', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '781', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '781', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '781', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '781', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '788', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '788', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '788', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '788', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '788', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '788', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '788', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'a', 'Host-Name', 'Host-Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'b', 'Zugriffsnummer', 'Zugriffsnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'c', 'Angaben zur Komprimierung', 'Angaben zur Komprimierung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'd', 'Pfad', 'Pfad', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'f', 'Elektronischer Name', 'Elektronischer Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'h', 'Bearbeiter der Anfrage', 'Bearbeiter der Anfrage', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'i', 'Anweisung', 'Anweisung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'j', 'Bits pro Sekunde', 'Bits pro Sekunde', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'k', 'Passwort', 'Passwort', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'l', 'Login', 'Login', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'm', 'Kontaktstelle für Hilfe beim Zugriff', 'Kontaktstelle für Hilfe beim Zugriff', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'n', 'Name des Standortes des Hosts', 'Name des Standortes des Hosts', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'o', 'Betriebssystem', 'Betriebssystem', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'p', 'Port', 'Port', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'q', 'Elektronisches Format', 'Elektronisches Format', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'r', 'Einstellungen', 'Einstellungen', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 's', 'Dateigröße', 'Dateigröße', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 't', 'Terminalemulation', 'Terminalemulation', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'v', 'Zugriffszeiten', 'Zugriffszeiten', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'w', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'x', 'Interne Anmerkungen', 'Interne Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'y', 'Verlinkungstext', 'Verlinkungstext', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', 'z', 'Allgemeine Anmerkungen', 'Allgemeine Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', '2', 'Zugriffsart', 'Zugriffsart', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', '3', 'Spezifische Materialangaben', 'Spezifische Materialangaben', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '856', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'a', 'a', 'a', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'b', 'b', 'b', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'c', 'c', 'c', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'd', 'd', 'd', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'e', 'e', 'e', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'f', 'f', 'f', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'g', 'g', 'g', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'h', 'h', 'h', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'i', 'i', 'i', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'j', 'j', 'j', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'k', 'k', 'k', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'l', 'l', 'l', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'm', 'm', 'm', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'n', 'n', 'n', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'o', 'o', 'o', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'p', 'p', 'p', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'q', 'q', 'q', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'r', 'r', 'r', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 's', 's', 's', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 't', 't', 't', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'u', 'u', 'u', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'v', 'v', 'v', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'w', 'w', 'w', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'x', 'x', 'x', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'y', 'y', 'y', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', 'z', 'z', 'z', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', '0', '0', '0', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', '1', '1', '1', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', '2', '2', '2', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', '3', '3', '3', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', '4', '4', '4', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', '5', '5', '5', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', '6', '6', '6', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', '7', '7', '7', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', '8', '8', '8', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '880', '9', '9', '9', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GEOGR_NAME', '942', 'a', 'Koha-Normdatentyp', 'Koha-Normdatentyp', 0, 1, 9, NULL, NULL, NULL, 0, 8, '', 'auth_header.authtypecode', '');


-- ******************************************************



-- *******************************************************************
-- GENRE/FORM TERM AUTHORITY FIELDS/SUBFIELDS.
-- *******************************************************************

-- These ought to be adjusted for different less conflicting and more
-- rationally chosen fields and subfields but I had left that for last.

-- ADJUST ME
-- Use values from your dump of auth_tag_structure and auth_subfield_structure
-- to provide support for your Koha database.


INSERT INTO `auth_tag_structure` (`authtypecode`, `tagfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `authorised_value`) VALUES
		('GENRE/FORM', '000', 'Leader', 'Leader', 0, 1, NULL),
		('GENRE/FORM', '001', 'Kontrollnummer', 'Kontrollnummer', 0, 1, NULL),
		('GENRE/FORM', '003', 'Kontrollnummer-Identifier', 'Kontrollnummer-Identifier', 0, 1, NULL),
		('GENRE/FORM', '005', 'Datum und Zeit der letzten Transaktion', 'Datum und Zeit der letzten Transaktion', 0, 1, NULL),
		('GENRE/FORM', '008', 'Datenelemente mit fester Länge', 'Datenelemente mit fester Länge', 0, 1, NULL),
		('GENRE/FORM', '010', 'Kontrollnummer der Library of Congress', 'Kontrollnummer der Library of Congress', 0, 0, NULL),
		('GENRE/FORM', '016', 'Kontrollnummer der nationalen bibliografischen Stelle', 'Kontrollnummer der nationalen bibliografischen Stelle', 1, 0, NULL),
		('GENRE/FORM', '024', 'Anderer Standard-Identifier', 'Anderer Standard-Identifier', 1, 0, NULL),
		('GENRE/FORM', '035', 'System-Kontrollnummer', 'System-Kontrollnummer', 1, 0, NULL),
		('GENRE/FORM', '040', 'Katalogisierungsquelle', 'Katalogisierungsquelle', 0, 1, NULL),
		('GENRE/FORM', '042', 'Authentifizierungscode', 'Authentifizierungscode', 0, 0, NULL),
		('GENRE/FORM', '043', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 0, 0, NULL),
		('GENRE/FORM', '045', 'Zeitabschnitt der Ansetzung', 'Zeitabschnitt der Ansetzung', 0, 0, NULL),
		('GENRE/FORM', '050', 'Signatur der Library of Congress', 'Signatur der Library of Congress', 1, 0, NULL),
		('GENRE/FORM', '052', 'Geografische Klassifikation', 'Geografische Klassifikation', 1, 0, NULL),
		('GENRE/FORM', '053', 'Notation der LC', 'Notation der LC', 1, 0, NULL),
		('GENRE/FORM', '055', 'Signatur der Library and Archives Canada', 'Signatur der Library and Archives Canada', 1, 0, NULL),
		('GENRE/FORM', '060', 'Signatur der National Library of Medicine', 'Signatur der National Library of Medicine', 1, 0, NULL),
		('GENRE/FORM', '065', 'Andere Notation', 'Andere Notation', 1, 0, NULL),
		('GENRE/FORM', '066', 'Angewendete Zeichensätze', 'Angewendete Zeichensätze', 0, 0, NULL),
		('GENRE/FORM', '070', 'Signatur der National Agricultural Library', 'Signatur der National Agricultural Library', 1, 0, NULL),
		('GENRE/FORM', '072', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 1, 0, NULL),
		('GENRE/FORM', '073', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 0, 0, NULL),
		('GENRE/FORM', '082', 'Dewey-Dezimal-Signatur', 'Dewey-Dezimal-Signatur', 1, 0, NULL),
		('GENRE/FORM', '083', 'DDC-Notation', 'DDC-Notation', 1, 0, NULL),
		('GENRE/FORM', '086', 'Signatur für Amtsdruckschriften', 'Signatur für Amtsdruckschriften', 1, 0, NULL),
		('GENRE/FORM', '087', 'Notation fürs Amtsdruckschriften', 'Notation fürs Amtsdruckschriften', 1, 0, NULL),
		('GENRE/FORM', '090', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (RLIN)', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (OCLC)', 1, 0, NULL),
		('GENRE/FORM', '091', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 0, 0, NULL),
		('GENRE/FORM', '092', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 1, 0, NULL),
		('GENRE/FORM', '093', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('GENRE/FORM', '096', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 1, 0, NULL),
		('GENRE/FORM', '097', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('GENRE/FORM', '098', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 1, 0, NULL),
		('GENRE/FORM', '099', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 1, 0, NULL),
		('GENRE/FORM', '155', 'Ansetzung - Genre/Formschlagwort', 'Ansetzung - Genre/Formschlagwort', 0, 0, NULL),
		('GENRE/FORM', '185', 'Ansetzung - Unterteilung nach Form', 'Ansetzung - Unterteilung nach Form', 0, 0, NULL),
		('GENRE/FORM', '260', 'Komplexer Siehe-Hinweis - Schlagwort', 'Komplexer Siehe-Hinweis - Schlagwort', 1, 0, NULL),
		('GENRE/FORM', '360', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 'Komplexer Siehe-auch-Hinweis - Schlagwort', 1, 0, NULL),
		('GENRE/FORM', '400', 'Siehe-Verweisung - Personenname', 'Siehe-Verweisung - Personenname', 1, 0, NULL),
		('GENRE/FORM', '410', 'Siehe-Verweisung - Körperschaftsname', 'Siehe-Verweisung - Körperschaftsname', 1, 0, NULL),
		('GENRE/FORM', '411', 'Siehe-Verweisung - Kongressname', 'Siehe-Verweisung - Kongressname', 1, 0, NULL),
		('GENRE/FORM', '430', 'Siehe-Verweisung - Einheitstitel', 'Siehe-Verweisung - Einheitstitel', 1, 0, NULL),
		('GENRE/FORM', '448', 'Siehe-Verweisung - Zeitschlagwort', 'Siehe-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('GENRE/FORM', '450', 'Siehe-Verweisung - Sachschlagwort', 'Siehe-Verweisung - Sachschlagwort', 1, 0, NULL),
		('GENRE/FORM', '451', 'Siehe-Verweisung - Geografischer Name', 'Siehe-Verweisung - Geografischer Name', 1, 0, NULL),
		('GENRE/FORM', '455', 'Siehe-Verweisung - Genre/Formschlagwort', 'Siehe-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('GENRE/FORM', '480', 'Siehe-Verweisung - Allgemeine Unterteilung', 'Siehe-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('GENRE/FORM', '481', 'Siehe-Verweisung - Geografische Unterteilung', 'Siehe-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('GENRE/FORM', '482', 'Siehe-Verweisung - Chronologische Unterteilung', 'Siehe-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('GENRE/FORM', '485', 'Siehe-Verweisung - Unterteilung nach Form', 'Siehe-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('GENRE/FORM', '500', 'Siehe-auch-Verweisung - Personenname', 'Siehe-auch-Verweisung - Personenname', 1, 0, NULL),
		('GENRE/FORM', '510', 'Siehe-auch-Verweisung - Körperschaftsname', 'Siehe-auch-Verweisung - Körperschaftsname', 1, 0, NULL),
		('GENRE/FORM', '511', 'Siehe-auch-Verweisung - Kongressname', 'Siehe-auch-Verweisung - Kongressname', 1, 0, NULL),
		('GENRE/FORM', '530', 'Siehe-auch-Verweisung - Einheitstitel', 'Siehe-auch-Verweisung - Einheitstitel', 1, 0, NULL),
		('GENRE/FORM', '548', 'Siehe-auch-Verweisung - Zeitschlagwort', 'Siehe-auch-Verweisung - Zeitschlagwort', 1, 0, NULL),
		('GENRE/FORM', '550', 'Siehe-auch-Verweisung - Sachschlagwort', 'Siehe-auch-Verweisung - Sachschlagwort', 1, 0, NULL),
		('GENRE/FORM', '551', 'Siehe-auch-Verweisung - Geografischer Name', 'Siehe-auch-Verweisung - Geografischer Name', 1, 0, NULL),
		('GENRE/FORM', '555', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 'Siehe-auch-Verweisung - Genre/Formschlagwort', 1, 0, NULL),
		('GENRE/FORM', '580', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 'Siehe-auch-Verweisung - Allgemeine Unterteilung', 1, 0, NULL),
		('GENRE/FORM', '581', 'Siehe-auch-Verweisung - Geografische Unterteilung', 'Siehe-auch-Verweisung - Geografische Unterteilung', 1, 0, NULL),
		('GENRE/FORM', '582', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 'Siehe-auch-Verweisung - Chronologische Unterteilung', 1, 0, NULL),
		('GENRE/FORM', '585', 'Siehe-auch-Verweisung - Unterteilung nach Form', 'Siehe-auch-Verweisung - Unterteilung nach Form', 1, 0, NULL),
		('GENRE/FORM', '663', 'Komplexe Siehe-auch-Verweisung - Name', 'Komplexe Siehe-auch-Verweisung - Name', 0, 0, NULL),
		('GENRE/FORM', '664', 'Komplexe Siehe-Verweisung - Name', 'Komplexe Siehe-Verweisung - Name', 0, 0, NULL),
		('GENRE/FORM', '665', 'Geschichte der Verweisung', 'Geschichte der Verweisung', 0, 0, NULL),
		('GENRE/FORM', '666', 'Allgemein erläuternde Verweisung - Name', 'Allgemein erläuternde Verweisung - Name', 0, 0, NULL),
		('GENRE/FORM', '667', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 1, 0, NULL),
		('GENRE/FORM', '670', 'Datenquelle', 'Datenquelle', 1, 0, NULL),
		('GENRE/FORM', '675', 'Datenquelle ohne Information', 'Datenquelle ohne Information', 0, 0, NULL),
		('GENRE/FORM', '678', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, NULL),
		('GENRE/FORM', '680', 'Allgemeine Fußnote', 'Allgemeine Fußnote', 1, 0, NULL),
		('GENRE/FORM', '681', 'Beispiel für die Schlagwortverweisung', 'Beispiel für die Schlagwortverweisung', 1, 0, NULL),
		('GENRE/FORM', '682', 'Angaben zu gelöschten Ansetzungen', 'Angaben zu gelöschten Ansetzungen', 0, 0, NULL),
		('GENRE/FORM', '683', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('GENRE/FORM', '688', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 1, 0, NULL),
		('GENRE/FORM', '750', 'Verknüpfungselement für normierte Ansetzungen - Sachschlagwort', 'Verknüpfungselement für normierte Ansetzungen - Sachschlagwort', 1, 0, NULL),
		('GENRE/FORM', '755', 'Verknüpfungseintragung für normierte Ansetzungen - Genre/Formschlagwort', 'Verknüpfungseintragung für normierte Ansetzungen - Genre/Formschlagwort', 1, 0, NULL),
		('GENRE/FORM', '780', 'Verknüpfungseintragung der Unterteilung - Allgemeine Unterteilung', 'Verknüpfungseintragung der Unterteilung - Allgemeine Unterteilung', 1, 0, NULL),
		('GENRE/FORM', '785', 'Verknüpfungseintragung der Unterteilung - Unterteilung nach Form', 'Verknüpfungseintragung der Unterteilung - Unterteilung nach Form', 1, 0, NULL),
		('GENRE/FORM', '788', 'Komplexe Verknüpfungseintragungsdaten', 'Komplexe Verknüpfungseintragungsdaten', 0, 0, NULL),
		('GENRE/FORM', '856', 'Elektronische Adresse und Zugriff', 'Elektronische Adresse und Zugriff', 1, 0, NULL),
		('GENRE/FORM', '880', 'Andersschriftliche Darstellung', 'Andersschriftliche Darstellung', 1, 0, NULL),
        ('GENRE/FORM', '942', 'Interne Verwendung (KOHA)', 'Interne Verwendung (KOHA)', 0, 1, NULL);


INSERT INTO `auth_subfield_structure` (`authtypecode`, `tagfield`, `tagsubfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `tab`, `authorised_value`, `value_builder`, `seealso`, `isurl`, `hidden`, `linkid`, `kohafield`, `frameworkcode`) VALUES
		('GENRE/FORM', '000', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_leader_authorities.pl', NULL, 0, 0, '', '', ''),
                ('GENRE/FORM', '001', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', 'auth_header.authid', ''),
                ('GENRE/FORM', '003', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
                ('GENRE/FORM', '005', '@', 'Kontrollfeld', 'Kontrollfeld', 0, 1, 0, NULL, 'marc21_field_005.pl', NULL, 0, 0, '', '', ''),
                ('GENRE/FORM', '008', '@', 'Kontrollfeld mit fester Länge', 'Kontrollfeld mit fester Länge', 0, 1, 0, NULL, 'marc21_field_008_authorities.pl', NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '010', 'a', 'LoC-Kontrollnummer', 'LoC-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '010', 'z', 'Gelöschte/ungültige LoC-Kontrollnummer', 'Gelöschte/ungültige LoC-Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '010', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '016', 'a', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '016', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '016', '2', 'Quelle', 'Quelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '016', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '024', 'a', 'Standardnummer oder Code', 'Standardnummer oder Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '024', 'c', 'Bezugsbedingungen', 'Bezugsbedingungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '024', 'd', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 'Zusätzliche Codes zu der Standardnummer oder dem Code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '024', 'z', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 'Gelöschte(r)/ungültige(r) Standardnummer oder Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '024', '2', 'Quelle der Nummer oder des Codes', 'Quelle der Nummer oder des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '024', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '024', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '035', 'a', 'System-Kontrollnummer', 'System-Kontrollnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '035', 'z', 'Gelöschte/ungültige Kontrollnummer', 'Gelöschte/ungültige Kontrollnummer', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '035', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '035', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '040', 'a', 'Original-Katalogisierungsstelle', 'Original-Katalogisierungsstelle', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '040', 'b', 'Katalogisierungssprache', 'Katalogisierungssprache', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '040', 'c', 'Übertragungsstelle', 'Übertragungsstelle', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '040', 'd', 'Bearbeitungsstelle', 'Bearbeitungsstelle', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '040', 'e', 'Beschreibungsfestlegungen', 'Beschreibungsfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '040', 'f', 'Schlagwort- oder Thesaurusfestlegungen', 'Schlagwort- oder Thesaurusfestlegungen', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '040', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '040', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '042', 'a', 'Authentifizierungscode', 'Authentifizierungscode', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '043', 'a', 'Code für geografische Gebiete', 'Code für geografische Gebiete', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '043', 'b', 'Lokaler GAC-Code', 'Lokaler GAC-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '043', 'c', 'ISO-Code', 'ISO-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '043', '2', 'Quelle des lokalen Codes', 'Quelle des lokalen Codes', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '043', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '043', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '045', 'a', 'Zeitabschnitts-Code', 'Zeitabschnitts-Code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '045', 'b', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 'Formatierter 9999 v. Chr. bis n. Chr. Zeitabschnitt', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '045', 'c', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 'Formatierter Vor-9999 v. Chr. Zeitabschnitt', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '045', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '045', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '050', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '050', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '050', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '050', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '050', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '050', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '052', 'a', 'Klassifikation des geografischen Gebiets', 'Klassifikation des geografischen Gebiets', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '052', 'b', 'Klassifikation des geografischen Teilgebiets', 'Klassifikation des geografischen Teilgebiets', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '052', 'd', 'Eingetragener Ortsname', 'Eingetragener Ortsname', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '052', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '052', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '052', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '053', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '053', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '053', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '053', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '053', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '053', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '055', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '055', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '055', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '055', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '055', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '055', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '060', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '060', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '060', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '060', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '060', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '060', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '065', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '065', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '065', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '065', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '065', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '065', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '065', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '066', 'a', 'Primärer G0-Zeichensatz', 'Primärer G0-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '066', 'b', 'Primärer G1-Zeichensatz', 'Primärer G1-Zeichensatz', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '066', 'c', 'Wechselnder G0- oder G1-Zeichensatz', 'Wechselnder G0- oder G1-Zeichensatz', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '070', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '070', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '070', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '070', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '070', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '072', 'a', 'Code der Sacherschließungskategorie', 'Code der Sacherschließungskategorie', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '072', 'x', 'Subject category code subdivision', 'Subject category code subdivision', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '072', '2', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '072', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '072', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '073', 'a', 'Verwendung der Unterteilung', 'Verwendung der Unterteilung', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '073', 'z', 'Quelle des Codes', 'Quelle des Codes', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '073', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '073', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '082', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '082', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '082', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '082', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '082', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '082', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '082', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '083', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '083', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '083', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '083', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '083', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '083', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '083', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '083', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '086', 'a', 'Signatur', 'Signatur', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '086', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '086', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '086', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '086', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '086', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '086', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '087', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '087', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '087', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '087', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '087', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '087', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 'a', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 'b', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 'e', 'Feature heading (OCLC)', 'Feature heading (OCLC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 'f', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 'h', 'Output transaction history, HST (RLIN)', 'Output transaction history, HST (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 'i', 'Output transaction instruction, INS (RLIN)', 'Output transaction instruction, INS (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 'l', 'Extra card control statement, EXT (RLIN)', 'Extra card control statement, EXT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 'n', 'Additional local notes, ANT (RLIN)', 'Additional local notes, ANT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 'p', 'Pathfinder code, PTH (RLIN)', 'Pathfinder code, PTH (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 't', 'Field suppresion, FSP (RLIN)', 'Field suppresion, FSP (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 'v', 'Volumes, VOL (RLIN)', 'Volumes, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 'y', 'Date, VOL (RLIN)', 'Date, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', 'z', 'Gelöschte/ungültige Signatur', 'Gelöschte/ungültige Signatur', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', '2', 'Quelle der Nummer', 'Quelle der Nummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '090', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '091', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '091', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '091', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '091', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '091', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '091', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '091', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '091', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '092', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '092', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '092', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '092', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '092', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '092', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '092', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '092', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '092', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '093', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '093', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '093', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '093', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '093', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '093', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '093', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '093', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '096', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '096', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '096', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '096', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '096', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '096', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '096', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '096', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '096', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '097', 'a', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 'Notationselement - Einzelnummer oder Beginnnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '097', 'b', 'Notationselement - Endnummer des Bereiches', 'Notationselement - Endnummer des Bereiches', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '097', 'c', 'Erläuternder Term', 'Erläuternder Term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '097', 'z', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 'Hilfstafelkennzeichnung-Hilfstafelnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '097', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '097', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '097', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '097', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '098', 'a', 'Call number based on other classification scheme', 'Call number based on other classification scheme', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '098', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '098', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '098', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '098', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '098', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '098', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '098', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '098', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '099', 'a', 'Notation', 'Notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '099', 'b', 'Exemplarnummer', 'Exemplarnummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '099', 'd', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 'Bände/Datumsangaben, auf die sich die Signatur bezieht', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '099', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '099', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '099', '2', 'Ausgabenummer', 'Ausgabenummer', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '099', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '099', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '099', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '155', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 1, NULL, NULL, '''155v'',''155x'',''155z'',''155y''', 0, 0, '', '', ''),
		('GENRE/FORM', '155', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '155', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '155', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '155', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '155', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '155', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '185', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '185', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '185', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '185', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '185', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '185', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '260', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '260', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '260', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '260', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '360', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '360', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '360', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '360', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'a', 'Personenname', 'Personenname', 0, 0, 4, NULL, NULL, '''400b'',''400c'',''400q'',''400d'',''400t'',''400o'',''400m'',''400r'',''400s'',''400k'',''400n'',''400p'',''400g'',''400l'',''400f'',''400h'',''400x'',''400z'',''400y'',''400v''', 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'b', 'Zählung', 'Zählung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '400', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''410b'',''410c'',''410d'',''410t'',''410o'',''410m'',''410r'',''410s'',''410k'',''410n'',''410p'',''410g'',''410l'',''410f'',''410h'',''410x'',''410z'',''410y'',''410v''', 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '410', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 4, NULL, NULL, '''411e'',''411c'',''411d'',''411t'',''411s'',''411k'',''411n'',''411p'',''411g'',''411l'',''411f'',''411h'',''411x'',''411z'',''411y'',''411v''', 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'b', 'Nummer [OBSOLET]', 'Nummer [OBSOLET]', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '411', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 4, NULL, NULL, '''430o'',''430m'',''430r'',''430s'',''430d'',''430k'',''430n'',''430p'',''430g'',''430l'',''430f'',''430h'',''430t'',''430x'',''430z'',''430y'',''430v''', 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'r', 'Tonart', 'Tonart', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '430', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '448', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 4, NULL, NULL, '''448y'',''448x'',''448z'',''448v''', 0, 0, '', '', ''),
		('GENRE/FORM', '448', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '448', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '448', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '448', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '448', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '448', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '448', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '448', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '448', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '450', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 4, NULL, NULL, '''450x'',''450z'',''450y'',''450v''', 0, 0, '', '', ''),
		('GENRE/FORM', '450', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '450', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '450', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '450', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '450', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '450', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '450', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '450', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '450', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '450', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '451', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 4, NULL, NULL, '''451z'',''451x'',''451y'',''451v''', 0, 0, '', '', ''),
		('GENRE/FORM', '451', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '451', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '451', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '451', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '451', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '451', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '451', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '451', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '451', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '455', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 4, NULL, NULL, '''455v'',''455x'',''455z'',''455y''', 0, 0, '', '', ''),
		('GENRE/FORM', '455', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '455', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '455', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '455', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '455', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '455', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '455', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '455', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '455', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '480', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '480', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '480', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '480', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '480', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '480', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '480', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '480', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '480', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '481', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '481', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '481', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '481', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '481', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '481', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '481', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '481', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '481', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '482', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '482', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '482', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '482', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '482', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '482', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '482', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '482', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '482', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '485', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '485', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '485', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '485', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '485', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '485', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '485', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '485', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '485', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'a', 'Personenname', 'Personenname', 0, 0, 5, NULL, NULL, '''500b'',''500c'',''500q'',''500d'',''500t'',''500o'',''500m'',''500r'',''500s'',''500k'',''500n'',''500p'',''500g'',''500l'',''500f'',''500h'',''500x'',''500z'',''500y'',''500v''', 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'b', 'Zählung', 'Zählung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'c', 'Titel und andere Wörter in Verbindung mit einem Namen', 'Titel und andere Wörter in Verbindung mit einem Namen', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'd', 'Datumsangaben in Verbindung mit einem Namen', 'Datumsangaben in Verbindung mit einem Namen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'j', 'Zuordnungsvermerk', 'Zuordnungsvermerk', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'q', 'Vollständige Form eines Namens', 'Vollständige Form eines Namens', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '500', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'a', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 'Körperschafts- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''510b'',''510c'',''510d'',''510t'',''510o'',''510m'',''510r'',''510s'',''510k'',''510n'',''510p'',''510g'',''510l'',''510f'',''510h'',''510x'',''510z'',''510y'',''510v''', 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'b', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'd', 'Datum des Kongresses oder der Vertragsunterzeichnung', 'Datum des Kongresses oder der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'e', 'Funktionsbezeichnung', 'Funktionsbezeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '510', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'a', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 'Kongress- oder Gebietskörperschaftsname als Eintragungselement', 0, 0, 5, NULL, NULL, '''511e'',''511c'',''511d'',''511t'',''511s'',''511k'',''511n'',''511p'',''511g'',''511l'',''511f'',''511h'',''511x'',''511z'',''511y'',''511v''', 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'c', 'Ort des Kongresses', 'Ort des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'd', 'Datum des Kongresses', 'Datum des Kongresses', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'e', 'Untergeordnete Einheit', 'Untergeordnete Einheit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'n', 'Zählung des Teils/der Abteilung/eines Kongresses', 'Zählung des Teils/der Abteilung/eines Kongresses', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'q', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 'Name des Kongresses, der dem Gebietskörperschaftsnamen-Eintragungselement folgt', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '511', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'a', 'Einheitstitel', 'Einheitstitel', 0, 0, 5, NULL, NULL, '''530o'',''530m'',''530r'',''530s'',''530d'',''530k'',''530n'',''530p'',''530g'',''530l'',''530f'',''530h'',''530t'',''530x'',''530z'',''530y'',''530v''', 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'd', 'Datum der Vertragsunterzeichnung', 'Datum der Vertragsunterzeichnung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'f', 'Erscheinungsjahr eines Werkes', 'Erscheinungsjahr eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'g', 'Sonstige Informationen', 'Sonstige Informationen', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'k', 'Formbestandteil der Ansetzung', 'Formbestandteil der Ansetzung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'l', 'Sprache eines Werkes', 'Sprache eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'm', 'Medium der Musikaufführung', 'Medium der Musikaufführung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'n', 'Zählung des Teils/der Abteilung eines Werkes', 'Zählung des Teils/der Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'o', 'Angabe des Musikarrangements', 'Angabe des Musikarrangements', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'p', 'Titel eines Teils/einer Abteilung eines Werkes', 'Titel eines Teils/einer Abteilung eines Werkes', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'r', 'Tonart', 'Tonart', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 't', 'Titel eines Werkes', 'Titel eines Werkes', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '530', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '548', 'a', 'Zeitschlagwort', 'Zeitschlagwort', 0, 0, 5, NULL, NULL, '''548y'',''548x'',''548z'',''548v''', 0, 0, '', '', ''),
		('GENRE/FORM', '548', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '548', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '548', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '548', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '548', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '548', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '548', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '548', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '548', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '548', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '550', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 5, NULL, NULL, '''550x'',''550z'',''550y'',''550v''', 0, 0, '', '', ''),
		('GENRE/FORM', '550', 'b', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 'Das Unterfeld enthält ein Sachschlagwort, das dem geografischen Namen als Eintragungselement', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '550', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '550', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '550', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '550', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '550', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '550', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '550', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '550', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '550', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '550', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '551', 'a', 'Geografischer Name', 'Geografischer Name', 0, 0, 5, NULL, NULL, '''551z'',''551x'',''551y'',''551v''', 0, 0, '', '', ''),
		('GENRE/FORM', '551', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '551', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '551', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '551', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '551', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '551', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '551', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '551', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '551', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '551', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '555', 'a', 'Genre/Formschlagwort', 'Genre/Formschlagwort', 0, 0, 5, NULL, NULL, '''555v'',''555x'',''555z'',''555y''', 0, 0, '', '', ''),
		('GENRE/FORM', '555', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '555', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '555', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '555', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '555', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '555', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '555', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '555', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '555', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '555', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '580', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '580', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '580', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '580', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '580', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '580', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '580', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '580', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '580', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '580', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '581', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '581', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '581', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '581', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '581', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '581', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '581', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '581', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '581', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '581', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '582', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '582', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '582', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '582', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '582', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '582', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '582', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '582', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '582', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '582', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '585', 'i', 'Verweisungsphrase', 'Verweisungsphrase', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '585', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '585', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '585', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '585', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '585', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '585', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '585', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '585', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '585', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '663', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '663', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '663', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '663', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '663', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '664', 'a', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '664', 'b', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '664', 't', 'Titel verweist auf', 'Titel verweist auf', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '664', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '664', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '665', 'a', 'Verlauf der Verweisung', 'Verlauf der Verweisung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '665', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '665', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '666', 'a', 'Allgemeine Hinweiserläuterung', 'Allgemeine Hinweiserläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '666', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '666', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '667', 'a', 'Interne allgemeine Fußnote', 'Interne allgemeine Fußnote', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '667', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '667', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '667', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '670', 'a', 'Quellenangabe', 'Quellenangabe', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '670', 'b', 'Vorhandene Informationen', 'Vorhandene Informationen', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '670', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '670', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '670', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '675', 'a', 'Quellenangabe', 'Quellenangabe', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '675', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '675', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '678', 'a', 'Biografische oder geschichtliche Daten', 'Biografische oder geschichtliche Daten', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '678', 'b', 'Erweiterung', 'Erweiterung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '678', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '678', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '678', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '680', 'a', 'Ansetzung oder Unterteilung', 'Ansetzung oder Unterteilung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '680', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '680', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '680', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '680', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '680', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '681', 'a', 'Schlagwort- oder Unterteilungsansetzung', 'Schlagwort- oder Unterteilungsansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '681', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '681', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '681', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '681', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '682', 'a', 'Zu ersetzende Ansetzung', 'Zu ersetzende Ansetzung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '682', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '682', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '682', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '683', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '683', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '683', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '683', 'p', 'Corresponding classification field', 'Corresponding classification field', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '683', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '683', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '683', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '683', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '683', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '688', 'a', 'Fußnote zur Anwendungsgeschichte', 'Fußnote zur Anwendungsgeschichte', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '688', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '688', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '688', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', 'a', 'Sachschlagwort oder geografischer Name als Eintragungselement', 'Sachschlagwort oder geografischer Name als Eintragungselement', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', 'b', 'Einem geografischen Namen folgendes Sachschlagwort als Eintragungselement', 'Einem geografischen Namen folgendes Sachschlagwort als Eintragungselement', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', 'c', 'Location of event', 'Location of event', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', 'd', 'Active date', 'Active date', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '750', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '755', 'a', 'Genre/Formschlagwort als Eintragungselement', 'Genre/Formschlagwort als Eintragungselement', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '755', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '755', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '755', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '755', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '755', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '755', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '755', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '755', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '755', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '755', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '780', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '780', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '780', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '780', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '780', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '780', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '780', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '780', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '780', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '780', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '785', 'v', 'Unterteilung nach Form', 'Unterteilung nach Form', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '785', 'w', 'Kontrollunterfeld', 'Kontrollunterfeld', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '785', 'x', 'Allgemeine Unterteilung', 'Allgemeine Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '785', 'y', 'Chronologische Unterteilung', 'Chronologische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '785', 'z', 'Geografische Unterteilung', 'Geografische Unterteilung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '785', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '785', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '785', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '785', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '785', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '788', 'a', 'Ansetzung verweist auf', 'Ansetzung verweist auf', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '788', 'i', 'Erläuterung', 'Erläuterung', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '788', '0', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '788', '2', 'Quelle der Ansetzung oder des Terms', 'Quelle der Ansetzung oder des Terms', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '788', '5', 'Institution, auf die sich das Feld bezieht', 'Institution, auf die sich das Feld bezieht', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '788', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '788', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'a', 'Host-Name', 'Host-Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'b', 'Zugriffsnummer', 'Zugriffsnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'c', 'Angaben zur Komprimierung', 'Angaben zur Komprimierung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'd', 'Pfad', 'Pfad', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'f', 'Elektronischer Name', 'Elektronischer Name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'h', 'Bearbeiter der Anfrage', 'Bearbeiter der Anfrage', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'i', 'Anweisung', 'Anweisung', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'j', 'Bits pro Sekunde', 'Bits pro Sekunde', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'k', 'Passwort', 'Passwort', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'l', 'Login', 'Login', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'm', 'Kontaktstelle für Hilfe beim Zugriff', 'Kontaktstelle für Hilfe beim Zugriff', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'n', 'Name des Standortes des Hosts', 'Name des Standortes des Hosts', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'o', 'Betriebssystem', 'Betriebssystem', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'p', 'Port', 'Port', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'q', 'Elektronisches Format', 'Elektronisches Format', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'r', 'Einstellungen', 'Einstellungen', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 's', 'Dateigröße', 'Dateigröße', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 't', 'Terminalemulation', 'Terminalemulation', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'v', 'Zugriffszeiten', 'Zugriffszeiten', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'w', 'Datensatzkontrollnummer', 'Datensatzkontrollnummer', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'x', 'Interne Anmerkungen', 'Interne Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'y', 'Verlinkungstext', 'Verlinkungstext', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', 'z', 'Allgemeine Anmerkungen', 'Allgemeine Anmerkungen', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', '2', 'Zugriffsart', 'Zugriffsart', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', '3', 'Spezifische Materialangaben', 'Spezifische Materialangaben', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', '6', 'Verknüpfung', 'Verknüpfung', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '856', '8', 'Feldverknüpfung und Reihenfolge', 'Feldverknüpfung und Reihenfolge', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'a', 'a', 'a', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'b', 'b', 'b', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'c', 'c', 'c', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'd', 'd', 'd', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'e', 'e', 'e', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'f', 'f', 'f', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'g', 'g', 'g', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'h', 'h', 'h', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'i', 'i', 'i', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'j', 'j', 'j', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'k', 'k', 'k', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'l', 'l', 'l', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'm', 'm', 'm', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'n', 'n', 'n', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'o', 'o', 'o', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'p', 'p', 'p', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'q', 'q', 'q', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'r', 'r', 'r', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 's', 's', 's', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 't', 't', 't', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'u', 'u', 'u', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'v', 'v', 'v', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'w', 'w', 'w', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'x', 'x', 'x', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'y', 'y', 'y', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', 'z', 'z', 'z', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', '0', '0', '0', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', '1', '1', '1', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', '2', '2', '2', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', '3', '3', '3', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', '4', '4', '4', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', '5', '5', '5', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', '6', '6', '6', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', '7', '7', '7', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', '8', '8', '8', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '880', '9', '9', '9', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('GENRE/FORM', '942', 'a', 'Koha-Normdatentyp', 'Koha-Normdatentyp', 0, 1, 9, NULL, NULL, NULL, 0, 8, '', 'auth_header.authtypecode', '');

