-- *******************************************************
--   KOHA  MARC 21 STANDARD DEFAULT AUTHORITY FRAMEWORKS
--
--        Revised to Update No. 16 (april 2013)
-- *******************************************************

-- ******************************************************
-- KOHA DEFAULT MARC 21 AUTHORITY TYPE.
-- ******************************************************

-- This authority type includes all fields and subfieds used by any
-- authority type.

INSERT INTO auth_types (authtypecode, authtypetext, auth_tag_to_report, summary) VALUES
		('', 'Default', '', '');


-- ******************************************************
-- KOHA SUPPORTED STANDARD MARC 21 AUTHORITY TYPES.
-- ******************************************************

-- These authority types are supported for for guiding the cataloguer to
-- fill authorised values in Koha MARC bibliographic editor.


INSERT INTO auth_types (authtypecode, authtypetext, auth_tag_to_report, summary) VALUES
		('PERSO_NAME', 'Personal Name', '100', 'Personal Names'),
		('CORPO_NAME', 'Corporate Name', '110', 'Corporate Names'),
		('MEETI_NAME', 'Meeting Name', '111', 'Meeting Name'),
		('UNIF_TITLE', 'Uniform Title', '130', 'Uniform Title'),
		('CHRON_TERM', 'Chronological Term', '148', 'Chronological Term'),
		('TOPIC_TERM', 'Topical Term', '150', 'Topical Term'),
		('GEOGR_NAME', 'Geographic Name', '151', 'Geographic Name'),
		('GENRE/FORM', 'Genre/Form Term', '155', 'Genre/Form Term');


-- ******************************************************
-- KOHA UNSUPPORTED STANDARD MARC 21 AUTHORITY TYPES.
-- ******************************************************

-- These authority types are only supported for guiding the cataloguer to
-- fill authorised values in the Koha MARC bibliographic editor to the
-- extent that they have already been included in a primary authority type,
-- therefore, they have not yet been specified.
--
-- Minimal primary authorities including subdivisions may currently be
-- built by a script which uses the values in bibliographic records but
-- include no tracings and references which are necessarily not present
-- in bibliographic records.


-- INSERT INTO `auth_types` (`authtypecode`, `authtypetext`, `auth_tag_to_report`, `summary`) VALUES
--		('TOPIC_SUBD', 'General Topical Term Subdivision', '180', 'General Topical Term Subdivision'),
--		('GEOGR_SUBD', 'Geographic Subdivision', '181', 'Geographic Subdivision'),
--		('CHRON_SUBD', 'Chronological Subdivision', '182', 'Chronological Subdivision'),
--		('FORM_SUBDI', 'Form Subdivision', '185', 'Form Subdivision');



-- *****************************************************************
-- MARC 21 AUTHORITY FIELDS/SUBFIELDS AND COMMMONLY USED EXTENSIONS
-- *****************************************************************


-- No support for subfield visibility is yet provided by the Koha code
-- matching the column name 'hidden' in the bibliographic framework.
--
-- Needs checking for errors but probably tolerable for use on a production.
-- A server can be upgraded easily from later versions of this file.
--
-- In the absense of more column support for qualifying the relative
-- importance of subfields to the record editor, some modest modification of
-- the default framework is needed setting the not-useful non-Koha holdings
-- subfields to not managed in Koha.

-- MARC fields including letters as part of the field identifier are from RLIN
-- and should be expected to remain along with RLIN $% subfields.  RLIN has
-- been using letters in fields because there are not enough local use number
-- fields which have not already been specified for very large union catalogue
-- networks such as RLIN itself.

-- Fields ending in a or b are temporary placeholders for information from
-- a numeric value until a non-conflicting way to treat the content under the
-- proper original numeric field is adopted.  090 for LC call numbers is much
-- too common and important so 999 is also provided as a temporary place
-- holder until all Koha code for finding control fields has been changed from
-- a numeric test of < 10 to a regular expression match of m/^00/ to prevent
-- mistaken matching of fields with letters such as 09o if they were control
-- fields.

-- Fields and subfields which belong exclusively in a classification
-- framework have been marked '[CLASSIFICATION FRAMEWORK]'.  They are retained
-- or included here becuase some had been included previously and Koha does
-- not yet have a classification framework.


INSERT INTO `auth_tag_structure` (`authtypecode`, `tagfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `authorised_value`) VALUES
		('', '000', 'LEADER', 'LEADER', 0, 1, NULL),
		('', '001', 'CONTROL NUMBER', 'CONTROL NUMBER', 0, 1, NULL),
		('', '003', 'CONTROL NUMBER IDENTIFIER', 'CONTROL NUMBER IDENTIFIER', 0, 1, NULL),
		('', '005', 'DATE AND TIME OF LATEST TRANSACTION', 'DATE AND TIME OF LATEST TRANSACTION', 0, 1, NULL),
		('', '008', 'FIXED-LENGTH DATA ELEMENTS', 'FIXED-LENGTH DATA ELEMENTS', 0, 1, NULL),
		('', '010', 'LIBRARY OF CONGRESS CONTROL NUMBER', 'LIBRARY OF CONGRESS CONTROL NUMBER', 0, 0, NULL),
		('', '014', 'LINK TO BIBLIOGRAPHIC RECORD FOR SERIAL OR MULTIPART ITEM', 'LINK TO BIBLIOGRAPHIC RECORD FOR SERIAL OR MULTIPART ITEM', 1, 0, NULL),
		('', '016', 'NATIONAL BIBLIOGRAPHIC AGENCY CONTROL NUMBER', 'NATIONAL BIBLIOGRAPHIC AGENCY CONTROL NUMBER', 1, 0, NULL),
		('', '020', 'INTERNATIONAL STANDARD BOOK NUMBER', 'INTERNATIONAL STANDARD BOOK NUMBER', 1, 0, NULL),
		('', '022', 'INTERNATIONAL STANDARD SERIAL NUMBER', 'INTERNATIONAL STANDARD SERIAL NUMBER', 1, 0, NULL),
		('', '024', 'OTHER STANDARD IDENTIFIER', 'OTHER STANDARD IDENTIFIER', 1, 0, NULL),
		('', '031', 'MUSICAL INCIPITS INFORMATION', 'MUSICAL INCIPITS INFORMATION', 1, 0, NULL),
		('', '034', 'CODED CARTOGRAPHIC MATHEMATICAL DATA', 'CODED CARTOGRAPHIC MATHEMATICAL DATA', 1, 0, NULL),
		('', '035', 'SYSTEM CONTROL NUMBER', 'SYSTEM CONTROL NUMBER', 1, 0, NULL),
		('', '040', 'CATALOGING SOURCE', 'CATALOGING SOURCE', 0, 1, NULL),
		('', '042', 'AUTHENTICATION CODE', 'AUTHENTICATION CODE', 0, 0, NULL),
		('', '043', 'GEOGRAPHIC AREA CODE', 'GEOGRAPHIC AREA CODE', 0, 0, NULL),
		('', '045', 'TIME PERIOD OF HEADING', 'TIME PERIOD OF HEADING', 0, 0, NULL),
		('', '046', 'SPECIAL CODED DATES', 'SPECIAL CODED DATES', 1, 0, NULL),
		('', '050', 'LIBRARY OF CONGRESS CALL NUMBER', 'LIBRARY OF CONGRESS CALL NUMBER', 1, 0, NULL),
		('', '052', 'GEOGRAPHIC CLASSIFICATION', 'GEOGRAPHIC CLASSIFICATION', 1, 0, NULL),
		('', '053', 'LC CLASSIFICATION NUMBER', 'LC CLASSIFICATION NUMBER', 1, 0, NULL),
		('', '055', 'LIBRARY AND ARCHIVES CANADA CALL NUMBER', 'LIBRARY AND ARCHIVES CANADA CALL NUMBER', 1, 0, NULL),
		('', '058', 'LC CLASSIFICATION NUMBER ASSIGNED IN CANADA [OBSOLETE, CAN/MARC]', 'LC CLASSIFICATION NUMBER ASSIGNED IN CANADA [OBSOLETE, CAN/MARC]', 1, 0, NULL),
		('', '060', 'NATIONAL LIBRARY OF MEDICINE CALL NUMBER', 'NATIONAL LIBRARY OF MEDICINE CALL NUMBER', 1, 0, NULL),
		('', '063', 'NLM CLASSIFICATION NUMBER ASSIGNED BY NLM [OBSOLETE, CAN/MARC]', 'NLM CLASSIFICATION NUMBER ASSIGNED BY NLM [OBSOLETE, CAN/MARC]', 1, 0, NULL),
		('', '065', 'OTHER CLASSIFICATION NUMBER', 'OTHER CLASSIFICATION NUMBER', 1, 0, NULL),
		('', '066', 'CHARACTER SETS PRESENT', 'CHARACTER SETS PRESENT', 0, 0, NULL),
		('', '068', 'NLM CLASSIFICATION NUMBER ASSIGNED IN CANADA [OBSOLETE, CAN/MARC]', 'NLM CLASSIFICATION NUMBER ASSIGNED IN CANADA [OBSOLETE, CAN/MARC]', 1, 0, NULL),
		('', '070', 'NATIONAL AGRICULTURAL LIBRARY CALL NUMBER', 'NATIONAL AGRICULTURAL LIBRARY CALL NUMBER', 1, 0, NULL),
		('', '072', 'SUBJECT CATEGORY CODE', 'SUBJECT CATEGORY CODE', 1, 0, NULL),
		('', '073', 'SUBDIVISION USAGE', 'SUBDIVISION USAGE', 0, 0, NULL),
		('', '080', 'UNIVERSAL DECIMAL CLASSIFICATION NUMBER', 'UNIVERSAL DECIMAL CLASSIFICATION NUMBER', 1, 0, NULL),
		('', '082', 'DEWEY DECIMAL CALL NUMBER', 'DEWEY DECIMAL CALL NUMBER', 1, 0, NULL),
		('', '083', 'DEWEY DECIMAL CLASSIFICATION NUMBER', 'DEWEY DECIMAL CLASSIFICATION NUMBER', 1, 0, NULL),
		('', '084', 'CLASSIFICATION SCHEME AND EDITION [CLASSIFICATION FORMAT]', 'CLASSIFICATION SCHEME AND EDITION [CLASSIFICATION FORMAT]', 0, 0, NULL),
		('', '086', 'GOVERNMENT DOCUMENT CALL NUMBER', 'GOVERNMENT DOCUMENT CALL NUMBER', 1, 0, NULL),
		('', '087', 'GOVERNMENT DOCUMENT CLASSIFICATION NUMBER', 'GOVERNMENT DOCUMENT CLASSIFICATION NUMBER', 1, 0, NULL),
		('', '088', 'DOCUMENT SHELVING NUMBER (CODOC) [OBSOLETE, CAN/MARC]', 'DOCUMENT SHELVING NUMBER (CODOC) [OBSOLETE, CAN/MARC]', 1, 0, NULL),
		('', '090', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (RLIN)', 'LOCAL CALL NUMBER (SERIES) [OBSOLETE]; LOCALLY ASSIGNED LC-TYPE CALL NUMBER (OCLC); LOCAL CALL NUMBER (OCLC)', 1, 0, NULL),
		('', '091', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 'LOCALLY ASSIGNED LC-TYPE CLASSIFICATION NUMBER (OCLC); LOCAL CLASSIFICATION NUMBER (RLIN)', 0, 0, NULL),
		('', '092', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CALL NUMBER (OCLC)', 1, 0, NULL),
		('', '093', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED DEWEY CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('', '096', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CALL NUMBER (OCLC)', 1, 0, NULL),
		('', '097', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 'LOCALLY ASSIGNED NLM-TYPE CLASSIFICATION NUMBER (OCLC)', 1, 0, NULL),
		('', '098', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 'OTHER CLASSIFICATION SCHEMES (OCLC)', 1, 0, NULL),
		('', '099', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 'LOCAL FREE-TEXT CALL NUMBER (OCLC)', 1, 0, NULL),
		('', '100', 'HEADING--PERSONAL NAME', 'HEADING--PERSONAL NAME', 0, 0, NULL),
		('', '110', 'HEADING--CORPORATE NAME', 'HEADING--CORPORATE NAME', 0, 0, NULL),
		('', '111', 'HEADING--MEETING NAME', 'HEADING--MEETING NAME', 0, 0, NULL),
		('', '130', 'HEADING--UNIFORM TITLE', 'HEADING--UNIFORM TITLE', 0, 0, NULL),
		('', '140', 'UNIFORM TITLE [OBSOLETE, CAN/MARC]', 'UNIFORM TITLE [OBSOLETE, CAN/MARC]', 1, 0, NULL),
		('', '143', 'COLLECTIVE TITLE [OBSOLETE, CAN/MARC]', 'COLLECTIVE TITLE [OBSOLETE, CAN/MARC]', 1, 0, NULL),
		('', '148', 'HEADING--CHRONOLOGICAL TERM', 'HEADING--CHRONOLOGICAL TERM', 0, 0, NULL),
		('', '150', 'HEADING--TOPICAL TERM', 'HEADING--TOPICAL TERM', 0, 0, NULL),
		('', '151', 'HEADING--GEOGRAPHIC NAME', 'HEADING--GEOGRAPHIC NAME', 0, 0, NULL),
		('', '153', 'CLASSIFICATION NUMBER [CLASSIFICATION FORMAT]', 'CLASSIFICATION NUMBER [CLASSIFICATION FORMAT]', 0, 0, NULL),
		('', '154', 'GENERAL EXPLANATORY INDEX TERM [CLASSIFICATION FORMAT]', 'GENERAL EXPLANATORY INDEX TERM [CLASSIFICATION FORMAT]', 0, 0, NULL),
		('', '155', 'HEADING--GENRE/FORM TERM', 'HEADING--GENRE/FORM TERM', 0, 0, NULL),
        ('', '162', 'HEADING-MEDIUM OF PERFORMANCE TERM', 'HEADING-MEDIUM OF PERFORMANCE TERM', 0, 0, NULL),
		('', '180', 'HEADING--GENERAL SUBDIVISION', 'HEADING--GENERAL SUBDIVISION', 0, 0, NULL),
		('', '181', 'HEADING--GEOGRAPHIC SUBDIVISION', 'HEADING--GEOGRAPHIC SUBDIVISION', 0, 0, NULL),
		('', '182', 'HEADING--CHRONOLOGICAL SUBDIVISION', 'HEADING--CHRONOLOGICAL SUBDIVISION', 0, 0, NULL),
		('', '185', 'HEADING--FORM SUBDIVISION', 'HEADING--FORM SUBDIVISION', 0, 0, NULL),
		('', '253', 'COMPLEX SEE REFERENCE [CLASSIFICATION FORMAT]', 'COMPLEX SEE REFERENCE [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '260', 'COMPLEX SEE REFERENCE--SUBJECT', 'COMPLEX SEE REFERENCE--SUBJECT', 1, 0, NULL),
		('', '336', 'CONTENT TYPE', 'CONTENT TYPE', 1, 0, NULL),
		('', '353', 'COMPLEX SEE ALSO REFERENCE [CLASSIFICATION FORMAT]', 'COMPLEX SEE ALSO REFERENCE [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '360', 'COMPLEX SEE ALSO REFERENCE--SUBJECT', 'COMPLEX SEE ALSO REFERENCE--SUBJECT', 1, 0, NULL),
		('', '368', 'OTHER ATTRIBUTES OF PERSON OR CORPORATE BODY', 'OTHER ATTRIBUTES OF PERSON OR CORPORATE BODY', 1, 0, NULL),
		('', '370', 'ASSOCIATED PLACE', 'ASSOCIATED PLACE', 1, 0, NULL),
		('', '371', 'ADDRESS', 'ADDRESS', 1, 0, NULL),
		('', '372', 'FIELD OF ACTIVITY', 'FIELD OF ACTIVITY', 1, 0, NULL),
		('', '373', 'ASSOCIATED GROUP', 'ASSOCIATED GROUP', 1, 0, NULL),
		('', '374', 'OCCUPATION', 'OCCUPATION', 1, 0, NULL),
		('', '375', 'GENDER', 'GENDER', 1, 0, NULL),
		('', '376', 'FAMILY INFORMATION', 'FAMILY INFORMATION', 1, 0, NULL),
		('', '377', 'ASSOCIATED LANGUAGE', 'ASSOCIATED LANGUAGE', 1, 0, NULL),
		('', '378', 'FULLER FORM OF PERSONAL NAME', 'FULLER FORM OF PERSONAL NAME', 0, 0, NULL),
		('', '380', 'FORM OF WORK', 'FORM OF WORK', 1, 0, NULL),
		('', '381', 'OTHER DISTINGUISHING CHARACTERISTICS OF WORK OR EXPRESSION', 'OTHER DISTINGUISHING CHARACTERISTICS OF WORK OR EXPRESSION', 1, 0, NULL),
		('', '382', 'MEDIUM OF PERFORMANCE', 'MEDIUM OF PERFORMANCE', 1, 0, NULL),
		('', '383', 'NUMERIC DESIGNATION OF MUSICAL WORK', 'NUMERIC DESIGNATION OF MUSICAL WORK', 1, 0, NULL),
		('', '384', 'KEY', 'KEY', 0, 0, NULL),
        ('', '385', 'AUDIENCE CHARACTERISTICS', 'AUDIENCE CHARACTERISTICS', 1, 0, NULL),
        ('', '386', 'CREATOR/CONTRIBUTOR CHARACTERISTICS', 'CREATOR/CONTRIBUTOR CHARACTERISTICS', 1, 0, NULL),
		('', '400', 'SEE FROM TRACING--PERSONAL NAME', 'SEE FROM TRACING--PERSONAL NAME', 1, 0, NULL),
		('', '410', 'SEE FROM TRACING--CORPORATE NAME', 'SEE FROM TRACING--CORPORATE NAME', 1, 0, NULL),
		('', '411', 'SEE FROM TRACING--MEETING NAME', 'SEE FROM TRACING--MEETING NAME', 1, 0, NULL),
		('', '430', 'SEE FROM TRACING--UNIFORM TITLE', 'SEE FROM TRACING--UNIFORM TITLE', 1, 0, NULL),
		('', '448', 'SEE FROM TRACING--CHRONOLOGICAL TERM', 'SEE FROM TRACING--CHRONOLOGICAL TERM', 1, 0, NULL),
		('', '450', 'SEE FROM TRACING--TOPICAL TERM', 'SEE FROM TRACING--TOPICAL TERM', 1, 0, NULL),
		('', '451', 'SEE FROM TRACING--GEOGRAPHIC NAME', 'SEE FROM TRACING--GEOGRAPHIC NAME', 1, 0, NULL),
		('', '453', 'INVALID NUMBER TRACING [CLASSIFICATION FORMAT]', 'INVALID NUMBER TRACING [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '455', 'SEE FROM TRACING--GENRE/FORM TERM', 'SEE FROM TRACING--GENRE/FORM TERM', 1, 0, NULL),
        ('', '462', 'SEE FROM TRACING-MEDIUM OF PERFORMANCE TERM', 'SEE FROM TRACING-MEDIUM OF PERFORMANCE TERM', 1, 0, NULL),
		('', '480', 'SEE FROM TRACING--GENERAL SUBDIVISION', 'SEE FROM TRACING--GENERAL SUBDIVISION', 1, 0, NULL),
		('', '481', 'SEE FROM TRACING--GEOGRAPHIC SUBDIVISION', 'SEE FROM TRACING--GEOGRAPHIC SUBDIVISION', 1, 0, NULL),
		('', '482', 'SEE FROM TRACING--CHRONOLOGICAL SUBDIVISION', 'SEE FROM TRACING--CHRONOLOGICAL SUBDIVISION', 1, 0, NULL),
		('', '485', 'SEE FROM TRACING--FORM SUBDIVISION', 'SEE FROM TRACING--FORM SUBDIVISION', 1, 0, NULL),
		('', '500', 'SEE ALSO FROM TRACING--PERSONAL NAME', 'SEE ALSO FROM TRACING--PERSONAL NAME', 1, 0, NULL),
		('', '510', 'SEE ALSO FROM TRACING--CORPORATE NAME', 'SEE ALSO FROM TRACING--CORPORATE NAME', 1, 0, NULL),
		('', '511', 'SEE ALSO FROM TRACING--MEETING NAME', 'SEE ALSO FROM TRACING--MEETING NAME', 1, 0, NULL),
		('', '530', 'SEE ALSO FROM TRACING--UNIFORM TITLE', 'SEE ALSO FROM TRACING--UNIFORM TITLE', 1, 0, NULL),
		('', '548', 'SEE ALSO FROM TRACING--CHRONOLOGICAL TERM', 'SEE ALSO FROM TRACING--CHRONOLOGICAL TERM', 1, 0, NULL),
		('', '550', 'SEE ALSO FROM TRACING--TOPICAL TERM', 'SEE ALSO FROM TRACING--TOPICAL TERM', 1, 0, NULL),
		('', '551', 'SEE ALSO FROM TRACING--GEOGRAPHIC NAME', 'SEE ALSO FROM TRACING--GEOGRAPHIC NAME', 1, 0, NULL),
		('', '553', 'VALID NUMBER TRACING [CLASSIFICATION FORMAT]', 'VALID NUMBER TRACING [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '555', 'SEE ALSO FROM TRACING--GENRE/FORM TERM', 'SEE ALSO FROM TRACING--GENRE/FORM TERM', 1, 0, NULL),
        ('', '562', 'SEE ALSO FROM TRACING-MEDIUM OF PERFORMANCE TERM', 'SEE ALSO FROM TRACING-MEDIUM OF PERFORMANCE TERM', 1, 0, NULL),
		('', '580', 'SEE ALSO FROM TRACING--GENERAL SUBDIVISION', 'SEE ALSO FROM TRACING--GENERAL SUBDIVISION', 1, 0, NULL),
		('', '581', 'SEE ALSO FROM TRACING--GEOGRAPHIC SUBDIVISION', 'SEE ALSO FROM TRACING--GEOGRAPHIC SUBDIVISION', 1, 0, NULL),
		('', '582', 'SEE ALSO FROM TRACING--CHRONOLOGICAL SUBDIVISION', 'SEE ALSO FROM TRACING--CHRONOLOGICAL SUBDIVISION', 1, 0, NULL),
		('', '585', 'SEE ALSO FROM TRACING--FORM SUBDIVISION', 'SEE ALSO FROM TRACING--FORM SUBDIVISION', 1, 0, NULL),
		('', '640', 'SERIES DATES OF PUBLICATION AND/OR SEQUENTIAL DESIGNATION', 'SERIES DATES OF PUBLICATION AND/OR SEQUENTIAL DESIGNATION', 1, 0, NULL),
		('', '641', 'SERIES NUMBERING PECULIARITIES', 'SERIES NUMBERING PECULIARITIES', 1, 0, NULL),
		('', '642', 'SERIES NUMBERING EXAMPLE', 'SERIES NUMBERING EXAMPLE', 1, 0, NULL),
		('', '643', 'SERIES PLACE AND PUBLISHER/ISSUING BODY', 'SERIES PLACE AND PUBLISHER/ISSUING BODY', 1, 0, NULL),
		('', '644', 'SERIES ANALYSIS PRACTICE', 'SERIES ANALYSIS PRACTICE', 1, 0, NULL),
		('', '645', 'SERIES TRACING PRACTICE', 'SERIES TRACING PRACTICE', 1, 0, NULL),
		('', '646', 'SERIES CLASSIFICATION PRACTICE', 'SERIES CLASSIFICATION PRACTICE', 1, 0, NULL),
		('', '663', 'COMPLEX SEE ALSO REFERENCE--NAME', 'COMPLEX SEE ALSO REFERENCE--NAME', 0, 0, NULL),
		('', '664', 'COMPLEX SEE REFERENCE--NAME', 'COMPLEX SEE REFERENCE--NAME', 0, 0, NULL),
		('', '665', 'HISTORY REFERENCE', 'HISTORY REFERENCE', 0, 0, NULL),
		('', '666', 'GENERAL EXPLANATORY REFERENCE--NAME', 'GENERAL EXPLANATORY REFERENCE--NAME', 0, 0, NULL),
		('', '667', 'NONPUBLIC GENERAL NOTE', 'NONPUBLIC GENERAL NOTE', 1, 0, NULL),
		('', '668', 'CHARACTERS IN NONROMAN ALPHABETS [OBSOLETE]', 'CHARACTERS IN NONROMAN ALPHABETS [OBSOLETE]', 1, 0, NULL),
		('', '670', 'SOURCE DATA FOUND', 'SOURCE DATA FOUND', 1, 0, NULL),
		('', '671', 'NOTE--WORK CATALOGUED [OBSOLETE, CAN/MARC ONLY]', 'NOTE--WORK CATALOGUED [OBSOLETE, CAN/MARC ONLY]', 1, 0, NULL),
        ('', '672', 'TITLE RELATED TO THE ENTITY', 'TITLE RELATED TO THE ENTITY', 1, 0, NULL),
        ('', '673', 'TITLE NOT RELATED TO THE ENTITY', 'TITLE NOT RELATED TO THE ENTITY', 1, 0, NULL),
		('', '675', 'SOURCE DATA NOT FOUND', 'SOURCE DATA NOT FOUND', 0, 0, NULL),
		('', '676', 'NOTE--CATALOGUING RULES (NAMES/TITLES) [OBSOLETE, CAN/MARC ONLY]', 'NOTE--CATALOGUING RULES (NAMES/TITLES) [OBSOLETE, CAN/MARC ONLY]', 0, 0, NULL),
		('', '678', 'BIOGRAPHICAL OR HISTORICAL DATA', 'BIOGRAPHICAL OR HISTORICAL DATA', 1, 0, NULL),
		('', '680', 'PUBLIC GENERAL NOTE', 'PUBLIC GENERAL NOTE', 1, 0, NULL),
		('', '681', 'SUBJECT EXAMPLE TRACING NOTE', 'SUBJECT EXAMPLE TRACING NOTE', 1, 0, NULL),
		('', '682', 'DELETED HEADING INFORMATION', 'DELETED HEADING INFORMATION', 0, 0, NULL),
		('', '683', 'APPLICATION HISTORY NOTE', 'APPLICATION HISTORY NOTE', 1, 0, NULL),
		('', '684', 'AUXILIARY INSTRUCTION NOTE [CLASSIFICATION FORMAT]', 'AUXILIARY INSTRUCTION NOTE [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '685', 'NOTE--SOURCE DATA FOUND (SUBJECTS) [OBSOLETE, CAN/MARC ONLY]', 'NOTE--SOURCE DATA FOUND (SUBJECTS) [OBSOLETE, CAN/MARC ONLY]', 1, 0, NULL),
		('', '686', 'NOTE--SOURCE DATA NOT FOUND (SUBJECTS) [OBSOLETE, CAN/MARC ONLY]', 'NOTE--SOURCE DATA NOT FOUND (SUBJECTS) [OBSOLETE, CAN/MARC ONLY]', 1, 0, NULL),
		('', '687', 'NOTE--USAGE (SUBJECTS) [OBSOLETE, CAN/MARC ONLY]', 'NOTE--USAGE (SUBJECTS) [OBSOLETE, CAN/MARC ONLY]', 1, 0, NULL),
		('', '688', 'APPLICATION HISTORY NOTE', 'APPLICATION HISTORY NOTE', 1, 0, NULL),
		('', '700', 'ESTABLISHED HEADING LINKING ENTRY--PERSONAL NAME', 'ESTABLISHED HEADING LINKING ENTRY--PERSONAL NAME', 1, 0, NULL),
		('', '710', 'ESTABLISHED HEADING LINKING ENTRY--CORPORATE NAME', 'ESTABLISHED HEADING LINKING ENTRY--CORPORATE NAME', 1, 0, NULL),
		('', '711', 'ESTABLISHED HEADING LINKING ENTRY--MEETING NAME', 'ESTABLISHED HEADING LINKING ENTRY--MEETING NAME', 1, 0, NULL),
		('', '730', 'ESTABLISHED HEADING LINKING ENTRY--UNIFORM TITLE', 'ESTABLISHED HEADING LINKING ENTRY--UNIFORM TITLE', 1, 0, NULL),
		('', '748', 'ESTABLISHED HEADING LINKING ENTRY--CHRONOLOGICAL TERM', 'ESTABLISHED HEADING LINKING ENTRY--CHRONOLOGICAL TERM', 1, 0, NULL),
		('', '750', 'ESTABLISHED HEADING LINKING ENTRY--TOPICAL TERM', 'ESTABLISHED HEADING LINKING ENTRY--TOPICAL TERM', 1, 0, NULL),
		('', '751', 'ESTABLISHED HEADING LINKING ENTRY--GEOGRAPHIC NAME', 'ESTABLISHED HEADING LINKING ENTRY--GEOGRAPHIC NAME', 1, 0, NULL),
		('', '753', 'INDEX TERM--UNCONTROLLED [CLASSIFICATION FORMAT]', 'INDEX TERM--UNCONTROLLED [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '754', 'INDEX TERM--FACETED TOPICAL TERMS [CLASSIFICATION FORMAT]', 'INDEX TERM--FACETED TOPICAL TERMS [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '755', 'ESTABLISHED HEADING LINKING ENTRY--GENRE/FORM TERM', 'ESTABLISHED HEADING LINKING ENTRY--GENRE/FORM TERM', 1, 0, NULL),
		('', '761', 'ADD OR DIVIDE LIKE INSTRUCTIONS [CLASSIFICATION FORMAT]', 'ADD OR DIVIDE LIKE INSTRUCTIONS [CLASSIFICATION FORMAT]', 1, 0, NULL),
        ('', '762', 'ESTABLISHED HEADING LINKING ENTRY-MEDIUM OF PERFORMANCE TERM', 'ESTABLISHED HEADING LINKING ENTRY-MEDIUM OF PERFORMANCE TERM', 1, 0, NULL),
		('', '763', 'INTERNAL SUBARRANGEMENT OR ADD TABLE ENTRY [CLASSIFICATION FORMAT]', 'INTERNAL SUBARRANGEMENT OR ADD TABLE ENTRY [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '764', 'RULE IDENTIFICATION [CLASSIFICATION FORMAT]', 'RULE IDENTIFICATION [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '765', 'SYNTHESIZED NUMBER COMPONENTS [CLASSIFICATION FORMAT]', 'SYNTHESIZED NUMBER COMPONENTS [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '766', 'SECONDARY TABLE INFORMATION [CLASSIFICATION FORMAT]', 'SECONDARY TABLE INFORMATION [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '768', 'CITATION AND PREFERENCE ORDER INSTRUCTIONS [CLASSIFICATION FORMAT]', 'CITATION AND PREFERENCE ORDER INSTRUCTIONS [CLASSIFICATION FORMAT]', 1, 0, NULL),
		('', '780', 'SUBDIVISION LINKING ENTRY--GENERAL SUBDIVISION', 'SUBDIVISION LINKING ENTRY--GENERAL SUBDIVISION', 1, 0, NULL),
		('', '781', 'SUBDIVISION LINKING ENTRY--GEOGRAPHIC SUBDIVISION', 'SUBDIVISION LINKING ENTRY--GEOGRAPHIC SUBDIVISION', 1, 0, NULL),
		('', '782', 'SUBDIVISION LINKING ENTRY--CHRONOLOGICAL SUBDIVISION', 'SUBDIVISION LINKING ENTRY--CHRONOLOGICAL SUBDIVISION', 1, 0, NULL),
		('', '785', 'SUBDIVISION LINKING ENTRY--FORM SUBDIVISION', 'SUBDIVISION LINKING ENTRY--FORM SUBDIVISION', 1, 0, NULL),
		('', '788', 'COMPLEX LINKING ENTRY DATA', 'COMPLEX LINKING ENTRY DATA', 0, 0, NULL),
		('', '856', 'ELECTRONIC LOCATION AND ACCESS', 'ELECTRONIC LOCATION AND ACCESS', 1, 0, NULL),
		('', '880', 'ALTERNATE GRAPHIC REPRESENTATION', 'ALTERNATE GRAPHIC REPRESENTATION', 1, 0, NULL),
		('', '883', 'MACHINE-GENERATED METADATA PROVENANCE', 'MACHINE-GENERATED METADATA PROVENANCE', 1, 0, NULL),
		('', '942', 'KOHA INTERNAL USE', 'KOHA INTERNAL USE', 0, 1, NULL);



INSERT INTO `auth_subfield_structure` (`authtypecode`, `tagfield`, `tagsubfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `tab`, `authorised_value`, `value_builder`, `seealso`, `isurl`, `hidden`, `linkid`, `kohafield`, `frameworkcode`) VALUES
		('', '000', '@', 'fixed length control field', 'fixed length control field', 0, 1, 0, NULL, 'marc21_leader_authorities.pl', NULL, 0, 0, '', '', ''),
		('', '001', '@', 'control field', 'control field', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', 'auth_header.authid', ''),
		('', '003', '@', 'control field', 'control field', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
		('', '005', '@', 'control field', 'control field', 0, 1, 0, NULL, 'marc21_field_005.pl', NULL, 0, 0, '', '', ''),
		('', '008', '@', 'fixed length control field', 'fixed length control field', 0, 1, 0, NULL, 'marc21_field_008_authorities.pl', NULL, 0, 0, '', '', ''),
		('', '010', 'a', 'LC control number', 'LC control number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '010', 'z', 'Canceled/invalid LC control number', 'Canceled/invalid LC control number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '010', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '014', 'a', 'Control number of related bibliographic record', 'Control number of related bibliographic record', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '014', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '014', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '016', 'a', 'Record control number', 'Record control number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '016', 'z', 'Canceled or invalid record control number', 'Canceled or invalid record control number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '016', '2', 'Source', 'Source', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '016', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '020', 'a', 'International Standard Book Number', 'International Standard Book Number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '020', 'c', 'Terms of availability', 'Terms of availability', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '020', 'z', 'Canceled/invalid ISBN', 'Canceled/invalid ISBN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '020', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '020', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '022', 'a', 'International Standard Serial Number', 'International Standard Serial Number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '022', 'l', 'ISSN-L', 'ISSN-L', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '022', 'm', 'Canceled ISSN-L', 'Canceled ISSN-L', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '022', 'y', 'Incorrect ISSN', 'Incorrect ISSN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '022', 'z', 'Canceled ISSN', 'Canceled ISSN', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '022', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '022', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', 'a', 'Standard number or code', 'Standard number or code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', 'c', 'Terms of availability', 'Terms of availability', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', 'd', 'Additional codes following the standard number or code', 'Additional codes following the standard number or code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', 'z', 'Canceled/invalid standard number or code', 'Canceled/invalid standard number or code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', '2', 'Source of number or code', 'Source of number or code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '024', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'a', 'Number of work', 'Number of work', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'b', 'Number of movement', 'Number of movement', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'c', 'Number of excerpt', 'Number of excerpt', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'd', 'Caption or heading', 'Caption or heading', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'e', 'Role', 'Role', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'g', 'Clef', 'Clef', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'm', 'Voice/instrument', 'Voice/instrument', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'n', 'Key signature', 'Key signature', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'o', 'Time signature', 'Time signature', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'p', 'Musical notation', 'Musical notation', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'q', 'General note', 'General note', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'r', 'Key or mode', 'Key or mode', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 's', 'Coded validity note', 'Coded validity note', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 't', 'Text incipit', 'Text incipit', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'y', 'Link text', 'Link text', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', 'z', 'Public note', 'Public note', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', '2', 'System code', 'System code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '031', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '034', 'd', 'Coordinates - westernmost longitude', 'Coordinates - westernmost longitude', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '034', 'e', 'Coordinates - easternmost longitude', 'Coordinates - easternmost longitude', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '034', 'f', 'Coordinates - northernmost latitude', 'Coordinates - northernmost latitude', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '034', 'g', 'Coordinates - southernmost latitude', 'Coordinates - southernmost latitude', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '034', 'j', 'Declination - northern limit', 'Declination - northern limit', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '034', 'k', 'Declination - southern limit', 'Declination - southern limit', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '034', 'm', 'Right ascension - eastern limit', 'Right ascension - eastern limit', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '034', 'n', 'Right ascension - western limit', 'Right ascension - western limit', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'p', 'Equinox', 'Equinox', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'r', 'Distance from earth', 'Distance from earth',  1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 's', 'G-ring latitude', 'G-ring latitude', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 't', 'G-ring longitude', 'G-ring longitude', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'x', 'Beginning date', 'Beginning date', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'y', 'Ending date', 'Ending date', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', 'z', 'Name of extraterrestrial body', 'Name of extraterrestrial body', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', '0', 'Authority record control number or standard number', 'Authority record control number or standard number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', '2', 'Source', 'Source', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', '3', 'Materials specified', 'Materials specified', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '034', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '035', 'a', 'System control number', 'System control number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '035', 'z', 'Canceled/invalid system control number', 'Canceled/invalid system control number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '035', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '035', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', 'a', 'Original cataloging agency', 'Original cataloging agency', 0, 1, 0, NULL, 'marc21_field_003.pl', NULL, 0, 0, '', '', ''),
		('', '040', 'b', 'Language of cataloging', 'Language of cataloging', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', 'c', 'Transcribing agency', 'Transcribing agency', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', 'd', 'Modifying agency', 'Modifying agency', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', 'e', 'Description conventions', 'Description conventions', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', 'f', 'Subject heading/thesaurus conventions', 'Subject heading/thesaurus conventions', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '040', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '042', 'a', 'Authentication code', 'Authentication code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '043', 'a', 'Geographic area code', 'Geographic area code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '043', 'b', 'Local GAC code', 'Local GAC code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '043', 'c', 'ISO code', 'ISO code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '043', '0', 'Authority record control number or standard number', 'Authority record control number or standard number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '043', '2', 'Source of local code', 'Source of local code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '043', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '043', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '045', 'a', 'Time period code', 'Time period code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '045', 'b', 'Formatted 9999 B.C. through C.E. time period', 'Formatted 9999 B.C. through C.E. time period', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '045', 'c', 'Formatted pre-9999 B.C. time period', 'Formatted pre-9999 B.C. time period', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '045', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '045', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '046', 'f', 'Birth date', 'Birth date', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '046', 'g', 'Death date', 'Death date', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '046', 'k', 'Beginning or single date created', 'Beginning or single date created', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '046', 'l', 'Ending date created', 'Ending date created', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '046', 'o', 'Single or starting date for aggregated content', 'Single or starting date for aggregated content', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '046', 'p', 'Ending date for aggregated content', 'Ending date for aggregated content', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '046', 's', 'Start period', 'Start period', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '046', 't', 'End period', 'End period', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '046', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '046', 'v', 'Source of information', 'Source of information', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '046', '2', 'Source of date scheme', 'Source of date scheme', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '046', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '046', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '050', 'a', 'Classification number', 'Classification number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '050', 'b', 'Item number', 'Item number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '050', 'd', 'Volumes/dates to which call number applies', 'Volumes/dates to which call number applies', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '050', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '050', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '050', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '052', 'a', 'Geographic classification area code', 'Geographic classification area code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '052', 'b', 'Geographic classification subarea code', 'Geographic classification subarea code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '052', 'd', 'Populated place name', 'Populated place name', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '052', '2', 'Code source', 'Code source', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '052', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '052', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '053', 'a', 'Classification number element-single number or beginning number of span', 'Classification number element--single number or beginning number of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '053', 'b', 'Classification number element-ending number of span', 'Classification number element--ending number of span', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '053', 'c', 'Explanatory term', 'Explanatory term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '053', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '053', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '053', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '055', 'a', 'Classification number', 'Classification number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '055', 'b', 'Item number', 'Item number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '055', 'd', 'Volumes/dates to which call number applies', 'Volumes/dates to which call number applies', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '055', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '055', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '055', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '058', 'a', 'LC classification number--Single number or beginning number of a range', 'LC classification number--Single number or beginning number of a range', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '058', 'b', 'LC classification number--End number of a range', 'LC classification number--End number of a range', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '058', 'c', 'Explanatory term', 'Explanatory term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '058', '5', 'Library to which class number applies', 'Library to which class number applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '058', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '060', 'a', 'Classification number', 'Classification number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '060', 'b', 'Item number', 'Item number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '060', 'd', 'Volumes/dates to which call number applies', 'Volumes/dates to which call number applies', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '060', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '060', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '060', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '063', 'a', 'NLM classification number--Single number or beginning number of a range', 'NLM classification number--Single number or beginning number of a range', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '063', 'b', 'NLM classification number--End number of a range', 'NLM classification number--End number of a range', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '063', 'c', 'Explanatory term', 'Explanatory term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '065', 'a', 'Classification number element-single number or beginning of span', 'Classification number element--single number or beginning of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '065', 'b', 'Classification number element-ending number of span', 'Classification number element--ending number of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '065', 'c', 'Explanatory term', 'Explanatory term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '065', '2', 'Number source', 'Number source', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '065', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '065', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '065', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '066', 'a', 'Primary G0 character set', 'Primary G0 character set', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '066', 'b', 'Primary G1 character set', 'Primary G1 character set', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '066', 'c', 'Alternate G0 or G1 character set', 'Alternate G0 or G1 character set', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '068', 'a', 'NLM classification number--Single number or beginning number of a range', 'NLM classification number--Single number or beginning number of a range', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '068', 'b', 'NLM classification number--End number of a range', 'NLM classification number--End number of a range', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '068', 'c', 'Explanatory term', 'Explanatory term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '068', '5', 'Library to which class number applies', 'Library to which class number applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '070', 'a', 'Classification number', 'Classification number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '070', 'b', 'Item number', 'Item number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '070', 'd', 'Volumes/dates to which call number applies', 'Volumes/dates to which call number applies', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '070', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '070', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '072', 'a', 'Subject category code', 'Subject category code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '072', 'x', 'Subject category code subdivision', 'Subject category code subdivision', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '072', '2', 'Code source', 'Code source', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '072', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '072', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '073', 'a', 'Subdivision usage', 'Subdivision usage', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '073', 'z', 'Code source', 'Code source', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '073', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '073', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '080', 'a', 'Universal Decimal Classification number', 'Universal Decimal Classification number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '080', 'b', 'Item number', 'Item number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '080', 'x', 'Common auxiliary subdivision', 'Common auxiliary subdivision', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '080', '2', 'Edition identifier', 'Edition identifier', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '080', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '080', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', 'y', 'Table sequence number for internal subarrangement or add table', 'Table sequence number for internal subarrangement or add table', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', 'a', 'Classification number', 'Classification number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', 'b', 'Item number', 'Item number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', 'd', 'Volumes/dates to which call number applies', 'Volumes/dates to which call number applies', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', '2', 'Edition number', 'Edition number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '082', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '083', 'a', 'Classification number element-single number or beginning number of span', 'Classification number element--single number or beginning number of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '083', 'b', 'Classification number element-ending number of span', 'Classification number element--ending number of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', 'c', 'Explanatory term', 'Explanatory term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '083', 'z', 'Table identification-table number', 'Table identification-table number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', '2', 'Edition number', 'Edition number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '083', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'a', 'Classification scheme code', 'Classification scheme code', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'b', 'Edition title', 'Edition title', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'c', 'Edition identifier', 'Edition identifier', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'd', 'Source edition identifier', 'Source edition identifier', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'e', 'Language code', 'Language code', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'f', 'Authorization', 'Authorization', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', 'n', 'Variations', 'Variations', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '084', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', 'a', 'Call number', 'Call number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', 'd', 'Volumes/dates to which call number applies', 'Volumes/dates to which call number applies', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', 'z', 'Canceled/invalid call number', 'Canceled/invalid call number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', '2', 'Number source', 'Number source', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '086', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '087', 'a', 'Classification number element-Single number of beginning number of span', 'Classification number element-Single number of beginning number of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '087', 'b', 'Classification number element-Ending number of span', 'Classification number element--Ending number of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '087', 'c', 'Explanatory information', 'Explanatory information', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '087', '2', 'Number source', 'Number source', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '087', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '087', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '088', 'a', 'Document shelving number (CODOC)', 'Document shelving number (CODOC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'a', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 'Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'b', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 'Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'd', 'Volumes/dates to which call number applies', 'Volumes/dates to which call number applies', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'e', 'Feature heading (OCLC)', 'Feature heading (OCLC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'f', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 'Filing suffix (OCLC) ; Footnote, FNT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'h', 'Output transaction history, HST (RLIN)', 'Output transaction history, HST (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'i', 'Output transaction instruction, INS (RLIN)', 'Output transaction instruction, INS (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'l', 'Extra card control statement, EXT (RLIN)', 'Extra card control statement, EXT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'n', 'Additional local notes, ANT (RLIN)', 'Additional local notes, ANT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'p', 'Pathfinder code, PTH (RLIN)', 'Pathfinder code, PTH (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 't', 'Field suppresion, FSP (RLIN)', 'Field suppresion, FSP (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'v', 'Volumes, VOL (RLIN)', 'Volumes, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'y', 'Date, VOL (RLIN)', 'Date, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', 'z', 'Canceled/invalid call number', 'Canceled/invalid call number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', '2', 'Number source', 'Number source', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '090', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', 'a', 'Classification number element--single number or beginning number of span', 'Classification number element--single number or beginning number of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', 'b', 'Classification number element--ending number of span', 'Classification number element--ending number of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', 'c', 'Explanatory term', 'Explanatory term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', 'z', 'Table identification--table number', 'Table identification--table number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', '2', 'Edition number', 'Edition number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '091', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', 'a', 'Classification number', 'Classification number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', 'b', 'Item number', 'Item number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', 'd', 'Volumes/dates to which call number applies', 'Volumes/dates to which call number applies', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', '2', 'Edition number', 'Edition number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '092', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', 'a', 'Classification number element--single number or beginning number of span', 'Classification number element--single number or beginning number of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', 'b', 'Classification number element--ending number of span', 'Classification number element--ending number of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', 'c', 'Explanatory term', 'Explanatory term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', 'z', 'Table identification--table number', 'Table identification--table number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', '2', 'Edition number', 'Edition number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '093', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', 'a', 'Classification number', 'Classification number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', 'b', 'Item number', 'Item number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', 'd', 'Volumes/dates to which call number applies', 'Volumes/dates to which call number applies', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', '2', 'Edition number', 'Edition number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '096', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', 'a', 'Classification number element--single number or beginning number of span', 'Classification number element--single number or beginning number of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', 'b', 'Classification number element--ending number of span', 'Classification number element--ending number of span', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', 'c', 'Explanatory term', 'Explanatory term', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', 'z', 'Table identification--table number', 'Table identification--table number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', '2', 'Edition number', 'Edition number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '097', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', 'a', 'Call number based on other classification scheme', 'Call number based on other classification scheme', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', 'b', 'Item number', 'Item number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', 'd', 'Volumes/dates to which call number applies', 'Volumes/dates to which call number applies', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', '2', 'Edition number', 'Edition number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '098', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', 'a', 'Classification number', 'Classification number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', 'b', 'Item number', 'Item number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', 'd', 'Volumes/dates to which call number applies', 'Volumes/dates to which call number applies', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', 'e', 'Feature heading', 'Feature heading', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', 'f', 'Filing suffix', 'Filing suffix', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', '2', 'Edition number', 'Edition number', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', '6', 'Linkage', 'Linkage', 0, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '099', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 0, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'a', 'Personal name', 'Personal name', 0, 0, 1, NULL, NULL, '''100b'',''100c'',''100q'',''100d'',''100t'',''100o'',''100m'',''100r'',''100s'',''100k'',''100n'',''100p'',''100g'',''100l'',''100f'',''100h'',''100x'',''100z'',''100y'',''100v''', 0, 0, '', '', ''),
		('', '100', 'b', 'Numeration', 'Numeration', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'c', 'Titles and other words associated with a name', 'Titles and other words associated with a name', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'd', 'Dates associated with a name', 'Dates associated with a name', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'e', 'Relator term', 'Relator term', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'f', 'Date of a work', 'Date of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'h', 'Medium', 'Medium', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'j', 'Attribution qualifier', 'Attribution qualifier', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'k', 'Form subheading', 'Form subheading', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'l', 'Language of a work', 'Language of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'n', 'Number of part/section of a work', 'Number of part/section of a work', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'o', 'Arranged statement for music', 'Arranged statement for music', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'q', 'Fuller form of name', 'Fuller form of name', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'r', 'Key for music', 'Key for music', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 's', 'Version', 'Version', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 't', 'Title of a work', 'Title of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'x', 'General subdivision', 'General subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '100', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'a', 'Corporate name or jurisdiction name as entry element', 'Corporate name or jurisdiction name as entry element', 0, 0, 1, NULL, NULL, '''110b'',''110c'',''110d'',''110t'',''110o'',''110m'',''110r'',''110s'',''110k'',''110n'',''110p'',''110g'',''110l'',''110f'',''110h'',''110x'',''110z'',''110y'',''110v''', 0, 0, '', '', ''),
		('', '110', 'b', 'Subordinate unit', 'Subordinate unit', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'c', 'Location of meeting', 'Location of meeting', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'd', 'Date of meeting or treaty signing', 'Date of meeting or treaty signing', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'e', 'Relator term', 'Relator term', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'f', 'Date of a work', 'Date of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'h', 'Medium', 'Medium', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'k', 'Form subheading', 'Form subheading', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'l', 'Language of a work', 'Language of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'n', 'Number of part/section/meeting', 'Number of part/section/meeting', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'o', 'Arranged statement for music', 'Arranged statement for music', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'r', 'Key for music', 'Key for music', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 's', 'Version', 'Version', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 't', 'Title of a work', 'Title of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'x', 'General subdivision', 'General subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '110', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'a', 'Meeting name or jurisdiction name as entry element', 'Meeting name or jurisdiction name as entry element', 0, 0, 1, NULL, NULL, '''111e'',''111c'',''111d'',''111t'',''111s'',''111k'',''111n'',''111p'',''111g'',''111l'',''111f'',''111h'',''111x'',''111z'',''111y'',''111v''', 0, 0, '', '', ''),
		('', '111', 'b', 'Number [OBSOLETE]', 'Number [OBSOLETE]', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'c', 'Location of meeting', 'Location of meeting', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'd', 'Date of meeting', 'Date of meeting', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'e', 'Subordinate unit', 'Subordinate unit', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'f', 'Date of a work', 'Date of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'h', 'Medium', 'Medium', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'j', 'Relator term', 'Relator term', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'k', 'Form subheading', 'Form subheading', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'l', 'Language of a work', 'Language of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'n', 'Number of part/section/meeting', 'Number of part/section/meeting', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'q', 'Name of meeting following jurisdiction name entry element', 'Name of meeting following jurisdiction name entry element', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 's', 'Version', 'Version', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 't', 'Title of a work', 'Title of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'x', 'General subdivision', 'General subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '111', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'a', 'Uniform title', 'Uniform title', 0, 0, 1, NULL, NULL, '''130o'',''130m'',''130r'',''130s'',''130d'',''130k'',''130n'',''130p'',''130g'',''130l'',''130f'',''130h'',''130t'',''130x'',''130z'',''130y'',''130v''', 0, 0, '', '', ''),
		('', '130', 'd', 'Date of treaty signing', 'Date of treaty signing', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'f', 'Date of a work', 'Date of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'h', 'Medium', 'Medium', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'k', 'Form subheading', 'Form subheading', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'l', 'Language of a work', 'Language of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'n', 'Number of part/section of a work', 'Number of part/section of a work', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'o', 'Arranged statement for music', 'Arranged statement for music', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'r', 'Key for music', 'Key for music', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 's', 'Version', 'Version', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 't', 'Title of a work', 'Title of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'x', 'General subdivision', 'General subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '130', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'a', 'Uniform title', 'Uniform title', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'd', 'Date of treaty', 'Date of treaty', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'f', 'Date of a work', 'Date of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'h', 'General material designation', 'General material designation', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'k', 'Form subheading', 'Form subheading', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'l', 'Language', 'Language', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'n', 'Number of part or section/serial, thematic, or opus number', 'Number of part or section/serial, thematic, or opus number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'o', 'Arranged or arr. for music', 'Arranged or arr. for music', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'p', 'Part or section', 'Part or section', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'r', 'Key for music', 'Key for music', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'x', 'General subject subdivision', 'General subject subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'y', 'Period subject subdivision', 'Period subject subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '140', 'z', 'Place subject subdivision', 'Place subject subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'a', 'Collective title', 'Collective title', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'd', 'Date of treaty', 'Date of treaty', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'f', 'Date of a work', 'Date of a work', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'h', 'General material designation', 'General material designation', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'k', 'Form subheading', 'Form subheading', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'l', 'Language', 'Language', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'n', 'Number of part or section/serial, thematic, or opus number', 'Number of part or section/serial, thematic, or opus number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'o', 'Arranged or arr. for music', 'Arranged or arr. for music', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'p', 'Part or section', 'Part or section', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 'r', 'Key for music', 'Key for music', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '143', 's', 'Version', 'Version', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '148', 'a', 'Chronological term', 'Chronological term', 0, 0, 1, NULL, NULL, '''148y'',''148x'',''148z'',''148v''', 0, 0, '', '', ''),
		('', '148', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '148', 'x', 'General subdivision', 'General subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '148', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '148', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '148', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '148', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '150', 'a', 'Topical term or geographic name entry element', 'Topical term or geographic name entry element', 0, 0, 1, NULL, NULL, '''150x'',''150z'',''150y'',''150v''', 0, 0, '', '', ''),
        ('', '150', 'b', 'Topical term following geographic name entry element', 'Topical term following geographic name entry element', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '150', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '150', 'x', 'General subdivision', 'General subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '150', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '150', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '150', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '150', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', 'a', 'Geographic name', 'Geographic name', 0, 0, 1, NULL, NULL, '''151z'',''151x'',''151y'',''151v''', 0, 0, '', '', ''),
		('', '151', 'b', 'Name following place as an entry element {OBSOLETE]', 'Name following place as an entry element {OBSOLETE]', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', 'x', 'General subdivision', 'General subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '151', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', 'h', 'Caption hierarchy', 'Caption hierarchy', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', 'j', 'Caption', 'Caption', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', 'k', 'Summary number span caption hierarchy', 'Summary number span caption hierarchy', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', 'z', 'Table identification', 'Table identification', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '153', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '154', 'a', 'General explanatory index term', 'General explanatory index term', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '154', 'b', 'General explanatory index term--Succeeding level', 'General explanatory index term--Succeeding level', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '154', 'f', 'Schedule identification', 'Schedule identification', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '154', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '154', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '155', 'a', 'Genre/form term', 'Genre/form term', 0, 0, 1, NULL, NULL, '''155v'',''155x'',''155z'',''155y''', 0, 0, '', '', ''),
		('', '155', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '155', 'x', 'General subdivision', 'General subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '155', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '155', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '155', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '155', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '162', 'a', 'Medium of performance term', 'Medium of performance term', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '162', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '162', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '180', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '180', 'x', 'General subdivision', 'General subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '180', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '180', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '180', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '180', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '181', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '181', 'x', 'General subdivision', 'General subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '181', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '181', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '181', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '181', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '182', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '182', 'x', 'General subdivision', 'General subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '182', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '182', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '182', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '182', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '185', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '185', 'x', 'General subdivision', 'General subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '185', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '185', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '185', '6', 'Linkage', 'Linkage', 0, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '185', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 1, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', 'a', 'Classification number referred to--Single number or beginning number of span', 'Classification number referred to--Single number or beginning number of span', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', 'c', 'Classification number referred to--Ending number of span', 'Classification number referred to--Ending number of span', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', 'z', 'Table identification', 'Table identification', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', '6', 'Linkage', 'Linkage', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '253', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '260', 'a', 'Heading referred to', 'Heading referred to', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '260', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '260', '0', 'Authority record control number', 'Authority record control number', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '260', '6', 'Linkage', 'Linkage', 0, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '260', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 2, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '336', 'a', 'Content type term', 'Content type term', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '336', 'b', 'Content type code', 'Content type code', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '336', '2', 'Source', 'Source', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '336', '3', 'Materials specified', 'Materials specified', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '336', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '336', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', 'a', 'Classification number referred to--Single number or beginning number of span', 'Classification number referred to--Single number or beginning number of span', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', 'c', 'Classification number referred to--Ending number of span', 'Classification number referred to--Ending number of span', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', 'z', 'Table identification', 'Table identification', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '353', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '360', 'a', 'Heading referred to', 'Heading referred to', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '360', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '360', '0', 'Authority record control number', 'Authority record control number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '360', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '360', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '368', 'a', 'Type of corporate body', 'Type of corporate body', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '368', 'b', 'Type of jurisdiction', 'Type of jurisdiction', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '368', 'c', 'Other designation', 'Other designation', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '368', 'd', 'Title of person', 'Title of person', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '368', 's', 'Start period', 'Start period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '368', 't', 'End period', 'End period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '368', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '368', 'v', 'Source of information', 'Source of information', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '368', '0', 'Authority record control number or standard number', 'Authority record control number or standard number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '368', '2', 'Source', 'Source', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '368', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '368', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', 'a', 'Place of birth', 'Place of birth', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', 'b', 'Place of death', 'Place of death', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', 'c', 'Associated country', 'Associated country', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', 'e', 'Place of residence/headquarters', 'Place of residence/headquarters', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', 'f', 'Other associated place', 'Other associated place', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', 'g', 'Place of origin of work', 'Place of origin of work', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', 's', 'Start period', 'Start period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', 't', 'End period', 'End period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', 'v', 'Source of information', 'Source of information', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', '0', 'Record control number', 'Record control number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', '2', 'Source of term', 'Source of term', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '370', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', 'a', 'Address', 'Address', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', 'b', 'City', 'City', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', 'c', 'Intermediate jurisdiction', 'Intermediate jurisdiction', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', 'd', 'Country', 'Country', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', 'e', 'Postal code', 'Postal code', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', 'm', 'Electronic mail address', 'Electronic mail address', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', 's', 'Start period', 'Start period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', 't', 'End period', 'End period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', 'v', 'Source of information', 'Source of information', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', 'z', 'Public note', 'Public note', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', '4', 'Relator code', 'Relator code', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '371', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '372', 'a', 'Field of activity', 'Field of activity', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '372', 's', 'Start period', 'Start period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '372', 't', 'End period', 'End period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '372', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '372', 'v', 'Source of information', 'Source of information', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '372', '0', 'Record control number', 'Record control number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '372', '2', 'Source of term', 'Source of term', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '372', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '372', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '373', 'a', 'Associated group', 'Associated group', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '373', 's', 'Start period', 'Start period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '373', 't', 'End period', 'End period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '373', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '373', 'v', 'Source of information', 'Source of information', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '373', '0', 'Record control number', 'Record control number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '373', '2', 'Source of term', 'Source of term', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '373', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '373', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '374', 'a', 'Occupation', 'Occupation', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '374', 's', 'Start period', 'Start period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '374', 't', 'End period', 'End period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '374', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '374', 'v', 'Source of information', 'Source of information', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '374', '0', 'Record control number', 'Record control number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '374', '2', 'Source of term', 'Source of term', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '374', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '374', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '375', 'a', 'Gender', 'Gender', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '375', 's', 'Start period', 'Start period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '375', 't', 'End period', 'End period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '375', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '375', 'v', 'Source of information', 'Source of information', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '375', '2', 'Source of term', 'Source of term', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '375', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '375', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '376', 'a', 'Type of family', 'Type of family', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '376', 'b', 'Name of prominent member', 'Name of prominent member', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '376', 'c', 'Hereditary title', 'Hereditary title', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '376', 's', 'Start period', 'Start period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '376', 't', 'End period', 'End period', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '376', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '376', 'v', 'Source of information', 'Source of information', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '376', '0', 'Record control number', 'Record control number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '376', '2', 'Source of term', 'Source of term', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '376', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '376', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '377', 'a', 'Language code', 'Language code', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '377', 'l', 'Language term', 'Language term', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '377', '2', 'Source of code', 'Source of code', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '377', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '377', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '378', 'q', 'Fuller form of personal name', 'Fuller form of personal name', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '378', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '378', 'v', 'Source of information', 'Source of information', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '378', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '378', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '380', 'a', 'Form of work', 'Form of work', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '380', '0', 'Record control number', 'Record control number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '380', '2', 'Source of term', 'Source of term', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '380', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '380', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '381', 'a', 'Other distinguishing characteristic', 'Other distinguishing characteristic', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '381', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '381', 'v', 'Source of information', 'Source of information', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '381', '0', 'Record control number', 'Record control number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '381', '2', 'Source of term', 'Source of term', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '381', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '381', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '382', 'a', 'Medium of performance', 'Medium of performance', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '382', 'b', 'Soloist', 'Soloist', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '382', 'd', 'Doubling instrument', 'Doubling instrument', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '382', 'n', 'Number of performers of the same medium', 'Number of performers of the same medium', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '382', 'p', 'Alternative medium of performance', 'Alternative medium of performance', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '382', 's', 'Total number of performers', 'Total number of performers', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '382', 'v', 'Note', 'Note', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '382', '0', 'Authority record control number or standard number', 'Authority record control number or standard number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '382', '2', 'Source of term', 'Source of term', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '382', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '382', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '383', 'a', 'Serial number', 'Serial number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '383', 'b', 'Opus number', 'Opus number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '383', 'c', 'Thematic index number', 'Thematic index number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '383', 'd', 'Thematic index code', 'Thematic index code', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '383', 'e', 'Publisher associated with opus number', 'Publisher associated with opus number', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '383', '2', 'Source', 'Source', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '383', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '383', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '384', 'a', 'Key', 'Key', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '384', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '384', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '385', 'a', 'Audience term', 'Audience term', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '385', 'b', 'Audience code', 'Audience code', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '385', 'm', 'Demographic group term', 'Demographic group term', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '385', 'n', 'Demographic group code', 'Demographic group code', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '385', '0', 'Authority record control number or standard number', 'Authority record control number or standard number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '385', '2', 'Source', 'Source', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '385', '3', 'Materials specified', 'Materials specified', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '385', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '385', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '386', 'a', 'Creator/contributor term', 'Creator/contributor term', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '386', 'b', 'Creator/contributor code', 'Creator/contributor code', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '386', 'm', 'Demographic group term', 'Demographic group term', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '386', 'n', 'Demographic group code', 'Demographic group code', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '386', '0', 'Authority record control number or standard number', 'Authority record control number or standard number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '386', '2', 'Source', 'Source', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '386', '3', 'Materials specified', 'Materials specified', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '386', '6', 'Linkage', 'Linkage', 0, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '386', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 3, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'a', 'Personal name', 'Personal name', 0, 0, 4, NULL, NULL, '''400b'',''400c'',''400q'',''400d'',''400t'',''400o'',''400m'',''400r'',''400s'',''400k'',''400n'',''400p'',''400g'',''400l'',''400f'',''400h'',''400x'',''400z'',''400y'',''400v''', 0, 0, '', '', 'PERSO_NAME'),
		('', '400', 'b', 'Numeration', 'Numeration', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'c', 'Titles and other words associated with a name', 'Titles and other words associated with a name', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'd', 'Dates associated with a name', 'Dates associated with a name', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'e', 'Relator term', 'Relator term', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'f', 'Date of a work', 'Date of a work', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'i', 'Relationship information', 'Relationship information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'j', 'Attribution qualifier', 'Attribution qualifier', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'k', 'Form subheading', 'Form subheading', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'l', 'Language of a work', 'Language of a work', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'n', 'Number of part/section of a work', 'Number of part/section of a work', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'o', 'Arranged statement for music', 'Arranged statement for music', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'q', 'Fuller form of name', 'Fuller form of name', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'r', 'Key for music', 'Key for music', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 't', 'Title of a work', 'Title of a work', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'x', 'General subdivision', 'General subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', '4', 'Relationship code', 'Relationship code', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '400', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '410', 'a', 'Corporate name or jurisdiction name as entry element', 'Corporate name or jurisdiction name as entry element', 0, 0, 4, NULL, NULL, '''410b'',''410c'',''410d'',''410t'',''410o'',''410m'',''410r'',''410s'',''410k'',''410n'',''410p'',''410g'',''410l'',''410f'',''410h'',''410x'',''410z'',''410y'',''410v''', 0, 0, '', '', 'CORPO_NAME'),
		('', '410', 'b', 'Subordinate unit', 'Subordinate unit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'c', 'Location of meeting', 'Location of meeting', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'd', 'Date of meeting or treaty signing', 'Date of meeting or treaty signing', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'e', 'Relator term', 'Relator term', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'f', 'Date of a work', 'Date of a work', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'i', 'Relationship information', 'Relationship information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'k', 'Form subheading', 'Form subheading', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'l', 'Language of a work', 'Language of a work', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'n', 'Number of part/section/meeting', 'Number of part/section/meeting', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'o', 'Arranged statement for music', 'Arranged statement for music', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'r', 'Key for music', 'Key for music', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 't', 'Title of a work', 'Title of a work', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'x', 'General subdivision', 'General subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', '4', 'Relationship code', 'Relationship code', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '410', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '411', 'a', 'Meeting name or jurisdiction name as entry element', 'Meeting name or jurisdiction name as entry element', 0, 0, 4, NULL, NULL, '''411e'',''411c'',''411d'',''411t'',''411s'',''411k'',''411n'',''411p'',''411g'',''411l'',''411f'',''411h'',''411x'',''411z'',''411y'',''411v''', 0, 0, '', '', 'MEETI_NAME'),
		('', '411', 'b', 'Number {OBSOLETE]', 'Number {OBSOLETE]', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'c', 'Location of meeting', 'Location of meeting', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'd', 'Date of meeting', 'Date of meeting', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'e', 'Subordinate unit', 'Subordinate unit', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'f', 'Date of a work', 'Date of a work', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'i', 'Relationship information', 'Relationship information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'j', 'Relator term', 'Relator term', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'k', 'Form subheading', 'Form subheading', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'l', 'Language of a work', 'Language of a work', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'n', 'Number of part/section/meeting', 'Number of part/section/meeting', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'q', 'Name of meeting following jurisdiction name entry element', 'Name of meeting following jurisdiction name entry element', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 't', 'Title of a work', 'Title of a work', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'x', 'General subdivision', 'General subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', '4', 'Relationship code', 'Relationship code', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '411', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '430', 'a', 'Uniform title', 'Uniform title', 0, 0, 4, NULL, NULL, '''430o'',''430m'',''430r'',''430s'',''430d'',''430k'',''430n'',''430p'',''430g'',''430l'',''430f'',''430h'',''430t'',''430x'',''430z'',''430y'',''430v''', 0, 0, '', '', 'UNIF_TITLE'),
		('', '430', 'd', 'Date of treaty signing', 'Date of treaty signing', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'f', 'Date of a work', 'Date of a work', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'h', 'Medium', 'Medium', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'i', 'Relationship information', 'Relationship information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'k', 'Form subheading', 'Form subheading', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'l', 'Language of a work', 'Language of a work', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'n', 'Number of part/section of a work', 'Number of part/section of a work', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'o', 'Arranged statement for music', 'Arranged statement for music', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'r', 'Key for music', 'Key for music', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 's', 'Version', 'Version', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 't', 'Title of a work', 'Title of a work', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'x', 'General subdivision', 'General subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', '4', 'Relationship code', 'Relationship code', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '430', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '448', 'a', 'Chronological term', 'Chronological term', 0, 0, 4, NULL, NULL, '''448y'',''448x'',''448z'',''448v''', 0, 0, '', '', 'CHRON_TERM'),
		('', '448', 'i', 'Relationship information', 'Relationship information', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', 'x', 'General subdivision', 'General subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', '4', 'Relationship code', 'Relationship code', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '448', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '450', 'a', 'Topical term or geographic name entry element', 'Topical term or geographic name entry element', 0, 0, 4, NULL, NULL, '''450x'',''450z'',''450y'',''450v''', 0, 0, '', '', 'TOPIC_TERM'),
		('', '450', 'b', 'Topical term following geographic name entry element', 'Topical term following geographic name entry element', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', 'i', 'Relationship information', 'Relationship information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', 'x', 'General subdivision', 'General subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', '4', 'Relationship code', 'Relationship code', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '450', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '451', 'a', 'Geographic name', 'Geographic name', 0, 0, 4, NULL, NULL, '''451z'',''451x'',''451y'',''451v''', 0, 0, '', '', 'GEOGR_NAME'),
		('', '451', 'i', 'Relationship information', 'Relationship information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', 'x', 'General subdivision', 'General subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', '4', 'Relationship code', 'Relationship code', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '451', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '453', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'c', 'Classification element-Ending number of span', 'Classification element-Ending number of span', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'h', 'Caption hierarchy', 'Caption hierarchy', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'i', 'Relationship information', 'Relationship information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'j', 'Caption', 'Caption', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'k', 'Summary number span caption hierarchy', 'Summary number span caption hierarchy', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 't', 'Topic', 'Topic', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', 'z', 'Table identification', 'Table identification', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '453', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '455', 'a', 'Genre/form term', 'Genre/form term', 0, 0, 4, NULL, NULL, '''455v'',''455x'',''455z'',''455y''', 0, 0, '', '', 'GENRE/FORM'),
		('', '455', 'i', 'Relationship information', 'Relationship information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', 'x', 'General subdivision', 'General subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', '4', 'Relationship code', 'Relationship code', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '455', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, '', '', ''),
        ('', '462', 'a', 'Medium of performance term', 'Medium of performance term', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '462', 'i', 'Relationship information', 'Relationship information', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '462', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '462', '4', 'Relationship code', 'Relationship code', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '462', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '462', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '462', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', 'i', 'Relationship information', 'Relationship information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', 'x', 'General subdivision', 'General subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', '4', 'Relationship code', 'Relationship code', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '480', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', 'i', 'Relationship information', 'Relationship information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', 'x', 'General subdivision', 'General subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', '4', 'Relationship code', 'Relationship code', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '481', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', 'i', 'Relationship information', 'Relationship information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', 'x', 'General subdivision', 'General subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', '4', 'Relationship code', 'Relationship code', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '482', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', 'i', 'Relationship information', 'Relationship information', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', 'w', 'Control subfield', 'Control subfield', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', 'x', 'General subdivision', 'General subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', '4', 'Relationship code', 'Relationship code', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', '6', 'Linkage', 'Linkage', 0, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '485', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 4, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'a', 'Personal name', 'Personal name', 0, 0, 5, NULL, NULL, '''500b'',''500c'',''500q'',''500d'',''500t'',''500o'',''500m'',''500r'',''500s'',''500k'',''500n'',''500p'',''500g'',''500l'',''500f'',''500h'',''500x'',''500z'',''500y'',''500v''', 0, 0, '', '', 'PERSO_NAME'),
		('', '500', 'b', 'Numeration', 'Numeration', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'c', 'Titles and other words associated with a name', 'Titles and other words associated with a name', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'd', 'Dates associated with a name', 'Dates associated with a name', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'e', 'Relator term', 'Relator term', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'f', 'Date of a work', 'Date of a work', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'i', 'Relationship information', 'Relationship information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'j', 'Attribution qualifier', 'Attribution qualifier', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'k', 'Form subheading', 'Form subheading', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'l', 'Language of a work', 'Language of a work', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'n', 'Number of part/section of a work', 'Number of part/section of a work', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'o', 'Arranged statement for music', 'Arranged statement for music', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'q', 'Fuller form of name', 'Fuller form of name', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'r', 'Key for music', 'Key for music', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 't', 'Title of a work', 'Title of a work', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'x', 'General subdivision', 'General subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', '0', 'Record control number', 'Record control number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', '4', 'Relationship code', 'Relationship code', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '500', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '510', 'a', 'Corporate name or jurisdiction name as entry element', 'Corporate name or jurisdiction name as entry element', 0, 0, 5, NULL, NULL, '''510b'',''510c'',''510d'',''510t'',''510o'',''510m'',''510r'',''510s'',''510k'',''510n'',''510p'',''510g'',''510l'',''510f'',''510h'',''510x'',''510z'',''510y'',''510v''', 0, 0, '', '', 'CORPO_NAME'),
		('', '510', 'b', 'Subordinate unit', 'Subordinate unit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'c', 'Location of meeting', 'Location of meeting', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'd', 'Date of meeting or treaty signing', 'Date of meeting or treaty signing', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'e', 'Relator term', 'Relator term', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'f', 'Date of a work', 'Date of a work', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'i', 'Relationship information', 'Relationship information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'k', 'Form subheading', 'Form subheading', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'l', 'Language of a work', 'Language of a work', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'n', 'Number of part/section/meeting', 'Number of part/section/meeting', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'o', 'Arranged statement for music', 'Arranged statement for music', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'r', 'Key for music', 'Key for music', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 't', 'Title of a work', 'Title of a work', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'x', 'General subdivision', 'General subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', '0', 'Record control number', 'Record control number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', '4', 'Relationship code', 'Relationship code', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '510', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '511', 'a', 'Meeting name or jurisdiction name as entry element', 'Meeting name or jurisdiction name as entry element', 0, 0, 5, NULL, NULL, '''511e'',''511c'',''511d'',''511t'',''511s'',''511k'',''511n'',''511p'',''511g'',''511l'',''511f'',''511h'',''511x'',''511z'',''511y'',''511v''', 0, 0, '', '', 'MEETI_NAME'),
		('', '511', 'c', 'Location of meeting', 'Location of meeting', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'd', 'Date of meeting', 'Date of meeting', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'e', 'Subordinate unit', 'Subordinate unit', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'f', 'Date of a work', 'Date of a work', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'i', 'Relationship information', 'Relationship information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'j', 'Relator term', 'Relator term', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'k', 'Form subheading', 'Form subheading', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'l', 'Language of a work', 'Language of a work', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'n', 'Number of part/section/meeting', 'Number of part/section/meeting', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'q', 'Name of meeting following jurisdiction name entry element', 'Name of meeting following jurisdiction name entry element', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 't', 'Title of a work', 'Title of a work', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'x', 'General subdivision', 'General subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', '0', 'Record control number', 'Record control number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', '4', 'Relationship code', 'Relationship code', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '511', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '530', 'a', 'Uniform title', 'Uniform title', 0, 0, 5, NULL, NULL, '''530o'',''530m'',''530r'',''530s'',''530d'',''530k'',''530n'',''530p'',''530g'',''530l'',''530f'',''530h'',''530t'',''530x'',''530z'',''530y'',''530v''', 0, 0, '', '', 'UNIF_TITLE'),
		('', '530', 'd', 'Date of treaty signing', 'Date of treaty signing', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'f', 'Date of a work', 'Date of a work', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'h', 'Medium', 'Medium', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'i', 'Relationship information', 'Relationship information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'k', 'Form subheading', 'Form subheading', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'l', 'Language of a work', 'Language of a work', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'n', 'Number of part/section of a work', 'Number of part/section of a work', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'o', 'Arranged statement for music', 'Arranged statement for music', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'r', 'Key for music', 'Key for music', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 's', 'Version', 'Version', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 't', 'Title of a work', 'Title of a work', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'x', 'General subdivision', 'General subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', '0', 'Record control number', 'Record control number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', '4', 'Relationship code', 'Relationship code', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '530', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '548', 'a', 'Chronological term', 'Chronological term', 0, 0, 5, NULL, NULL, '''548y'',''548x'',''548z'',''548v''', 0, 0, '', '', 'CHRON_TERM'),
		('', '548', 'i', 'Relationship information', 'Relationship information', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', 'x', 'General subdivision', 'General subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', '0', 'Record control number', 'Record control number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', '4', 'Relationship code', 'Relationship code', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '548', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '550', 'a', 'Topical term or geographic name entry element', 'Topical term or geographic name entry element', 0, 0, 5, NULL, NULL, '''550x'',''550z'',''550y'',''550v''', 0, 0, '', '', 'TOPIC_TERM'),
		('', '550', 'b', 'Topical term following geographic name entry element', 'Topical term following geographic name entry element', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', 'i', 'Relationship information', 'Relationship information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', 'x', 'General subdivision', 'General subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', '0', 'Record control number', 'Record control number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', '4', 'Relationship code', 'Relationship code', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '550', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '551', 'a', 'Geographic name', 'Geographic name', 0, 0, 5, NULL, NULL, '''551z'',''551x'',''551y'',''551v''', 0, 0, '', '', 'GEOGR_NAME'),
		('', '551', 'i', 'Relationship information', 'Relationship information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', 'x', 'General subdivision', 'General subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', '0', 'Record control number', 'Record control number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', '4', 'Relationship code', 'Relationship code', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '551', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '553', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'h', 'Caption hierarchy', 'Caption hierarchy', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'i', 'Relationship information', 'Relationship information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'j', 'Caption', 'Caption', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'k', 'Summary number span caption hierarchy', 'Summary number span caption hierarchy', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 't', 'Topic', 'Topic', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', 'z', 'Table identification', 'Table identification', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '553', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, '', '', ''),
		('', '555', 'a', 'Genre/form term', 'Genre/form term', 0, 0, 5, NULL, NULL, '''555v'',''555x'',''555z'',''555y''', 0, 0, '', '', 'GENRE/FORM'),
		('', '555', 'i', 'Relationship information', 'Relationship information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', 'x', 'General subdivision', 'General subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', '0', 'Record control number', 'Record control number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', '4', 'Relationship code', 'Relationship code', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '555', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, '', '', ''),
        ('', '562', 'a', 'Medium of performance term', 'Medium of performance term', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '562', 'i', 'Relationship information', 'Relationship information', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '562', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '562', '0', 'Authority record control number or standard number', 'Authority record control number or standard number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '562', '4', 'Relationship code', 'Relationship code', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '562', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '562', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '562', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', 'i', 'Relationship information', 'Relationship information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', 'x', 'General subdivision', 'General subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', '0', 'Record control number', 'Record control number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', '4', 'Relationship code', 'Relationship code', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '580', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', 'i', 'Relationship information', 'Relationship information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', 'x', 'General subdivision', 'General subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', '0', 'Record control number', 'Record control number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', '4', 'Relationship code', 'Relationship code', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '581', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', 'i', 'Relationship information', 'Relationship information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', 'x', 'General subdivision', 'General subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', '0', 'Record control number', 'Record control number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', '4', 'Relationship code', 'Relationship code', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '582', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', 'i', 'Relationship information', 'Relationship information', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', 'w', 'Control subfield', 'Control subfield', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', 'x', 'General subdivision', 'General subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', '0', 'Record control number', 'Record control number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', '4', 'Relationship code', 'Relationship code', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', '6', 'Linkage', 'Linkage', 0, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '585', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 5, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '640', 'a', 'Dates of publication and/or sequential designation', 'Dates of publication and/or sequential designation', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '640', 'z', 'Source of information', 'Source of information', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '640', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '640', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '641', 'a', 'Numbering peculiarities note', 'Numbering peculiarities note', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '641', 'z', 'Source of information', 'Source of information', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '641', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '641', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '642', 'a', 'Series numbering example', 'Series numbering example', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '642', 'd', 'Volumes/dates to which series numbering example applies', 'Volumes/dates to which series numbering example applies', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '642', '5', 'Institution/copy to which field applies', 'Institution/copy to which field applies', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '642', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '642', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '643', 'a', 'Place', 'Place', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '643', 'b', 'Publisher/issuing body', 'Publisher/issuing body', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '643', 'd', 'Volumes/dates to which place and publisher/issuing body apply', 'Volumes/dates to which place and publisher/issuing body apply', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '643', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '643', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '644', 'a', 'Series analysis practice', 'Series analysis practice', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '644', 'b', 'Exceptions to analysis practice', 'Exceptions to analysis practice', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '644', 'd', 'Volumes/dates to which analysis practice applies', 'Volumes/dates to which analysis practice applies', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '644', '5', 'Institution/copy to which field applies', 'Institution/copy to which field applies', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '644', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '644', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '645', 'a', 'Series tracing practice', 'Series tracing practice', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '645', 'd', 'Volumes/dates to which tracing practice applies', 'Volumes/dates to which tracing practice applies', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '645', '5', 'Institution/copy to which field applies', 'Institution/copy to which field applies', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '645', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '645', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '646', 'a', 'Series classification practice', 'Series classification practice', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '646', 'd', 'Volumes/dates to which classification practice applies', 'Volumes/dates to which classification practice applies', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '646', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '646', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '646', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '663', 'a', 'Explanatory text', 'Explanatory text', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '663', 'b', 'Heading referred to', 'Heading referred to', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '663', 't', 'Title referred to', 'Title referred to', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '663', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '663', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '664', 'a', 'Explanatory text', 'Explanatory text', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '664', 'b', 'Heading referred to', 'Heading referred to', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '664', 't', 'Title referred to', 'Title referred to', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '664', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '664', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '665', 'a', 'History reference', 'History reference', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '665', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '665', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '666', 'a', 'General explanatory reference', 'General explanatory reference', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '666', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '666', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '667', 'a', 'Nonpublic general note', 'Nonpublic general note', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '667', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '667', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '667', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '668', 'a', 'Characters in nonroman alphabet', 'Characters in nonroman alphabet', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '670', 'a', 'Source citation', 'Source citation', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '670', 'b', 'Information found', 'Information found', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '670', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '670', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '670', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '671', 'a', 'Citation', 'Citation', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '671', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '672', 'a', 'Title', 'Title', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '672', 'b', 'Remainder of title', 'Remainder of title', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '672', 'f', 'Date', 'Date', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '672', 'w', 'Bibliographic record control number', 'Bibliographic record control number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '672', '0', 'Authority record control number or standard number', 'Authority record control number or standard number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '672', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '672', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '673', 'a', 'Title', 'Title', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '673', 'b', 'Remainder of title', 'Remainder of title', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '673', 'f', 'Date', 'Date', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '673', 'w', 'Bibliographic record control number', 'Bibliographic record control number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '673', '0', 'Authority record control number or standard number', 'Authority record control number or standard number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '673', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '673', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '675', 'a', 'Source citation', 'Source citation', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '675', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '675', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '676', 'a', 'Rule number(s) and additional information', 'Rule number(s) and additional information', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '676', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '678', 'a', 'Biographical or historical data', 'Biographical or historical data', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '678', 'b', 'Expansion', 'Expansion', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '678', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '678', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '678', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', 'a', 'Heading or subdivision term', 'Heading or subdivision term', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', 'c', 'Classification number--Ending number of span [CLASSIFICATION FORMAT]', 'Classification number--Ending number of span [CLASSIFICATION FORMAT]', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '680', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '681', 'a', 'Subject heading or subdivision term', 'Subject heading or subdivision term', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '681', 'c', 'Classification number--Ending number of span [CLASSIFICATION FORMAT]', 'Classification number--Ending number of span [CLASSIFICATION FORMAT]', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '681', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '681', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '681', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '681', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '682', 'a', 'Replacement heading', 'Replacement heading', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '682', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '682', '0', 'Replacement authority record control number', 'Replacement authority record control number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '682', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '682', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', 'p', 'Corresponding classification field', 'Corresponding classification field', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '683', '8', 'Field link and sequence number', 'Field link and sequence number', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', 'j', 'Caption', 'Caption', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', 'z', 'Table identification', 'Table identification', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '684', '8', 'Field link and sequence number', 'Field link and sequence number', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '685', 'a', 'Source consulted and information found', 'Source consulted and information found', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '685', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '686', 'a', 'Source consulted and information found', 'Source consulted and information found', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '686', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '687', 'a', 'Source consulted and information found', 'Source consulted and information found', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '687', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '688', 'a', 'Application history note', 'Application history note', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '688', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '688', '6', 'Linkage', 'Linkage', 0, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '688', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 6, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'a', 'Personal name', 'Personal name', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'b', 'Numeration', 'Numeration', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'c', 'Titles and other words associated with a name', 'Titles and other words associated with a name', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'd', 'Dates associated with a name', 'Dates associated with a name', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'e', 'Relator term', 'Relator term', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'f', 'Date of a work', 'Date of a work', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'h', 'Medium', 'Medium', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'j', 'Attribution qualifier', 'Attribution qualifier', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'k', 'Form subheading', 'Form subheading', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'l', 'Language of a work', 'Language of a work', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'n', 'Number of part/section of a work', 'Number of part/section of a work', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'o', 'Arranged statement for music', 'Arranged statement for music', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'q', 'Fuller form of name', 'Fuller form of name', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'r', 'Key for music', 'Key for music', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 's', 'Version', 'Version', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 't', 'Title of a work', 'Title of a work', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'w', 'Control subfield', 'Control subfield', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'x', 'General subdivision', 'General subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '0', 'Record control number', 'Record control number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '3', 'Materials specified [CLASSIFICATION FORMAT]', 'Materials specified [CLASSIFICATION FORMAT]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '4', 'Relator code', 'Relator code', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '700', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'a', 'Corporate name or jurisdiction name as entry element', 'Corporate name or jurisdiction name as entry element', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'b', 'Subordinate unit', 'Subordinate unit', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'c', 'Location of meeting', 'Location of meeting', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'd', 'Date of meeting or treaty signing', 'Date of meeting or treaty signing', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'e', 'Relator term', 'Relator term', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'f', 'Date of a work', 'Date of a work', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'h', 'Medium', 'Medium', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'k', 'Form subheading', 'Form subheading', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'l', 'Language of a work', 'Language of a work', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'n', 'Number of part/section/meeting', 'Number of part/section/meeting', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'o', 'Arranged statement for music', 'Arranged statement for music', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'r', 'Key for music', 'Key for music', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 's', 'Version', 'Version', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 't', 'Title of a work', 'Title of a work', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'w', 'Control subfield', 'Control subfield', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'x', 'General subdivision', 'General subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '0', 'Record control number', 'Record control number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '3', 'Materials specified [CLASSIFICATION FORMAT]', 'Materials specified [CLASSIFICATION FORMAT]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '4', 'Relator code', 'Relator code', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '710', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'a', 'Meeting name or jurisdiction name as entry element', 'Meeting name or jurisdiction name as entry element', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'c', 'Location of meeting', 'Location of meeting', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'd', 'Date of meeting', 'Date of meeting', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'e', 'Subordinate unit', 'Subordinate unit', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'f', 'Date of a work', 'Date of a work', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'h', 'Medium', 'Medium', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'j', 'Relator term', 'Relator term', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'k', 'Form subheading', 'Form subheading', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'l', 'Language of a work', 'Language of a work', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'n', 'Number of part/section/meeting', 'Number of part/section/meeting', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'q', 'Name of meeting following jurisdiction name entry element', 'Name of meeting following jurisdiction name entry element', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 's', 'Version', 'Version', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 't', 'Title of a work', 'Title of a work', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'w', 'Control subfield', 'Control subfield', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'x', 'General subdivision', 'General subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '0', 'Record control number', 'Record control number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '3', 'Materials specified', 'Materials specified', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '4', 'Relator code', 'Relator code', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '711', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'a', 'Uniform title', 'Uniform title', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'd', 'Date of treaty signing', 'Date of treaty signing', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'f', 'Date of a work', 'Date of a work', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'g', 'Miscellaneous information', 'Miscellaneous information', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'h', 'Medium', 'Medium', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'k', 'Form subheading', 'Form subheading', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'l', 'Language of a work', 'Language of a work', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'm', 'Medium of performance for music', 'Medium of performance for music', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'n', 'Number of part/section of a work', 'Number of part/section of a work', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'o', 'Arranged statement for music', 'Arranged statement for music', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'p', 'Name of part/section of a work', 'Name of part/section of a work', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'r', 'Key for music', 'Key for music', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 's', 'Version', 'Version', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 't', 'Title of a work', 'Title of a work', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'w', 'Control subfield', 'Control subfield', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'x', 'General subdivision', 'General subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', '0', 'Record control number', 'Record control number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', '3', 'Materials specified [CLASSIFICATION FORMAT]', 'Materials specified [CLASSIFICATION FORMAT]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '730', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', 'a', 'Chronological term', 'Chronological term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', 'w', 'Control subfield', 'Control subfield', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', 'x', 'General subdivision', 'General subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', '0', 'Record control number', 'Record control number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', '3', 'Materials specified [CLASSIFICATION FORMAT]', 'Materials specified [CLASSIFICATION FORMAT]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '748', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '750', 'a', 'Topical term or geographic name entry element', 'Topical term or geographic name entry element', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '750', 'b', 'Topical term following geographic name entry element', 'Topical term following geographic name entry element', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'c', 'Location of event', 'Location of event', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'd', 'Active date', 'Active date', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'i', 'Explanatory text [CLASSIFICATION FORMAT]', 'Explanatory text [CLASSIFICATION FORMAT]', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'w', 'Control subfield', 'Control subfield', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'x', 'General subdivision', 'General subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', '0', 'Record control number', 'Record control number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', '3', 'Materials specified [CLASSIFICATION FORMAT]', 'Materials specified [CLASSIFICATION FORMAT]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '750', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'a', 'Geographic name', 'Geographic name', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'w', 'Control subfield', 'Control subfield', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'x', 'General subdivision', 'General subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', '0', 'Record control number', 'Record control number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', '3', 'Materials specified [CLASSIFICATION FORMAT]', 'Materials specified [CLASSIFICATION FORMAT]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '751', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'a', 'Index term', 'Index term', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'b', 'Index term--Succeeding level', 'Index term--Succeeding level', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'd', 'Index term referred from', 'Index term referred from', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'e', 'Example class number', 'Example class number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 's', 'See also reference term', 'See also reference term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 't', 'See also reference term--Succeeding level', 'See also reference term--Succeeding level', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'u', 'Use reference term', 'Use reference term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', 'v', 'Use reference term--Succeeding level', 'Use reference term--Succeeding level', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '753', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', 'a', 'Focus term', 'Focus term', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', 'b', 'Non-focus term', 'Non-focus term', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', 'c', 'Facet/hierarchy designation', 'Facet/hierarchy designation', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', '3', 'Material specified', 'Material specified', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '754', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', 'a', 'Genre/form term as entry element', 'Genre/form term as entry element', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', 'w', 'Control subfield', 'Control subfield', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', 'x', 'General subdivision', 'General subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', '0', 'Record control number', 'Record control number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '755', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'a', 'Number where instructions are found--Single number or beginnning number of span', 'Number where instructions are found--Single number or beginnning number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'b', 'Base number', 'Base number', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'd', 'Divided like number', 'Divided like number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'e', 'Example class number', 'Example class number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'f', 'Facet designator', 'Facet designator', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'n', 'Negative example class number', 'Negative example class number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'r', 'Root number', 'Root number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'x', 'Other classification number', 'Other classification number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', 'z', 'Table identification', 'Table identification', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '761', '8', 'Field link and sequence number', 'Field link and sequence number', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '762', 'a', 'Medium of performance term as entry element', 'Medium of performance term as entry element', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '762', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '762', 'w', 'Control subfield', 'Control subfield', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '762', 'z', 'Table number', 'Table number', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '762', '0', 'Authority record control number or standard number', 'Authority record control number or standard number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '762', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
        ('', '762', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '762', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '762', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'b', 'Base number', 'Base number', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'd', 'Divided like number', 'Divided like number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'e', 'Example class number', 'Example class number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'h', 'Caption hierarchy', 'Caption hierarchy', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'j', 'Caption', 'Caption', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'k', 'Summary number span caption hierarchy', 'Summary number span caption hierarchy', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'm', 'Manual note', 'Manual note', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'n', 'Number where instructions are found', 'Number where instructions are found', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'p', 'Corresponding classification field', 'Corresponding classification field', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'r', 'Root number', 'Root number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 's', 'See reference', 'See reference', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'x', 'Other classification number', 'Other classification number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', 'z', 'Table identification', 'Table identification', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '763', '8', 'Field link and sequence number', 'Field link and sequence number', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '764', 'a', 'Rule number', 'Rule number', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '764', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '764', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '764', '8', 'Field link and sequence number', 'Field link and sequence number', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'a', 'Number where instructions are found--Single number or beginning number of span', 'Number where instructions are found--Single number or beginning number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'b', 'Base number', 'Base number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'c', 'Number where instructions are found--Ending number of span', 'Number where instructions are found--Ending number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'f', 'Facet designator', 'Facet designator', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'r', 'Root number', 'Root number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 's', 'Digits added from classification number in schedule or external table', 'Digits added from classification number in schedule or external table', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 't', 'Digits added from internal subarrangement or add table', 'Digits added from internal subarrangement or add table', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'u', 'Number being analyzed', 'Number being analyzed', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'v', 'Number in internal subarrangement or add table where instructions are found', 'Number in internal subarrangement or add table where instructions are found', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'w', 'Table identification--Internal subarrangement or add table', 'Table identification--Internal subarrangement or add table', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'y', 'Table identification--Schedule [OBSOLETE]', 'Table identification--Schedule [OBSOLETE]', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', 'z', 'Table identification', 'Table identification', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '765', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '766', 'a', 'Secondary table of applicability', 'Secondary table of applicability', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '766', 'y', 'Type of division', 'Type of division', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '766', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '766', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'a', 'Classification number--Single number or beginning number of span', 'Classification number--Single number or beginning number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'c', 'Classification number--Ending number of span', 'Classification number--Ending number of span', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'e', 'Example class number', 'Example class number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'j', 'Caption', 'Caption', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'n', 'Negative example class number', 'Negative example class number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 't', 'Topic used as example of citation and preference order instruction', 'Topic used as example of citation and preference order instruction', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'x', 'Exception to table of preference', 'Exception to table of preference', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', 'z', 'Table identification--Table number', 'Table identification--Table number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '768', '8', 'Field link and sequence number', 'Field link and sequence number', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', 'w', 'Control subfield', 'Control subfield', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', 'x', 'General subdivision', 'General subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', '0', 'Record control number', 'Record control number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '780', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', 'w', 'Control subfield', 'Control subfield', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', 'x', 'General subdivision', 'General subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', '0', 'Record control number', 'Record control number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '781', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', 'w', 'Control subfield', 'Control subfield', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', 'x', 'General subdivision', 'General subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', '0', 'Record control number', 'Record control number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '782', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', 'v', 'Form subdivision', 'Form subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', 'w', 'Control subfield', 'Control subfield', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', 'x', 'General subdivision', 'General subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', 'y', 'Chronological subdivision', 'Chronological subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', 'z', 'Geographic subdivision', 'Geographic subdivision', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', '0', 'Record control number', 'Record control number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '785', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', 'a', 'Heading referred to', 'Heading referred to', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', 'i', 'Explanatory text', 'Explanatory text', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', '0', 'Record control number', 'Record control number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', '2', 'Source of heading or term', 'Source of heading or term', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', '5', 'Institution to which field applies', 'Institution to which field applies', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', '6', 'Linkage', 'Linkage', 0, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '788', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 7, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'a', 'Host name', 'Host name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'b', 'Access number', 'Access number', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'c', 'Compression information', 'Compression information', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'd', 'Path', 'Path', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'f', 'Electronic name', 'Electronic name', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'h', 'Processor of request', 'Processor of request', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'i', 'Instruction', 'Instruction', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'j', 'Bits per second', 'Bits per second', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'k', 'Password', 'Password', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'l', 'Logon', 'Logon', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'm', 'Contact for access assistance', 'Contact for access assistance', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'n', 'Name of location of host', 'Name of location of host', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'o', 'Operating system', 'Operating system', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'p', 'Port', 'Port', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'q', 'Electronic format type', 'Electronic format type', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'r', 'Settings', 'Settings', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 's', 'File size', 'File size', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 't', 'Terminal emulation', 'Terminal emulation', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'v', 'Hours access method available', 'Hours access method available', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'w', 'Record control number', 'Record control number', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'x', 'Nonpublic note', 'Nonpublic note', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'y', 'Link text', 'Link text', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', 'z', 'Public note', 'Public note', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', '2', 'Access method', 'Access method', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', '3', 'Materials specified', 'Materials specified', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', '6', 'Linkage', 'Linkage', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '856', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'a', 'a', 'a', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'b', 'b', 'b', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'c', 'c', 'c', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'd', 'd', 'd', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'e', 'e', 'e', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'f', 'f', 'f', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'g', 'g', 'g', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'h', 'h', 'h', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'i', 'i', 'i', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'j', 'j', 'j', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'k', 'k', 'k', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'l', 'l', 'l', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'm', 'm', 'm', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'n', 'n', 'n', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'o', 'o', 'o', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'p', 'p', 'p', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'q', 'q', 'q', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'r', 'r', 'r', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 's', 's', 's', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 't', 't', 't', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'u', 'u', 'u', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'v', 'v', 'v', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'w', 'w', 'w', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'x', 'x', 'x', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'y', 'y', 'y', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', 'z', 'z', 'z', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '0', '0', '0', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '1', '1', '1', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '2', '2', '2', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '3', '3', '3', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '4', '4', '4', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '5', '5', '5', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '6', 'Linkage', 'Linkage', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '7', '7', '7', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '8', '8', '8', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '880', '9', '9', '9', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '883', 'a', 'Generation process', 'Generation process', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '883', 'c', 'Confidence value', 'Confidence value', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '883', 'd', 'Generation date', 'Generation date', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '883', 'q', 'Generation agency', 'Generation agency', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '883', 'x', 'Validity end date', 'Validity end date', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '883', 'u', 'Uniform Resource Identifier', 'Uniform Resource Identifier', 0, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '883', 'w', 'Bibliographic record control number', 'Bibliographic record control number', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '883', '0', 'Authority record control number or standard number', 'Authority record control number or standard number', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '883', '8', 'Field link and sequence number', 'Field link and sequence number', 1, 0, 8, NULL, NULL, NULL, 0, 0, '', '', ''),
		('', '942', 'a', 'Koha auth type', 'Koha auth type', 0, 1, 9, NULL, NULL, NULL, 0, 8, '', 'auth_header.authtypecode', '');


-- ******************************************************

-- *******************************************************************
-- PERSONAL NAME AUTHORITY FIELDS/SUBFIELDS. XX0
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'PERSO_NAME', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ('110','111','130','148','150','151','155','162',
                     '180','181','182','185','034','640','641','642',
                     '643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'PERSO_NAME', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ('110','111','130','148','150','151','155','162',
                     '180','181','182','185','034','640','641','642',
                     '643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- CORPORATE NAME AUTHORITY FIELDS/SUBFIELDS. X10
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'CORPO_NAME', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','111','130','148','150','151','155','162',
                      '180','181','182','185','034','640','641','642',
                      '643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'CORPO_NAME', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','111','130','148','150','151','155','162',
                      '180','181','182','185','034','640','641','642',
                      '643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- MEETING NAME AUTHORITY FIELDS/SUBFIELDS. X11
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'MEETI_NAME', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','130','148','150','151','155','162',
                      '180','181','182','185','640','641','642','643',
                      '644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'MEETI_NAME', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','130','148','150','151','155','162',
                      '180','181','182','185','640','641','642','643',
                      '644','645','646');

-- ******************************************************

-- *******************************************************************
-- UNIFORM TITLE AUTHORITY FIELDS/SUBFIELDS. X30
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'UNIF_TITLE', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','148','150','151','155','162',
                      '180','181','182','185');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'UNIF_TITLE', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','148','150','151','155','162',
                      '180','181','182','185');

-- ******************************************************

-- *******************************************************************
-- CHRONOLOGICAL TERMS AUTHORITY FIELDS/SUBFIELDS. X48
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'CHRON_TERM', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','150','151','155','162',
                      '180','181','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'CHRON_TERM', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','150','151','155','162',
                      '180','181','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- TOPICAL TERMS AUTHORITY FIELDS/SUBFIELDS. X50
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'TOPIC_TERM', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','151','155','162',
                      '181','182','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'TOPIC_TERM', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','151','155','162',
                      '181','182','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- GEOGRAPHIC NAMES AUTHORITY FIELDS/SUBFIELDS. X51
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'GEOGR_NAME', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','150','155','162',
                      '180','182','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'GEOGR_NAME', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','150','155','162',
                      '180','182','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- GENRE/FORM TERMS AUTHORITY FIELDS/SUBFIELDS. X55
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'GENRE/FORM', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','150','151','162',
                      '180','181','182','014','020','022','031','640',
                      '641','642','643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'GENRE/FORM', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','150','151','162',
                      '180','181','182','014','020','022','031','640',
                      '641','642','643','644','645','646');

-- ******************************************************
